@@ -9,11 +9,13 @@
 #undef HAVE_SYS_DIR_H
 #undef HAVE_NDIR_H
 
+#undef SO_EXTENSION
 #undef SYSCONF_DIR
 #undef LOCALEDIR
 #undef DOCDIR
 #undef PLUGINS_DIR
 #undef SCRIPTS_DIR
+#undef GLADE_DIR
 #undef TIPS_FILE
 #undef SUPERFLUOUS
 #undef COMPATIBILITY
@@ -22,9 +24,14 @@
 #undef USE_PYTHON
 #undef NO_GUI
 #undef FOLLOW_MIGUEL
+#undef USE_DEBIAN
+#undef HAVE_PYGTK
+#undef HAVE_LIBGLADE
 
 #undef HAVE_IMLIB
+#undef HAVE_GDKPIXBUF
 #undef HAVE_ESD
+#undef HAVE_LIBXML
 
 #undef PACKAGE
 #undef VERSION
@@ -34,3 +41,5 @@
 
 #undef HAVE_TMPNAM
 
+#undef USE_POSTGRESQL
+
