@@ -1,9 +1,9 @@
 /*
    Main window
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1999  Ron Bessems
-   Contact me via email at R.E.M.W.Bessems@stud.tue.nl
+   Copyright (C) 2000  Frederic Peters
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -110,7 +110,7 @@ disable_buttons ()
 void 
 cancel_x(gpointer data)
 {
-  g_print("Cancel\n");
+  debug_print("Cancel\n");
 #ifdef USE_GNOME
   if (data!= NULL)
     gnome_interaction_key_return(*(int *)data,FALSE);
@@ -121,7 +121,7 @@ gint
 load_x (gchar * name, gpointer data)
 {
 #ifdef DEBUG
-  g_print ("Load_x\n");
+  debug_print ("Load_x\n");
 #endif
   /* delete the old one if the database loads */
   delete_desc (s);
@@ -130,7 +130,7 @@ load_x (gchar * name, gpointer data)
   s = new_desc ();
   if (load_desc (name, s) != 0)
     {
-      error_dialog (_ ("Cannot read the file, please check for \n" \
+      error_dialog (_ ("Cannot read the file, please check for \n" 
 		       "read permissions"), _ ("Error"));
       return -1;
     }
@@ -146,7 +146,7 @@ void
 close_x (gpointer data)
 {
 #ifdef DEBUG
-  g_print ("close_x\n");
+  debug_print ("close_x\n");
 #endif
   delete_desc (s);
   s = NULL;
@@ -156,7 +156,7 @@ close_x (gpointer data)
   /* This one come from the session managent stuff */
   if (data != NULL)
   {
-    g_print("Ret val !!!\n");
+    debug_print("Ret val !!!\n");
     gnome_interaction_key_return(*(int *)data,FALSE);
   }
 #endif
@@ -170,12 +170,12 @@ save_x (gchar * name, gpointer data)
   gchar buffer[1000];
   gchar *sla;
 #ifdef DEBUG
-  g_print ("Save_x\n");
+  debug_print ("Save_x\n");
 #endif
 
   if (save_desc (name, s) != 0)
     {
-      error_dialog (_ ("Cannot save the file, please check for \n" \
+      error_dialog (_ ("Cannot save the file, please check for \n" 
 		       "write permissions"), _ ("Error"));
       return -1;
     }
@@ -201,7 +201,7 @@ void
 new_x (gpointer data)
 {
 #ifdef DEBUG
-  g_print ("new_x\n");
+  debug_print ("new_x\n");
 #endif
   delete_desc (s);
   s = NULL;
@@ -216,7 +216,7 @@ stop_x (gpointer data)
 {
   GtkWidget *w;
 #ifdef DEBUG
-  g_print ("stop_x\n");
+  debug_print ("stop_x\n");
 #endif
 
 
@@ -274,12 +274,12 @@ about_clicked (GtkWidget * wid, GtkWidget * list)
   GtkWidget *about;
   const gchar *authors[]= {
 	"Ron Bessems <R.E.M.W.Bessems@stud.tue.nl>",
-	"Frederic Peters <fpeters@multimania.com>",
+	"Frederic Peters <fpeters@tiscalinet.be>",
 	NULL
 	};
 
   about = gnome_about_new("Builder",BVERSION,
-			  "(c) 1999 Ron Bessems",
+			  "(c) 1999 Ron Bessem, 2000 Frederic Peters",
 			  authors,
 			  _("The Gaby database builder"),
 			  NULL);
@@ -289,12 +289,13 @@ about_clicked (GtkWidget * wid, GtkWidget * list)
 
 #else
   gchar buffer[1000];		/* enough for all this bla */
-  sprintf (buffer, _ ("Gaby Description File builder version %s\n" \
-                      "Copyright 1999 (c) Ron Bessems\n"\
-                      "GNU General Public License\n\n"\
-		      "Authors:\nRon Bessems <R.E.M.W.Bessems@stud.tue.nl>" \
-		      "\nFrederic Peters <fpeters@multimania.com>" \
-		      "\n(by alphabetical order)" \
+  sprintf (buffer, _ ("Gaby Description File builder version %s\n" 
+                      "Copyright (c) 1999 Ron Bessems\n"
+		      "Copyright (c) 2000 Frederic Peters\n"
+                      "GNU General Public License\n\n"
+		      "Authors:\nRon Bessems <R.E.M.W.Bessems@stud.tue.nl>" 
+		      "\nFrederic Peters <fpeters@tiscalinet.be>" 
+		      "\n(by alphabetical order)" 
 	   ), BVERSION);
   error_dialog (buffer, _("About"));
 #endif
@@ -374,7 +375,7 @@ run_gaby_clicked (GtkWidget * widget, GtkWidget * list)
 
   if (g_list_length(s->subtables)==0)
   {
-    error_dialog(_("You must define at least one subtable\nbefore you "\
+    error_dialog(_("You must define at least one subtable\nbefore you "
                    "can use gaby."),_("Warning"));
     return;
   }
@@ -411,7 +412,7 @@ gaby_clicked (GtkWidget * widget, GtkWidget * list)
 
   if (g_list_length(s->subtables)==0)
   {
-    error_dialog(_("You must define at least one subtable\nbefore you "\
+    error_dialog(_("You must define at least one subtable\nbefore you "
                    "can use gaby."),_("Warning"));
     return;
   }
@@ -421,7 +422,7 @@ gaby_clicked (GtkWidget * widget, GtkWidget * list)
   strcpy(buffer,name);
   strcat(buffer,"/.gaby/desc.ihopethisnameisnotused1");
   if (save_desc(buffer,s)!=0)
-	g_print(_("Cannot save to the default path\n"));
+	debug_print(_("Cannot save to the default path\n"));
   system("gaby --as ihopethisnameisnotused1 &");
 }
 
@@ -563,7 +564,7 @@ static void
 destroy (GtkWidget * widget, gpointer * data)
 {
 #ifdef DEBUG
-  g_print ("button win destroy\n");
+  debug_print ("button win destroy\n");
 #endif
 }
 
@@ -584,7 +585,7 @@ drag_data_received (GtkWidget * widget, GdkDragContext * contex,
 {
   gchar *p;
 #ifdef DEBUG
-  g_print ("Drag & Drop event\n");
+  debug_print ("Drag & Drop event\n");
 #endif
   p = selection_data->data;
   drop_open_fileop (NULL, p);
@@ -681,7 +682,7 @@ create_menu_item (char *labeltext, GtkAccelGroup * accel_group)
   if (key < 255 && key > 0)
     {
       gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (label), menuitem);
-      gtk_widget_add_accelerator (menuitem, "activate", accel_group, \
+      gtk_widget_add_accelerator (menuitem, "activate", accel_group, 
 				  key, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
     }
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 1);
@@ -781,7 +782,7 @@ create_menu (GtkWidget * window, GtkAccelGroup * accel)
   file_item = gtk_menu_item_new ();
   lab = gtk_label_new ("");
   key = gtk_label_parse_uline (GTK_LABEL (lab), _ ("_File"));
-  gtk_widget_add_accelerator (file_item, "activate_item", accel, \
+  gtk_widget_add_accelerator (file_item, "activate_item", accel, 
 			      key, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
   gtk_misc_set_alignment (GTK_MISC (lab), 0.0, 1);
   gtk_container_add (GTK_CONTAINER (file_item), lab);
@@ -815,7 +816,7 @@ create_menu (GtkWidget * window, GtkAccelGroup * accel)
   file_item = gtk_menu_item_new ();
   lab = gtk_label_new ("");
   key = gtk_label_parse_uline (GTK_LABEL (lab), _ ("_Help"));
-  gtk_widget_add_accelerator (file_item, "activate_item", accel, \
+  gtk_widget_add_accelerator (file_item, "activate_item", accel, 
 			      key, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
   gtk_misc_set_alignment (GTK_MISC (lab), 0.0, 1);
   gtk_container_add (GTK_CONTAINER (file_item), lab);
@@ -954,9 +955,8 @@ create_button_window (gchar * caption)
   s = NULL;
   but = g_malloc (sizeof (struct buttons));
 
-//  gtk_widget_set_usize (window, 100, 180);
-  gtk_widget_show (window);
-
+  gtk_widget_realize(window);	/* so xpm_label_box won't issue warning */
+  
   gtk_container_set_border_width (GTK_CONTAINER (window), 0);
   Window = window;
   /* The box */
@@ -1062,7 +1062,7 @@ create_button_window (gchar * caption)
   gtk_signal_connect (GTK_OBJECT (addtable), "clicked",
 		      GTK_SIGNAL_FUNC (close_win), window);
   gtk_tooltips_set_tip (tooltip, addtable,
-			_("Exit Gaby Description Builder."), NULL);
+			_("Exit Gaby Databases Builder."), NULL);
 #endif
 
   /* Misc */
@@ -1091,4 +1091,6 @@ create_button_window (gchar * caption)
 
   configure_dnd (window);
   gtk_accel_group_attach (accel, GTK_OBJECT (window));
+  
 }
+
