@@ -1,9 +1,9 @@
 /*
    Data options
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1998  Ron Bessems
-   Contact me via email at R.E.M.W.Bessems@stud.tue.nl
+   Copyright (C) 2000  Frederic Peters
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
  */
 
 #include "main.h"
+extern doublestring view_names[];
 
 /* ******************************************************************** */
 /* properties options  (CASE SENSITIVE)                                 */
@@ -99,7 +100,7 @@ subtable_tree_rename_fields (file_s *s, gchar *name_of_table,
   if (s == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Rename called on NULL file_struct. \n");
+      debug_print ("Rename called on NULL file_struct. \n");
 #endif
       return;
     }
@@ -510,7 +511,7 @@ new_location()
 {
   location *loc;
 #ifdef DEBUG_GABY
-  g_print ("Creating new location\n");
+  debug_print ("Creating new location\n");
 #endif
   loc = g_malloc (sizeof (location));
   loc->path = NULL;
@@ -525,7 +526,7 @@ new_tlocation()
 {
   tlocation *tloc;
  #ifdef DEBUG_GABY
-  g_print ("Creating new tlocation\n");
+  debug_print ("Creating new tlocation\n");
 #endif
   tloc = g_malloc (sizeof (tlocation));
   tloc->name_of_table = NULL;
@@ -542,7 +543,7 @@ new_misc_s()
 {
   misc_s *s;
  #ifdef DEBUG_GABY
-  g_print ("Creating new misc_s\n");
+  debug_print ("Creating new misc_s\n");
 #endif
   s = g_malloc (sizeof (misc_s));
   s->name_of_subtable = NULL;
@@ -560,7 +561,7 @@ new_desc ()
 {
   file_s *s;
 #ifdef DEBUG_GABY
-  g_print ("Creating new file_s\n");
+  debug_print ("Creating new file_s\n");
 #endif
   s = g_malloc (sizeof (file_s));
   s->preview = NULL;
@@ -586,7 +587,7 @@ new_table ()
 {
   table *tab;
 #ifdef DEBUG_GABY
-  g_print ("Creating new table\n");
+  debug_print ("Creating new table\n");
 #endif
   tab = g_malloc (sizeof (table));
   tab->name = NULL;
@@ -601,7 +602,7 @@ new_subtable ()
 {
   subtable *tab;
 #ifdef DEBUG_GABY
-  g_print ("Creating new subtable\n");
+  debug_print ("Creating new subtable\n");
 #endif
   tab = g_malloc (sizeof (subtable));
   tab->name = NULL;
@@ -609,7 +610,7 @@ new_subtable ()
   /* initialize this on a default value */
   tab->viewable_as = NULL;
   tab->viewable_as = g_list_append(tab->viewable_as,
-		g_strdup(g_list_first(viewable_as)->data));
+		g_strdup(view_names[0].name));
 
   tab->subfields = NULL;
   tab->propwindow = NULL;
@@ -624,7 +625,7 @@ new_field ()
 {
   field *fld;
 #ifdef DEBUG_GABY
-  g_print ("Creating new field\n");
+  debug_print ("Creating new field\n");
 #endif
   fld = g_malloc (sizeof (field));
   fld->name = NULL;
@@ -642,7 +643,7 @@ new_subfield ()
 {
   subfield *fld;
 #ifdef DEBUG_GABY
-  g_print ("Creating new subfield\n");
+  debug_print ("Creating new subfield\n");
 #endif
   fld = g_malloc (sizeof (field));
   fld->name = NULL;
@@ -658,7 +659,7 @@ new_i18n ()
 {
   doublestring *ds;
 #ifdef DEBUG_GABY
-  g_print ("Creating new dubblestring\n");
+  debug_print ("Creating new dubblestring\n");
 #endif
   ds = g_malloc (sizeof (doublestring));
   ds->name = NULL;
@@ -677,12 +678,12 @@ delete_location(location *loc)
   if (loc==NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete called on NULL pointer location\n");
+      debug_print ("Delete called on NULL pointer location\n");
 #endif
       return;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete location\n");
+  debug_print ("Delete location\n");
 #endif
 
   if (loc->window != NULL)
@@ -697,12 +698,12 @@ delete_tlocation(tlocation *tloc)
   if (tloc==NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete called on NULL pointer tlocation\n");
+      debug_print ("Delete called on NULL pointer tlocation\n");
 #endif
       return;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete tlocation: %s\n", tloc->name_of_table);
+  debug_print ("Delete tlocation: %s\n", tloc->name_of_table);
 #endif
 
   if (tloc->window != NULL)
@@ -719,12 +720,12 @@ delete_misc_s(misc_s *s)
   if (s == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete called on NULL pointer misc_s\n");
+      debug_print ("Delete called on NULL pointer misc_s\n");
 #endif
       return;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete misc: %s\n", s->name_of_subtable);
+  debug_print ("Delete misc: %s\n", s->name_of_subtable);
 #endif
 
   if (s->window != NULL)
@@ -745,12 +746,12 @@ delete_table (table *tab)
   if (tab == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete called on NULL pointer table\n");
+      debug_print ("Delete called on NULL pointer table\n");
 #endif
       return;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete table: %s\n", tab->name);
+  debug_print ("Delete table: %s\n", tab->name);
 #endif
 
   if (tab->window != NULL)
@@ -768,12 +769,12 @@ delete_subtable (subtable *tab)
   if (tab == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete called on NULL pointer subtable\n");
+      debug_print ("Delete called on NULL pointer subtable\n");
 #endif
       return;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete subtable: %s\n", tab->name);
+  debug_print ("Delete subtable: %s\n", tab->name);
 #endif
   if (tab->window != NULL)
     gtk_widget_destroy (tab->window);
@@ -807,7 +808,7 @@ delete_field (field *fld)
   if (fld == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete called on NULL pointer field\n");
+      debug_print ("Delete called on NULL pointer field\n");
 #endif
       return;
     }
@@ -815,7 +816,7 @@ delete_field (field *fld)
   if (fld->window != NULL)
     gtk_widget_destroy (fld->window);
 #ifdef DEBUG_GABY
-  g_print ("Delete field %s\n", fld->name);
+  debug_print ("Delete field %s\n", fld->name);
 #endif
   g_free (fld->name);
   fld->properties = free_i18n (fld->properties);
@@ -830,14 +831,14 @@ delete_subfield (subfield *fld)
   if (fld == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete called on NULL pointer field\n");
+      debug_print ("Delete called on NULL pointer field\n");
 #endif
       return;
     }
   if (fld->window != NULL)
     gtk_widget_destroy (fld->window);
 #ifdef DEBUG_GABY
-  g_print ("Field: %s\n", fld->name);
+  debug_print ("Field: %s\n", fld->name);
 #endif
   g_free (fld->name);
   g_free (fld->name_of_field);
@@ -852,12 +853,12 @@ delete_i18n (doublestring *ds)
   if (ds == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete called on NULL pointer dubblestring\n");
+      debug_print ("Delete called on NULL pointer dubblestring\n");
 #endif 
       return;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete i18n\n");
+  debug_print ("Delete i18n\n");
 #endif
 
   g_free (ds->name);
@@ -873,7 +874,7 @@ delete_desc (file_s *s)
   if (s == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("Delete desc called with struct s NULL\n");
+      debug_print ("Delete desc called with struct s NULL\n");
 #endif
       return;
     }
@@ -919,12 +920,12 @@ free_locations (GList * locs)
   if (locs == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("free_locs called on NULL glist\n");
+      debug_print ("free_locs called on NULL glist\n");
 #endif
       return NULL;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete GList locs\n");
+  debug_print ("Delete GList locs\n");
 #endif
   loop = locs;
 
@@ -945,12 +946,12 @@ free_tlocations (GList * tlocs)
   if (tlocs == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("free_tlocs called on NULL glist\n");
+      debug_print ("free_tlocs called on NULL glist\n");
 #endif
       return NULL;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete GList tlocs\n");
+  debug_print ("Delete GList tlocs\n");
 #endif
   loop = tlocs;
 
@@ -975,12 +976,12 @@ free_misc_s (GList * miscs)
   if (miscs == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("free_misc_s called on NULL glist\n");
+      debug_print ("free_misc_s called on NULL glist\n");
 #endif
       return NULL;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete GList miscs\n");
+  debug_print ("Delete GList miscs\n");
 #endif
   loop = miscs;
   while (loop != NULL)
@@ -1002,12 +1003,12 @@ free_tables (GList * tables)
   if (tables == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("free_tables called on NULL glist\n");
+      debug_print ("free_tables called on NULL glist\n");
 #endif
       return NULL;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete GList tables\n");
+  debug_print ("Delete GList tables\n");
 #endif
   loop = tables;
   while (loop != NULL)
@@ -1027,12 +1028,12 @@ free_subtables (GList * subtables)
   if (subtables == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("free_subtables called on NULL glist\n");
+      debug_print ("free_subtables called on NULL glist\n");
 #endif
       return NULL;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete GList subtables\n");
+  debug_print ("Delete GList subtables\n");
 #endif
   loop = subtables;
   while (loop != NULL)
@@ -1052,12 +1053,12 @@ free_fields (GList * fields)
   if (fields == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("free_fields called on NULL glist\n");
+      debug_print ("free_fields called on NULL glist\n");
 #endif
       return NULL;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete GList fields\n");
+  debug_print ("Delete GList fields\n");
 #endif
   loop = fields;
   while (loop != NULL)
@@ -1077,12 +1078,12 @@ free_subfields (GList * subfields)
   if (subfields == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("free_fields called on NULL glist\n");
+      debug_print ("free_fields called on NULL glist\n");
 #endif
       return NULL;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete GList subfields\n");
+  debug_print ("Delete GList subfields\n");
 #endif
   loop = subfields;
   while (loop != NULL)
@@ -1102,12 +1103,12 @@ free_i18n (GList * i18n)
   if (i18n == NULL)
     {
 #ifdef DEBUG_GABY
-      g_print ("free_i18n called on NULL glist\n");
+      debug_print ("free_i18n called on NULL glist\n");
 #endif
       return NULL;
     }
 #ifdef DEBUG_GABY
-  g_print ("Delete GList i18n\n");
+  debug_print ("Delete GList i18n\n");
 #endif
   loop = i18n;
   while (loop != NULL)
