@@ -1,9 +1,10 @@
 /*
    Description file handling
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1998  Ron Bessems
    Contact me via email at R.E.M.W.Bessems@stud.tue.nl
+   Copyright (C) 2000 Frederic Peters
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,6 +42,8 @@ ftype (char *text)
     type = T_INTEGER;
   if (strcasecmp (text, "Real") == 0)
     type = T_REAL;
+  if (strcasecmp (text, "Decimal") == 0)
+    type = T_DECIMAL;
   if (strcasecmp (text, "Date") == 0)
     type = T_DATE;
   if (strcasecmp (text, "Boolean") == 0)
@@ -51,6 +54,8 @@ ftype (char *text)
     type = T_RECORDS;
   if (strcasecmp (text, "Multimedia") == 0)
     type = T_MULTIMEDIA;
+  if (strcasecmp (text, "File") == 0)
+    type = T_FILE;
   if (type == -1)
     {
       type = T_STRING;
@@ -313,7 +318,7 @@ load_tables (file_s *s, FILE * in, gchar **errortext)
                 fld->type = ftype(right);
                 if (fld->type == T_RECORD || fld->type == T_RECORDS)
                   {
-                    add_error_text(errortext,linec,"Record(s) field type not"\
+                    add_error_text(errortext,linec,"Record(s) field type not"
 						" supported",buffer);
                     fld->type = T_STRING;
                   }
@@ -376,8 +381,7 @@ load_tables (file_s *s, FILE * in, gchar **errortext)
 
     } /* while != eof */
 
-  /* TODO :Can i hardcode this ????  Directory error... which include file . */
-  if (errno == 21)
+  if (errno == EISDIR)
     {
       return -2;
     }
@@ -446,7 +450,7 @@ with_every_field
               sfld->name = g_strdup(fld->name);
               sfld->name_of_field = g_strdup(fld->name);
 #ifdef DEBUG
-	      g_print ("Adding: %s\n", sfld->name);
+	      debug_print ("Adding: %s\n", sfld->name);
 #endif
 	      stab->subfields = g_list_append (stab->subfields, sfld);
 	      loop2 = loop2->next;
@@ -668,8 +672,7 @@ load_subtables (file_s *s, FILE * in, gchar **errortext)
 
     } /* while != eof */
 
-  /* TODO :Can i hardcode this ????  Directory error... which include file . */
-  if (errno == 21)
+  if (errno == EISDIR)
     {
       return -2;
     }
@@ -703,7 +706,7 @@ load_misc (file_s *s, FILE * in)
 
   if (s->miscs != NULL)
     {
-      g_print ("Warning misc !=NULL where it should be\n");
+      debug_print ("Warning misc !=NULL where it should be\n");
     }
 
   while (feof (in) == 0 && ferror (in) == 0)
@@ -790,12 +793,11 @@ load_misc (file_s *s, FILE * in)
            }break;
 	default:
           if (tables ==1)
-	    g_print("%d : Unexpected option !!\n",linec);
+	    debug_print("%d : Unexpected option !!\n",linec);
 	  break;
 	}
     }
-  /* TODO :Can i hardcode this ????  Directory error... which include file . */
-  if (errno == 21)
+  if (errno == EISDIR)
     {
       return -1;
     }
@@ -824,7 +826,7 @@ load_actions (file_s *s, FILE * in)
   tables = 0;
   if (s->actions != NULL)
     {
-      g_print ("Warning actions !=NULL where is should be\n");
+      debug_print ("Warning actions !=NULL where is should be\n");
     }
   s->actions = g_malloc (1);
   s->actions[0] = '\0';
@@ -860,8 +862,7 @@ load_actions (file_s *s, FILE * in)
 	  break;
 	}
     }
-  /* TODO :Can i hardcode this ????  Directory error... which include file . */
-  if (errno == 21)
+  if (errno == EISDIR)
     {
       return -1;
     }
@@ -941,7 +942,7 @@ load_locations (file_s *s, FILE * in, gchar **errortext)
            {
              split (buffer,'=',&left, &right);
 #ifdef DEBUG_GABY
-             g_print("left :[%s] right : [%s]\n",left,right);
+             debug_print("left :[%s] right : [%s]\n",left,right);
 #endif
              option = 0;
              if (strcasecmp(left,"format")==0)
@@ -961,7 +962,7 @@ load_locations (file_s *s, FILE * in, gchar **errortext)
                } 
              if (option ==0)
                {
-	         add_error_text(errortext,linec,"Unkown option for "\
+	         add_error_text(errortext,linec,"Unkown option for "
                                           "locations", buffer);
                }
            } 
@@ -970,14 +971,13 @@ load_locations (file_s *s, FILE * in, gchar **errortext)
           if (tables ==1)
             {
               trim(buffer);
-              add_error_text(errortext,linec,"Unkown indentation depth for "\
+              add_error_text(errortext,linec,"Unkown indentation depth for "
                                           "locations", buffer);
             }
 	  break;
 	}
     }
-  /* TODO :Can i hardcode this ????  Directory error... which include file . */
-  if (errno == 21)
+  if (errno == EISDIR)
     {
       return -1;
     }
@@ -1005,7 +1005,7 @@ load_options (file_s *s, FILE * in)
   tables = 0;
   if (s->plugin_options != NULL)
     {
-      g_print ("Warning actions !=NULL where is should be\n");
+      debug_print ("Warning actions !=NULL where is should be\n");
     }
   s->plugin_options = g_malloc (1);
   s->plugin_options[0] = '\0';
@@ -1041,8 +1041,7 @@ load_options (file_s *s, FILE * in)
 	  break;
 	}
     }
-  /* TODO :Can i hardcode this ????  Directory error... which include file . */
-  if (errno == 21)
+  if (errno == EISDIR)
     {
       return -1;
     }
@@ -1238,344 +1237,351 @@ print_i18n (GList * dubbel, gint veld,
 
 
 /* OK i need to use some functions for this */
-
-int
-print_table (file_s *s, gpointer * d,
-	     int (*print_function) (gchar *, gpointer *))
+/* note by Pitr: oh yeah... */
+int print_table (file_s *s, gpointer * d,
+		 int (*print_function) (gchar *, gpointer *))
 {
-  GList *trav;
-  GList *fields;
-  gchar buffer[1000];
+	GList *trav;
+	GList *fields;
+	gchar buffer[1000];
 
-  table *tab;
-  field *field;
-  subtable *stab;
-  subfield *fld;
-  misc_s *misc;
-  location *loc;
-  tlocation *tloc; 
-  gchar *stemp;
-  gint temp;
-  doublestring *ds;
+	table *tab;
+	field *field;
+	subtable *stab;
+	subfield *fld;
+	misc_s *misc;
+	location *loc;
+	tlocation *tloc; 
+	gchar *stemp;
+	gint temp;
+	doublestring *ds;
 
 
-  trav = s->tables;
-  g_list_first (trav);
-  sprintf (buffer, "Begin tables\n");
-  print_function (buffer, d);
-  while (trav)
-    {
-      tab = trav->data;
-      if (tab->alias != NULL && strlen (tab->alias) > 0)
-	sprintf (buffer, "\t%s:%s\n", tab->name, tab->alias);
-      else
-	sprintf (buffer, "\t%s\n", tab->name);
-      print_function (buffer, d);
-
-      if (tab->fields != NULL)
+	trav = s->tables;
+	g_list_first (trav);
+	sprintf (buffer, "Begin tables\n");
+	print_function (buffer, d);
+	while (trav)
 	{
-	  fields = tab->fields;
-	  g_list_first (fields);
-	  while (fields)
-	    {
-	      field = fields->data;
-	      switch (field->type)
+		tab = trav->data;
+		if (tab->alias != NULL && strlen (tab->alias) > 0)
+			sprintf (buffer, "\t%s:%s\n", tab->name, tab->alias);
+		else
+			sprintf (buffer, "\t%s\n", tab->name);
+		print_function (buffer, d);
+
+		if (tab->fields != NULL)
 		{
-		case T_STRING:
-		  sprintf (buffer, "\t\t%s:String\n", field->name);
-		  break;
-		case T_STRINGS:
-		  sprintf (buffer, "\t\t%s:Strings\n", field->name);
-		  break;
-		case T_INTEGER:
-		  sprintf (buffer, "\t\t%s:Integer\n", field->name);
-		  break;
-		case T_REAL:
-		  sprintf (buffer, "\t\t%s:Real\n", field->name);
-		  break;
-		case T_DATE:
-		  sprintf (buffer, "\t\t%s:Date\n", field->name);
-		  break;
-		case T_BOOLEAN:
-		  sprintf (buffer, "\t\t%s:Boolean\n", field->name);
-		  break;
-		case T_RECORD:
-		  sprintf (buffer, "\t\t%s:Record\n", field->name);
-		  break;
-		case T_RECORDS:
-		  sprintf (buffer, "\t\t%s:RECORDS\n", field->name);
-		  break;
-		case T_MULTIMEDIA:
-		  sprintf (buffer, "\t\t%s:Multimedia\n", field->name);
-		  break;
+			fields = tab->fields;
+			g_list_first (fields);
+			while (fields)
+			{
+				field = fields->data;
+				switch (field->type)
+				{
+					case T_STRING:
+						sprintf (buffer, "\t\t%s:String\n", field->name);
+						break;
+					case T_STRINGS:
+						sprintf (buffer, "\t\t%s:Strings\n", field->name);
+						break;
+					case T_INTEGER:
+						sprintf (buffer, "\t\t%s:Integer\n", field->name);
+						break;
+					case T_REAL:
+						sprintf (buffer, "\t\t%s:Real\n", field->name);
+						break;
+					case T_DECIMAL:
+						sprintf (buffer, "\t\t%s:Decimal\n", field->name);
+						break;
+					case T_DATE:
+						sprintf (buffer, "\t\t%s:Date\n", field->name);
+						break;
+					case T_BOOLEAN:
+						sprintf (buffer, "\t\t%s:Boolean\n", field->name);
+						break;
+					case T_RECORD:
+						sprintf (buffer, "\t\t%s:Record\n", field->name);
+						break;
+					case T_RECORDS:
+						sprintf (buffer, "\t\t%s:Records\n", field->name);
+						break;
+					case T_MULTIMEDIA:
+						sprintf (buffer, "\t\t%s:Multimedia\n", field->name);
+						break;
+					case T_FILE:
+						sprintf (buffer, "\t\t%s:File\n", field->name);
+						break;
+				}
+
+				print_function (buffer, d);
+				print_i18n (field->i18n_name, 1, print_function, d);
+				print_i18n (field->i18n_desc, 2, print_function, d);
+
+				if (get_option(&field->properties,"DEFAULT")!= NULL)
+				{
+					sprintf (buffer, "\t\t\tdefault=%s\n", 
+							get_option(&field->properties,"DEFAULT"));
+					print_function (buffer, d);
+				}
+
+
+				if (get_option(&field->properties,"FORMAT")!= NULL)
+				{
+					sprintf (buffer, "\t\t\tformat=%s\n", 
+							get_option(&field->properties,"FORMAT"));
+					print_function (buffer, d);
+				}
+
+				if (get_option(&field->properties,"TYPE")!= NULL)
+				{
+					sprintf (buffer, "\t\t\ttype=%s\n", 
+							get_option(&field->properties,"TYPE"));
+					print_function (buffer, d);
+				}
+
+
+				fields = fields->next;
+			}
 		}
-
-	      print_function (buffer, d);
-	      print_i18n (field->i18n_name, 1, print_function, d);
-	      print_i18n (field->i18n_desc, 2, print_function, d);
-
-		if (get_option(&field->properties,"DEFAULT")!= NULL)
-		  {
-		    sprintf (buffer, "\t\t\tdefault=%s\n", 
-			        get_option(&field->properties,"DEFAULT"));
-		    print_function (buffer, d);
-		  }
-
-
-		if (get_option(&field->properties,"FORMAT")!= NULL)
-		  {
-		    sprintf (buffer, "\t\t\tformat=%s\n", 
-			        get_option(&field->properties,"FORMAT"));
-		    print_function (buffer, d);
-		  }
-
-		if (get_option(&field->properties,"TYPE")!= NULL)
-		  {
-		    sprintf (buffer, "\t\t\ttype=%s\n", 
-				get_option(&field->properties,"TYPE"));
-		    print_function (buffer, d);
-		  }
-
-
-	      fields = fields->next;
-	    }
+		trav = trav->next;
 	}
-      trav = trav->next;
-    }
-  sprintf (buffer, "End\n");
-  print_function (buffer, d);
+	sprintf (buffer, "End\n");
+	print_function (buffer, d);
 
 
 
-  /* SUBTABLE PRINTING */
+	/* SUBTABLE PRINTING */
 
 
-  sprintf (buffer, "\nBegin subtables\n");
-  print_function (buffer, d);
-  trav = s->subtables;
-  trav = g_list_first (trav);
-  while (trav)
-    {
-      stab = trav->data;
-      sprintf (buffer, "\t%s:%s\n", stab->name, stab->name_of_table);
-      print_function (buffer, d);
-
-      print_i18n (stab->i18n_name, 5, print_function, d);
-      print_i18n (stab->i18n_desc, 6, print_function, d);
-      if (stab->viewable_as != NULL)
+	sprintf (buffer, "\nBegin subtables\n");
+	print_function (buffer, d);
+	trav = s->subtables;
+	trav = g_list_first (trav);
+	while (trav)
 	{
-	  fields = stab->viewable_as;
-	  fields = g_list_first (fields);
-	  strcpy (buffer, "\t\tviewable as ");
-	  while (fields != NULL)
-	    {
-	      strcat (buffer, fields->data);
-	      strcat (buffer, ",");
-	      fields = fields->next;
-	    }
+		stab = trav->data;
+		sprintf (buffer, "\t%s:%s\n", stab->name, stab->name_of_table);
+		print_function (buffer, d);
+
+		print_i18n (stab->i18n_name, 5, print_function, d);
+		print_i18n (stab->i18n_desc, 6, print_function, d);
+		if (stab->viewable_as != NULL)
+		{
+			fields = stab->viewable_as;
+			fields = g_list_first (fields);
+			strcpy (buffer, "\t\tviewable as ");
+			while (fields != NULL)
+			{
+				strcat (buffer, fields->data);
+				strcat (buffer, ",");
+				fields = fields->next;
+			}
+		}
+		temp = strlen (buffer);
+
+		buffer[temp + 1] = '\0';
+		buffer[temp] = '\n';
+		buffer[temp - 1] = '.';
+
+		print_function (buffer, d);
+
+		if (stab->subfields != NULL)
+		{
+			sprintf (buffer, "\t\twith only the following fields\n");
+			print_function (buffer, d);
+			fields = stab->subfields;
+			fields = g_list_first (fields);
+
+			while (fields != NULL)
+			{
+				fld = fields->data;
+				sprintf (buffer, "\t\t\t%s:%s\n", fld->name_of_field, fld->name);
+				print_function (buffer, d);
+				print_i18n (fld->i18n_name, 3, print_function, d);
+				print_i18n (fld->i18n_desc, 4, print_function, d);
+
+				fields = fields->next;
+			}
+		}
+		trav = trav->next;
 	}
-      temp = strlen (buffer);
 
-      buffer[temp + 1] = '\0';
-      buffer[temp] = '\n';
-      buffer[temp - 1] = '.';
+	sprintf (buffer, "End\n");
+	print_function (buffer, d);
 
-      print_function (buffer, d);
+	/* ACTIONS */
 
-      if (stab->subfields != NULL)
+	if (s->actions != NULL)
 	{
-	  sprintf (buffer, "\t\twith only the following fields\n");
-	  print_function (buffer, d);
-	  fields = stab->subfields;
-	  fields = g_list_first (fields);
-
-	  while (fields != NULL)
-	    {
-	      fld = fields->data;
-	      sprintf (buffer, "\t\t\t%s:%s\n", fld->name_of_field, fld->name);
-	      print_function (buffer, d);
-	      print_i18n (fld->i18n_name, 3, print_function, d);
-	      print_i18n (fld->i18n_desc, 4, print_function, d);
-
-	      fields = fields->next;
-	    }
+		if (strlen(s->actions)!=0)
+		{
+			sprintf (buffer, "\nBegin actions\n");
+			print_function (buffer, d);
+			print_function (s->actions, d);
+			sprintf (buffer, "End\n");
+			print_function (buffer, d);
+		}
 	}
-      trav = trav->next;
-    }
 
-  sprintf (buffer, "End\n");
-  print_function (buffer, d);
-
-  /* ACTIONS */
-
-  if (s->actions != NULL)
-  {
-    if (strlen(s->actions)!=0)
-    {
-      sprintf (buffer, "\nBegin actions\n");
-      print_function (buffer, d);
-      print_function (s->actions, d);
-      sprintf (buffer, "End\n");
-      print_function (buffer, d);
-    }
-  }
-
-  /* Plugin options */
+	/* Plugin options */
 
 
-  if (s->plugin_options != NULL)
-  {
-    if (strlen(s->plugin_options)!=0)
-    {
-      sprintf (buffer, "\nBegin plugins_options\n");
-      print_function (buffer, d);
-      print_function (s->plugin_options, d);
-      sprintf (buffer, "End\n");
-      print_function (buffer, d);
-    }
-  }
+	if (s->plugin_options != NULL)
+	{
+		if (strlen(s->plugin_options)!=0)
+		{
+			sprintf (buffer, "\nBegin plugins_options\n");
+			print_function (buffer, d);
+			print_function (s->plugin_options, d);
+			sprintf (buffer, "End\n");
+			print_function (buffer, d);
+		}
+	}
 
 
   /* LOCATION PRINTING */
 
 
 
-  if (s->tlocations != NULL)
-  {
-    sprintf(buffer,"\nBegin locations\n");
-    print_function(buffer,d);
-    trav = g_list_first(s->tlocations);
-    while (trav != NULL)
-    {
-      tloc = trav->data;
-      sprintf(buffer,"\t%s\n",tloc->name_of_table);
-      print_function(buffer,d);
-      fields = g_list_first(tloc->locations);
-      while (fields != NULL)
-      {
-        loc = fields->data;
-        sprintf(buffer,"\t\t%s\n",loc->path);
-        print_function(buffer,d);
-        stemp = get_option(&loc->prop,"FORMAT");
-        if (stemp != NULL)
-        {
-          if (strcasecmp(stemp,"gaby")!=0)
-          {
-            sprintf(buffer,"\t\t\tformat=%s\n",stemp);
-            print_function(buffer,d);
-          }
-        }
-        stemp = get_option(&loc->prop,"REREAD");
-        if (stemp != NULL)
-        {
-          if (atoi(stemp)>0)
-          {
-            sprintf(buffer,"\t\t\treread=%s\n",stemp);
-            print_function(buffer,d);
-          }
-        }
-        stemp = get_option(&loc->prop,"READONLY");
-        if (stemp != NULL)
-        {
-          if (strcasecmp(stemp,"YES")==0)
-          {
-            sprintf(buffer,"\t\t\tread-only=%s\n",stemp);
-            print_function(buffer,d);
-	  }
-          /* options} */
-        }
-        fields = fields->next;
-      } 
-      trav = trav->next;
-    }
-  }
-  sprintf (buffer, "End\n");
-  print_function (buffer, d);
- 
-
-  /* Misc printing */
+	if (s->tlocations != NULL)
+	{
+		sprintf(buffer,"\nBegin locations\n");
+		print_function(buffer,d);
+		trav = g_list_first(s->tlocations);
+		while (trav != NULL)
+		{
+			tloc = trav->data;
+			trav = g_list_next(trav);
+			sprintf(buffer,"\t%s\n",tloc->name_of_table);
+			print_function(buffer,d);
+			fields = g_list_first(tloc->locations);
+			while (fields != NULL)
+			{
+				loc = fields->data;
+				fields = g_list_next(fields);
+				sprintf(buffer,"\t\t%s\n",loc->path);
+				print_function(buffer,d);
+				stemp = get_option(&loc->prop,"FORMAT");
+				if (stemp != NULL)
+				{
+					if (strcasecmp(stemp,"gaby")!=0)
+					{
+						sprintf(buffer,"\t\t\tformat=%s\n",stemp);
+						print_function(buffer,d);
+					}
+				}
+				stemp = get_option(&loc->prop,"REREAD");
+				if (stemp != NULL)
+				{
+					if (atoi(stemp)>0)
+					{
+						sprintf(buffer,"\t\t\treread=%s\n",stemp);
+						print_function(buffer,d);
+					}
+				}
+				stemp = get_option(&loc->prop,"READONLY");
+				if (stemp != NULL)
+				{
+					if (strcasecmp(stemp,"YES")==0)
+					{
+						sprintf(buffer,"\t\t\tread-only=%s\n",stemp);
+						print_function(buffer,d);
+					}
+					/* options */
+				}
+			}
+		}
+	}
+	if ( s->tlocations ) {
+		sprintf (buffer, "End\n");
+		print_function (buffer, d);
+	}
 
 
-  temp = 0;
-  if (s->miscs != NULL)
-  {
-    sprintf (buffer, "\nBegin misc\n");
-    print_function (buffer, d);
- 
+	/* Misc printing */
 
-    trav = g_list_first(s->miscs);
-    while (trav != NULL)
-    {
-      misc = trav->data;
-      if (misc->main == TRUE)
-      {
-        sprintf (buffer, "\tMain window\n");
-        print_function (buffer, d);
-	sprintf (buffer, "\t\t%s:%s\n",misc->view_as,misc->name_of_subtable);
-        print_function (buffer, d);
-        if (misc->visible == TRUE)
-          sprintf (buffer, "\t\t\tvisible = yes\n");
-        else
-          sprintf (buffer, "\t\t\tvisible = no\n");
-        print_function (buffer, d);
-	if ( misc->bind_to != NULL)
-          {
-             sprintf (buffer, "\t\t\tbind to\n");
-             print_function (buffer, d);
-             fields = g_list_first(misc->bind_to);
-             while (fields!= NULL)
-               {
-		 ds = fields->data;
-                 sprintf (buffer, "\t\t\t\t%s:%s\n",ds->locale,ds->name);
-                 print_function (buffer, d);
-                 fields = fields ->next;
-               }
-          }
-      }
-      trav = trav->next;
-    }
 
-    trav = g_list_first(s->miscs);
-    while (trav != NULL)
-    {
-      misc = trav->data;
-      if (misc->main == FALSE)
-      {
-	if (temp == 0) 
-        {
-          sprintf (buffer, "\tOther windows\n");
-          print_function (buffer, d);
-          temp = 1;
-        }
-	sprintf (buffer, "\t\t%s:%s\n",misc->view_as,misc->name_of_subtable);
-        print_function (buffer, d);
-        if (misc->visible == TRUE)
-          sprintf (buffer, "\t\t\tvisible = yes\n");
-        else
-          sprintf (buffer, "\t\t\tvisible = no\n");
-        print_function (buffer, d);
-	if ( misc->bind_to != NULL)
-          {
-             sprintf (buffer, "\t\t\tbind to\n");
-             print_function (buffer, d);
-             fields = g_list_first(misc->bind_to);
-             while (fields!= NULL)
-               {
-		 ds = fields->data;
-                 sprintf (buffer, "\t\t\t\t%s:%s\n",ds->locale,ds->name);
-                 print_function (buffer, d);
-                 fields = fields ->next;
-               }
-          }
-      }
-      trav = trav->next;
-    }
+	temp = 0;
+	if (s->miscs != NULL)
+	{
+		sprintf (buffer, "\nBegin misc\n");
+		print_function (buffer, d);
 
-    sprintf (buffer, "End\n");
-    print_function (buffer, d);
- 
-  }
 
-  return 0;
+		trav = g_list_first(s->miscs);
+		while (trav != NULL)
+		{
+			misc = trav->data;
+			if (misc->main == TRUE)
+			{
+				sprintf (buffer, "\tMain window\n");
+				print_function (buffer, d);
+				sprintf (buffer, "\t\t%s:%s\n",misc->view_as,misc->name_of_subtable);
+				print_function (buffer, d);
+				if (misc->visible == TRUE)
+					sprintf (buffer, "\t\t\tvisible = yes\n");
+				else
+					sprintf (buffer, "\t\t\tvisible = no\n");
+				print_function (buffer, d);
+				if ( misc->bind_to != NULL)
+				{
+					sprintf (buffer, "\t\t\tbind to\n");
+					print_function (buffer, d);
+					fields = g_list_first(misc->bind_to);
+					while (fields!= NULL)
+					{
+						ds = fields->data;
+						sprintf (buffer, "\t\t\t\t%s:%s\n",ds->locale,ds->name);
+						print_function (buffer, d);
+						fields = fields ->next;
+					}
+				}
+			}
+			trav = trav->next;
+		}
+
+		trav = g_list_first(s->miscs);
+		while (trav != NULL)
+		{
+			misc = trav->data;
+			if (misc->main == FALSE)
+			{
+				if (temp == 0) 
+				{
+					sprintf (buffer, "\tOther windows\n");
+					print_function (buffer, d);
+					temp = 1;
+				}
+				sprintf (buffer, "\t\t%s:%s\n",misc->view_as,misc->name_of_subtable);
+				print_function (buffer, d);
+				if (misc->visible == TRUE)
+					sprintf (buffer, "\t\t\tvisible = yes\n");
+				else
+					sprintf (buffer, "\t\t\tvisible = no\n");
+				print_function (buffer, d);
+				if ( misc->bind_to != NULL)
+				{
+					sprintf (buffer, "\t\t\tbind to\n");
+					print_function (buffer, d);
+					fields = g_list_first(misc->bind_to);
+					while (fields!= NULL)
+					{
+						ds = fields->data;
+						sprintf (buffer, "\t\t\t\t%s:%s\n",ds->locale,ds->name);
+						print_function (buffer, d);
+						fields = fields ->next;
+					}
+				}
+			}
+			trav = trav->next;
+		}
+
+		sprintf (buffer, "End\n");
+		print_function (buffer, d);
+
+	}
+
+	return 0;
 
 }
