@@ -1,9 +1,10 @@
 /*
    Field properties window
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1998  Ron Bessems
    Contact me via email at R.E.M.W.Bessems@stud.tue.nl
+   Copyright (C) 2000 Frederic Peters
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,6 +27,7 @@
 
 static GtkAccelGroup *accel;
 
+extern doublestring type_names[];
 
 typedef struct _main_update info1;
 
@@ -439,15 +441,16 @@ void
 combo_set (GtkWidget * combo, field *fld)
 {
   gchar *buffer;
-  buffer = "String";
+  buffer = type_names[fld->type].locale;
+#if 0
   switch (fld->type)
     {
-    case T_STRINGS:
-      buffer = "Strings";
-      break;
     case T_STRING:
       buffer = "String";
       break;
+    case T_STRINGS:
+      buffer = "Strings";
+      break;
     case T_INTEGER:
       buffer = "Integer";
       break;
@@ -469,62 +472,74 @@ combo_set (GtkWidget * combo, field *fld)
     case T_MULTIMEDIA:
       buffer = "Multimedia";
       break;
+    case T_DECIMAL:
+      buffer = "Decimal";
+      break;
     }
+#endif
   gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), buffer);
 }
 
 void
 type_act (GtkWidget * wid, info1 *info)
 {
-  file_s *s;
-  gchar *text;
-  enum field_type type;
-  field *fld;
-  GtkWidget *type2;
+	file_s *s;
+	gchar *text;
+	enum field_type type = T_STRING;
+	field *fld;
+	GtkWidget *type2;
+	int i;
 
-  fld = info->fld;
-  s = info->s;
-  type2 = info->mmtype;
- 
-  s->changed = TRUE;
+	fld = info->fld;
+	s = info->s;
+	type2 = info->mmtype;
 
-  text = gtk_entry_get_text (GTK_ENTRY (wid));
-  type = T_STRING;
-  if (strcasecmp (text, "Strings") == 0)
-    type = T_STRINGS;
-  if (strcasecmp (text, "String") == 0)
-    type = T_STRING;
-  if (strcasecmp (text, "Integer") == 0)
-    type = T_INTEGER;
-  if (strcasecmp (text, "Real") == 0)
-    type = T_REAL;
-  if (strcasecmp (text, "Date") == 0)
-    type = T_DATE;
-  if (strcasecmp (text, "Boolean") == 0)
-    type = T_BOOLEAN;
-  if (strcasecmp (text, "Record") == 0)
-    type = T_RECORD;
-  if (strcasecmp (text, "Records") == 0)
-    type = T_RECORDS;
-  if (strcasecmp (text, "Multimedia") == 0)
-    type = T_MULTIMEDIA;
+	s->changed = TRUE;
 
-  fld->type = type;
-  
-  if (fld->type == T_MULTIMEDIA)
-  {
-    gtk_widget_set_sensitive(type2,TRUE);
-    if (get_option(&fld->properties,"TYPE")==NULL)
-    {
-      gtk_option_menu_set_history(GTK_OPTION_MENU(type2),0);
-    }
-  }
-  else
-  {
-    gtk_widget_set_sensitive(type2,FALSE);
-  }
- 
-  return;
+	text = gtk_entry_get_text (GTK_ENTRY (wid));
+	i = 0;
+	while ( type_names[i].locale ) {
+		if ( strcasecmp(text, type_names[i].locale) == 0 ) {
+			type = i;
+			break;
+		}
+		i++;
+	}
+#if 0
+	type = T_STRING;
+	if (strcasecmp (text, "Strings") == 0)
+		type = T_STRINGS;
+	if (strcasecmp (text, "String") == 0)
+		type = T_STRING;
+	if (strcasecmp (text, "Integer") == 0)
+		type = T_INTEGER;
+	if (strcasecmp (text, "Real") == 0)
+		type = T_REAL;
+	if (strcasecmp (text, "Date") == 0)
+		type = T_DATE;
+	if (strcasecmp (text, "Boolean") == 0)
+		type = T_BOOLEAN;
+	if (strcasecmp (text, "Record") == 0)
+		type = T_RECORD;
+	if (strcasecmp (text, "Records") == 0)
+		type = T_RECORDS;
+	if (strcasecmp (text, "Multimedia") == 0)
+		type = T_MULTIMEDIA;
+	if (strcasecmp (text, "Decimal") == 0)
+		type = T_DECIMAL;
+#endif
+	fld->type = type;
+
+	if (fld->type == T_MULTIMEDIA) {
+		gtk_widget_set_sensitive(type2,TRUE);
+		if (get_option(&fld->properties,"TYPE") == NULL) {
+			gtk_option_menu_set_history(GTK_OPTION_MENU(type2),0);
+		}
+	} else {
+		gtk_widget_set_sensitive(type2,FALSE);
+	}
+
+	return;
 }
 
 
@@ -658,6 +673,7 @@ create_fieldprop_window (field *fld, file_s *s, gchar * caption)
   gint row;
   doublestring *names;
   gchar *strd[2];
+  int i;
 
 
   if (fld->window != NULL)
@@ -832,15 +848,12 @@ create_fieldprop_window (field *fld, file_s *s, gchar * caption)
   gtk_widget_show (label);
 
   loop = NULL;
-  loop = g_list_append (loop, "String");
-  loop = g_list_append (loop, "Strings");
-  loop = g_list_append (loop, "Integer");
-  loop = g_list_append (loop, "Real");
-  loop = g_list_append (loop, "Date");
-  loop = g_list_append (loop, "Boolean");
-  /* loop = g_list_append (loop, "Record");
-     loop = g_list_append (loop, "Records"); */
-  loop = g_list_append (loop, "Multimedia");
+  i=0;
+  while ( type_names[i].name ) {
+	  loop = g_list_append(loop, type_names[i].locale);
+	  i++;
+  }
+  
   combo = gtk_combo_new ();
   gtk_combo_set_popdown_strings (GTK_COMBO (combo), loop);
   gtk_widget_show (combo);
