@@ -1,7 +1,7 @@
 /*
    Fields window
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1998  Ron Bessems
    Contact me via email at R.E.M.W.Bessems@stud.tue.nl
 
