@@ -1,9 +1,9 @@
 /*
    Location window
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1998  Ron Bessems
-   Contact me via email at R.E.M.W.Bessems@stud.tue.nl
+   Copyright (C) 2000  Frederic Peters
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@
 #include "icons/stock_add.xpm"
 #include "icons/stock_remove.xpm"
 
+extern doublestring format_names[];
+
 typedef struct _main_update info1;
 typedef struct _edit_update info2;
 
@@ -91,11 +93,13 @@ p_entry_changed (GtkWidget * widget, info2 *info)
 }
 
 
-static void
-f_combo_changed (GtkWidget * widget, info2 *info)
+static void f_combo_changed (GtkWidget * widget, info2 *info)
 {
-  set_option(&info->loc->prop,"FORMAT", gtk_entry_get_text(GTK_ENTRY(widget)));
-  info->s->changed = TRUE;
+	set_option(&info->loc->prop, "FORMAT",
+			get_untranslated_string(
+				gtk_entry_get_text(GTK_ENTRY(widget)),
+				format_names));
+	info->s->changed = TRUE;
 }
 
 static void
@@ -123,47 +127,54 @@ rr_spin_changed (GtkWidget * widget, info2 *info)
   set_option(&info->loc->prop,"REREAD",buffer);
 }
 
-static void
-update_edit_window(GtkWidget *window, gpointer data)
+static void update_edit_window(GtkWidget *window, gpointer data)
 {
-  info2 *info;
-  gchar *temp;
-  info = data;
+	info2 *info;
+	gchar *temp;
+	GList *list_formats = NULL;
+	int i=0;
+	info = data;
 
-  gtk_entry_set_text(GTK_ENTRY(info->p_entry),info->loc->path);
+	gtk_entry_set_text(GTK_ENTRY(info->p_entry),info->loc->path);
 
-  gtk_signal_handler_block_by_func(GTK_OBJECT(GTK_COMBO(info->f_combo)->entry),
+	gtk_signal_handler_block_by_func(GTK_OBJECT(GTK_COMBO(info->f_combo)->entry),
 			f_combo_changed,info); 
- 
-  gtk_combo_set_popdown_strings(GTK_COMBO(info->f_combo),format);
 
-  if (get_option(&info->loc->prop,"FORMAT") == NULL)
-    {
-      set_option(&info->loc->prop,"FORMAT", g_list_first(format)->data);
-    }
+	while ( format_names[i++].name ) {
+		list_formats = g_list_append(list_formats, format_names[i-1].locale);
+	}
+	gtk_combo_set_popdown_strings(GTK_COMBO(info->f_combo), list_formats);
+	g_list_free(list_formats);
 
-  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(info->f_combo)->entry),
-				get_option(&info->loc->prop,"FORMAT"));
- 
-  gtk_signal_handler_unblock_by_func(
-	GTK_OBJECT(GTK_COMBO(info->f_combo)->entry), f_combo_changed,info); 
- 
-  temp = get_option(&info->loc->prop,"READONLY");
-  if (temp == NULL)
-    {
-      set_option(&info->loc->prop,"READONLY","FALSE");
-      temp = "FALSE";
-    }
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(info->ro_check),
-		strcmp(temp,"FALSE")==0 ? FALSE:TRUE);
+	if (get_option(&info->loc->prop,"FORMAT") == NULL)
+	{
+		set_option(&info->loc->prop,"FORMAT", format_names[0].name);
+	}
 
-  temp = get_option(&info->loc->prop,"REREAD");
-  if (temp == NULL)
-    {
-      set_option(&info->loc->prop,"REREAD","0");
-      temp = "0";
-    }
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(info->rr_spin),atoi(temp));
+	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(info->f_combo)->entry),
+				get_translated_string(
+					get_option(&info->loc->prop,"FORMAT"),
+					format_names));
+
+	gtk_signal_handler_unblock_by_func(
+			GTK_OBJECT(GTK_COMBO(info->f_combo)->entry), f_combo_changed,info); 
+
+	temp = get_option(&info->loc->prop,"READONLY");
+	if (temp == NULL)
+	{
+		set_option(&info->loc->prop,"READONLY","FALSE");
+		temp = "FALSE";
+	}
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(info->ro_check),
+			strcmp(temp,"FALSE")==0 ? FALSE:TRUE);
+
+	temp = get_option(&info->loc->prop,"REREAD");
+	if (temp == NULL)
+	{
+		set_option(&info->loc->prop,"REREAD","0");
+		temp = "0";
+	}
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(info->rr_spin),atoi(temp));
 
 }
 
@@ -348,7 +359,7 @@ destroy (GtkWidget * widget, info1 *info)
 
   if (info == NULL)
   {
-     g_print("ERror in destroy info\n");
+     debug_print("ERror in destroy info\n");
   }
 
   s = info->s; 
