@@ -1,7 +1,7 @@
 /*
    Misc window
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1998  Ron Bessems
    Contact me via email at R.E.M.W.Bessems@stud.tue.nl
 
@@ -137,7 +137,7 @@ edit_destroy (GtkWidget * widget, info2 *info)
   }
   else
   {
-    g_print("AAAAH CRITICAL i will crash within 2 clicks.\n");
+    debug_print("AAAAH CRITICAL i will crash within 2 clicks.\n");
     return;
   }
   update_all(); 
@@ -403,7 +403,7 @@ update_combo2(GtkWidget *window, gpointer data)
 
       if (stab->viewable_as == NULL)
        {
-         g_print("AHHH viewable_as == NULL \n");
+         debug_print("AHHH viewable_as == NULL \n");
 	 return;
        }
 
