@@ -1,9 +1,9 @@
 /*
    Loads'o stuff waiting for a better place to be put in
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1998  Ron Bessems
-   Contact me via email at R.E.M.W.Bessems@stud.tue.nl
+   Copyright (C) 2000  Frederic Peters
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -791,6 +791,32 @@ is_subfield_uniq(gchar *name, GList *subfields)
 }
 
 
+char* get_untranslated_string(char *string, doublestring *table)
+{
+	int i=0;
+	
+	printf("Looking for %s\n", string);
+	while ( table[i].name ) {
+		printf("strcmp'ing with %s\n", table[i].locale);
+		if ( strcmp(table[i].locale, string) == 0 )
+			return table[i].name;
+		printf("   -> failed\n");
+		i++;
+	}
 
+	return NULL;
+}
 
+char* get_translated_string(char *string, doublestring *table)
+{
+	int i=0;
+	
+	while ( table[i].name ) {
+		if ( strcmp(table[i].name, string) == 0 )
+			return _(table[i].locale);
+		i++;
+	}
+
+	return NULL;
+}
 
