@@ -1,7 +1,7 @@
 /*
    subField properties window
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1998  Ron Bessems
    Contact me via email at R.E.M.W.Bessems@stud.tue.nl
 
@@ -639,7 +639,8 @@ void
 		      GTK_SIGNAL_FUNC (delete_name_clicked), info);
 
 #ifdef GABY_KNOWS_I18NDESCS
-  /* TODO: apply the info structure  */
+  /* TODO (post-2.0): apply the info structure 
+   * delayed since it is not my code and it does not look critical :) */
   frame = gtk_frame_new (NULL);
   gtk_frame_set_label (GTK_FRAME (frame), _ ("I18N Description"));
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
