@@ -1,9 +1,9 @@
 /*
    Sub Fields window
 
-   Gaby Description Builder
+   Gaby Databases Builder
    Copyright (C) 1999  Ron Bessems
-   Contact me via email at R.E.M.W.Bessems@stud.tue.nl
+   Copyright (C) 2000  Frederic Peters
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
  */
 
 
-
 #include "main.h"
 #include "icons/ja.xpm"
 #include "icons/edit.xpm"
@@ -41,6 +40,8 @@
 #define DEBUG
 #endif
 
+extern doublestring view_names[];
+
 static GtkAccelGroup *accel;
 
 
@@ -74,7 +75,7 @@ remove_all_clicked (GtkWidget * widget, info1 *info)
 
   if (stab == NULL)
     {
-      g_print ("Warning unexpected NULL pointer\n");
+      debug_print ("Warning unexpected NULL pointer\n");
       return;
     }
   stab->subfields = free_subfields (stab->subfields);
@@ -103,7 +104,7 @@ add_all_clicked (GtkWidget * widget, info1 *info)
 
   if (stab == NULL || table == NULL)
     {
-      g_print ("Warning unexpected NULL pointer\n");
+      debug_print ("Warning unexpected NULL pointer\n");
       return;
     }
 
@@ -290,7 +291,7 @@ check_clicked (GtkWidget * but, info1 *info)
 
   if (stab == NULL)
     {
-      g_print ("Unexpected NULL pointer\n");
+      debug_print ("Unexpected NULL pointer\n");
       return;
     }
 
@@ -343,8 +344,8 @@ combo_changed (GtkWidget * widget, info1 *info)
   gchar *table;
   subtable *stab;
   GtkWidget *window;
-#ifdef DEBUG_GABY
-  g_print ("In combo func\n");
+#ifdef DEBUG
+  debug_print ("In combo func\n");
 #endif 
   window = info->window;
   table = gtk_entry_get_text (GTK_ENTRY (widget));
@@ -470,8 +471,8 @@ update_subfieldwin (GtkWidget * window, gpointer data)
   GdkColor color;
   GdkColormap *colormap;
 
-#ifdef DEBUG_GABY
-  g_print("Updating subfield window\n");
+#ifdef DEBUG
+  debug_print("Updating subfield window\n");
 #endif
 
 
@@ -516,8 +517,8 @@ update_subfieldwin (GtkWidget * window, gpointer data)
 
   if (foundtab == NULL)
     {
-#ifdef DEBUG_GABY
-      g_print ("Cannot find requested table\n");
+#ifdef DEBUG
+      debug_print ("Cannot find requested table\n");
 #endif
       loop = g_list_first (s->tables);
       if (loop != NULL)
@@ -525,8 +526,8 @@ update_subfieldwin (GtkWidget * window, gpointer data)
 
       if (foundtab == NULL)
       {
-#ifdef DEBUG_GABY
-        g_print("Warning no tables left !!!! subtable win no good!\n");
+#ifdef DEBUG
+        debug_print("Warning no tables left !!!! subtable win no good!\n");
 #endif
         return;
       }
@@ -577,8 +578,8 @@ update_subfieldwin (GtkWidget * window, gpointer data)
 	}
       if (in == FALSE)
 	{
-#ifdef DEBUG_GABY
-	  g_print ("Name fieldlist :%s\n", fld->name);
+#ifdef DEBUG
+	  debug_print ("Name fieldlist :%s\n", fld->name);
 #endif
 	  row = gtk_clist_append (GTK_CLIST (info->fieldlist), &fld->name);
 	  gtk_clist_set_row_data (GTK_CLIST (info->fieldlist), row, fld);
@@ -666,10 +667,10 @@ create_subfield_window (subtable *tab, file_s *s, gchar * caption)
   GtkWidget *addright;
   GtkWidget *addleft;
   GtkWidget *checkbox;
-  GList *loop;
   info1 *info;
   gchar buffer[1000];
   gint key;
+  int i;
 
 
   if (tab->window != NULL)
@@ -865,20 +866,18 @@ create_subfield_window (subtable *tab, file_s *s, gchar * caption)
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
 
-  loop = viewable_as;
-  loop = g_list_first (loop);
-  while (loop != NULL)
-    {
-      checkbox = gtk_check_button_new_with_label (loop->data);
+  i = 0;
+  while ( view_names[i].name ) {
+      checkbox = gtk_check_button_new_with_label(_(view_names[i].locale));
       gtk_box_pack_start (GTK_BOX (vbox), checkbox, FALSE, TRUE, 0);
       gtk_widget_show (checkbox);
-      gtk_object_set_user_data (GTK_OBJECT (checkbox), loop->data);
-      if (is_viewable (tab->viewable_as, loop->data) == TRUE)
+      gtk_object_set_user_data (GTK_OBJECT (checkbox), view_names[i].name);
+      if (is_viewable (tab->viewable_as, view_names[i].name) == TRUE)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), TRUE);
 
       gtk_signal_connect (GTK_OBJECT (checkbox), "clicked",
 			  GTK_SIGNAL_FUNC (check_clicked), info);
-      loop = loop->next;
+      i++;
     }
 
 
