@@ -23,7 +23,8 @@
 
 /* actions: mail phone dtmfdial */
 
-#define DEFAULT_EMAIL_CMD		"xterm -e mutt \"$e\""
+/*#define DEFAULT_EMAIL_CMD		"xterm -e mutt \"$e\""*/
+#define DEFAULT_EMAIL_CMD		""
 #define DEFAULT_PHONE_CMD		"dtmfdial $p"
 #define DEFAULT_COUNTRY_CODE		""
 #define DEFAULT_AREA_CODE		""
@@ -82,7 +83,7 @@ mstatic void net_mail (struct action_param param[3], int *dec)
 	memcpy(&fields[1], &param[1].val, sizeof(union data));
 	memcpy(&fields[2], &param[2].val, sizeof(union data));
 	
-	/* TODO : different sorts of e-mail address formatting */
+	/* WISHLIST: different sorts of e-mail address formatting */
 	if ( fields[0].str != NULL && fields[0].str->str[0] != 0 ) {
 		st = g_string_append(st, fields[0].str->str);
 		st = g_string_append(st, " ");
@@ -110,13 +111,24 @@ mstatic void net_mail (struct action_param param[3], int *dec)
 #endif
 	
 	str = get_config_str("actions", "net", "cmd_email", DEFAULT_EMAIL_CMD);
+	if ( strlen(str) == 0 ) {
+		GtkWidget *a = configure_dialog(_("Net"));
+		if ( a ) gtk_widget_show(a);
+		gaby_message = g_strdup(
+			_("The command to send mails was not specified.\n"
+			  "You should enter it in the Preferences dialog."));
+		gaby_errno = CUSTOM_WARNING;
+		gaby_perror_in_a_box();
+		(*dec)--;
+		return;
+	}
 
 #ifdef DEBUG_GABY
 	debug_print("[action:mailto] using %s\n", str);
 #endif
 	if ( strstr(str, "$e") == NULL ) {
-		sprintf(cmd,_("The command for sending e-mail (%s) does not "\
-			     "have \"$e\" in it, which is the way to tell it "\
+		sprintf(cmd,_("The command for sending e-mail (%s) does not "
+			     "have \"$e\" in it, which is the way to tell it "
 			     "what is the address you want to mail to."), str);
 		g_free(str);
 		g_string_free(st, 1);
@@ -181,7 +193,7 @@ static gboolean create_phone_number(gchar *res, gchar *str)
 
 	/* and now the real stuff ... */
 	
-	i18n_code = get_config_str("actions", "net", "international_code", \
+	i18n_code = get_config_str("actions", "net", "international_code", 
 						DEFAULT_INTERNATIONAL_CODE );
 	cur_res = res;
 	if ( str[0] == '+' ) {
@@ -196,11 +208,11 @@ static gboolean create_phone_number(gchar *res, gchar *str)
 	}
 	*cur_res = 0;
 	
-	ld_code = get_config_str("actions", "net","long_distance_code", \
+	ld_code = get_config_str("actions", "net","long_distance_code", 
 						DEFAULT_LONG_DISTANCE_CODE );
 	
 	if ( strncmp(res, i18n_code, strlen(i18n_code)) == 0) {
-		country_code = get_config_str("actions", "net", \
+		country_code = get_config_str("actions", "net", 
 				"country_code", DEFAULT_COUNTRY_CODE);
 		if ( strlen(country_code) == 0 ) {
 #ifdef DEBUG_GABY
@@ -216,10 +228,10 @@ static gboolean create_phone_number(gchar *res, gchar *str)
 			gaby_perror_in_a_box();
 #endif
 		}
-		if ( strncmp(res+strlen(i18n_code), country_code, \
+		if ( strncmp(res+strlen(i18n_code), country_code, 
 					strlen(country_code)) == 0 ) {
-			memmove(res + strlen(ld_code), \
-				res + strlen(i18n_code) + strlen(country_code),\
+			memmove(res + strlen(ld_code), 
+				res + strlen(i18n_code) + strlen(country_code),
 				strlen(res)-strlen(ld_code));
 			memcpy(res, ld_code, strlen(ld_code));
 		} else {
@@ -236,7 +248,7 @@ static gboolean create_phone_number(gchar *res, gchar *str)
 	g_free(i18n_code);
 
 	if ( strncmp(res, ld_code, strlen(ld_code)) == 0) {
-		area_code = get_config_str("actions", "net", "area_code", \
+		area_code = get_config_str("actions", "net", "area_code", 
 							DEFAULT_AREA_CODE );
 		if ( strlen(area_code) == 0 ) {
 #ifdef DEBUG_GABY
@@ -247,10 +259,10 @@ static gboolean create_phone_number(gchar *res, gchar *str)
 			gaby_perror_in_a_box();
 		}
 
-		if ( strncmp(res+strlen(ld_code), area_code, \
+		if ( strncmp(res+strlen(ld_code), area_code, 
 					strlen(area_code)) == 0 ) {
-			memmove(res, \
-				res + strlen(ld_code) + strlen(area_code),\
+			memmove(res, 
+				res + strlen(ld_code) + strlen(area_code),
 				strlen(res));
 		}
 		g_free(area_code);
@@ -264,27 +276,27 @@ static gboolean create_phone_number(gchar *res, gchar *str)
 	return TRUE;
 }
 
-static void dlg_destroyed_cb(GtkWidget *dlg, int *dec)
-{
-#ifdef DEBUG_GABY
-	debug_print("dlg : %p\n", dlg);
-#endif
-	(*dec)--;
-}
-
-static void phone_reply_cb(gint reply, void *ptr[2])
+static void phone_reply_cb(gint reply, void **ptr)
 {
 	gchar *str;
 	gchar *number;
 	int *dec;
 	char cmd[1000];
+	char *s;
+	GString *st;
 	
 	dec = ptr[0];
 	number = ptr[1];
+	g_free(ptr);
 #ifdef DEBUG_GABY
 	debug_print("reply : %d\n", reply);
 #endif
-	/* if yes : phone to ..., else : ask the user to correct the number */
+	if ( reply != 0 ) {
+		g_free(number);
+		(*dec)--;
+		/* TODO (post-2.0) ask the user to correct the number */
+		return;
+	}
 	
 	str = get_config_str("actions", "net", "cmd_phone", DEFAULT_PHONE_CMD);
 	
@@ -292,20 +304,35 @@ static void phone_reply_cb(gint reply, void *ptr[2])
 	debug_print("str : %s\n", str);
 #endif
 	if ( strstr(str, "$p") == NULL ) {
-		sprintf(cmd,_("The command to use for phone numbers (%s) does "\
-			      "not have \"$p\" in it,\n which is the way to "\
+		sprintf(cmd,_("The command to use for phone numbers (%s) does "
+			      "not have \"$p\" in it,\n which is the way to "
 			      "tell it what is the phone number you want."),
 				str);
-		g_free(str);
 		gaby_errno = CUSTOM_ERROR;
 		gaby_message = g_strdup(cmd);
+		g_free(number);
+		g_free(str);
+		(*dec)--;
 		return;
 	}
+	
+	s = strstr(str, "$p"); s[0] = 0; s[1] = 0;
 
-	system(str);
+	st = g_string_new("");
+	st = g_string_append(st, number);
+	st = g_string_prepend(st, str);
+	st = g_string_append(st, str+strlen(str)+2);
+	
+	strcpy(cmd, st->str);
+	g_string_free(st, 1);
 
+	debug_print("Executing: %s\n", cmd);
+	system(cmd);
+
+	g_free(number);
 	g_free(str);
 
+	(*dec)--;
 }
 
 /**
@@ -318,10 +345,10 @@ static void phone_reply_cb(gint reply, void *ptr[2])
 mstatic void net_phone (struct action_param param[1], int *dec)
 {
 	union data fields[1];
-	char number[100];
+	gchar *number;
 	char question[1000];
 	GtkWidget *dlg;
-	void *ptr[2];
+	void **ptr;
 	
 	memcpy(&fields[0], &param[0].val, sizeof(union data));
 	
@@ -336,24 +363,23 @@ mstatic void net_phone (struct action_param param[1], int *dec)
 	debug_print("the phone number is %s\n", fields[0].str->str);
 #endif
 
+	number = g_malloc(100);
 	create_phone_number(number, fields[0].str->str);
 
 #ifdef DEBUG_GABY
 	debug_print("and I translated it to %s\n", number);
 #endif
-
-	sprintf(question, _("Is %s correct ?"), number );
-#ifdef USE_GNOME
+	
+	ptr = g_malloc(sizeof(void*)*2);
 	ptr[0] = dec;
 	ptr[1] = number;
-	dlg = gnome_question_dialog(question, \
+
+#ifdef USE_GNOME
+	sprintf(question, _("Is %s correct ?"), number );
+	dlg = gnome_question_dialog(question,
 			(GnomeReplyCallback)phone_reply_cb, ptr);
-#ifdef DEBUG_GABY
-	debug_print("dlg : %p\n", dlg);
-#endif
-	gtk_signal_connect(GTK_OBJECT(dlg), "destroy", dlg_destroyed_cb, dec);
 #else
-	(*dec)--;
+	phone_reply_cb(0, ptr);
 #endif
 }
 
@@ -375,7 +401,7 @@ GtkWidget* configure()
 	GtkWidget *table_email,
 		  *table_phone;
 	GtkWidget *label;
-	GtkWidget *entry_cmd_email;
+	GtkWidget *combo_cmd_email, *entry_cmd_email;
 	GtkWidget *om_format, *om_format_menu, *menuitem;
 	GtkWidget *entry_cmd_phone,
 		  *entry_country,
@@ -388,9 +414,9 @@ GtkWidget* configure()
 					/* or sth like mail&phone ?*/
 #if 0
 	if ( configure_widget && configure_widget->window ) {
-		entry_cmd_email = gtk_object_get_data( \
+		entry_cmd_email = gtk_object_get_data( 
 				GTK_OBJECT(configure_widget), "cmd_email");
-		str = get_config_str("actions", "net", "cmd_email", \
+		str = get_config_str("actions", "net", "cmd_email", 
 				DEFAULT_EMAIL_CMD);
 #ifdef DEBUG_GABY
 		debug_print("[actions:net:cfg] resetting cmd_email to %s\n", str);
@@ -403,11 +429,11 @@ GtkWidget* configure()
 #endif
 	
 	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(vbox), "destroy_event", \
+	gtk_signal_connect(GTK_OBJECT(vbox), "destroy_event", 
 			destroy_configure_event, &configure_widget);
 	gtk_widget_show(vbox);
 
-	frame = gtk_frame_new("E-Mail");
+	frame = gtk_frame_new(_("E-Mail"));
 	gtk_widget_show(frame);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 0);
 	gtk_container_border_width(GTK_CONTAINER(frame), 5);
@@ -419,25 +445,43 @@ GtkWidget* configure()
 	gtk_table_set_row_spacings(GTK_TABLE(table_email), 7);
 	gtk_table_set_col_spacings(GTK_TABLE(table_email), 5);
 
-	label = gtk_label_new("Command to execute :");
+	label = gtk_label_new(_("Command to execute :"));
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table_email), label, 0, 1, 0, 1,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
-	entry_cmd_email = gtk_entry_new();
+	combo_cmd_email = gtk_combo_new();
+	{
+		char *cmd[] = {
+			"mozilla -mail mailto:\"$e\"",
+			"xterm -e mutt \"$e\"",
+			NULL
+		};
+		int i=0;
+		GList *strings = NULL;
+		while ( cmd[i] ) {
+			strings = g_list_append(strings, cmd[i]);
+			i++;
+		}
+		gtk_combo_set_popdown_strings(GTK_COMBO(combo_cmd_email),
+								strings);
+		g_list_free(strings);
+	}
+		
+	entry_cmd_email = GTK_COMBO(combo_cmd_email)->entry;
 	str = get_config_str("actions", "net", "cmd_email", DEFAULT_EMAIL_CMD);
 	gtk_object_set_data(GTK_OBJECT(vbox), "cmd_email", entry_cmd_email);
 	gtk_entry_set_text(GTK_ENTRY(entry_cmd_email), str);
 	g_free(str);
-	gtk_signal_connect(GTK_OBJECT(entry_cmd_email), "changed", \
+	gtk_signal_connect(GTK_OBJECT(entry_cmd_email), "changed", 
 			GTK_SIGNAL_FUNC(gaby_property_box_changed), vbox);
-	gtk_widget_show(entry_cmd_email);
-	gtk_table_attach(GTK_TABLE(table_email), entry_cmd_email, 1, 2, 0, 1,
+	gtk_widget_show(combo_cmd_email);
+	gtk_table_attach(GTK_TABLE(table_email), combo_cmd_email, 1, 2, 0, 1,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
-	label = gtk_label_new("Address format :");
+	label = gtk_label_new(_("Address format :"));
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table_email), label, 0, 1, 1, 2,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
@@ -461,7 +505,7 @@ GtkWidget* configure()
 	gtk_menu_append(GTK_MENU(om_format_menu), menuitem);
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(om_format), om_format_menu);
 
-	frame = gtk_frame_new("Phone");
+	frame = gtk_frame_new(_("Phone"));
 	gtk_widget_show(frame);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 0);
 	gtk_container_border_width(GTK_CONTAINER(frame), 5);
@@ -473,7 +517,7 @@ GtkWidget* configure()
 	gtk_table_set_row_spacings(GTK_TABLE(table_phone), 5);
 	gtk_table_set_col_spacings(GTK_TABLE(table_phone), 5);
 
-	label = gtk_label_new("Command to execute :");
+	label = gtk_label_new(_("Command to execute :"));
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table_phone), label, 0, 1, 0, 1,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
@@ -489,14 +533,14 @@ GtkWidget* configure()
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 	
-	label = gtk_label_new("Country code :");
+	label = gtk_label_new(_("Country code :"));
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table_phone), label, 0, 1, 1, 2,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
 	entry_country = gtk_entry_new();
-	str = get_config_str("actions", "net", "country_code", \
+	str = get_config_str("actions", "net", "country_code", 
 						DEFAULT_COUNTRY_CODE);
 	gtk_object_set_data(GTK_OBJECT(vbox), "country_code", entry_country);
 	gtk_entry_set_text(GTK_ENTRY(entry_country), str);
@@ -506,14 +550,14 @@ GtkWidget* configure()
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
-	label = gtk_label_new("Area code :");
+	label = gtk_label_new(_("Area code :"));
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table_phone), label, 0, 1, 2, 3,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
 	entry_area = gtk_entry_new();
-	str = get_config_str("actions", "net", "area_code", \
+	str = get_config_str("actions", "net", "area_code", 
 						DEFAULT_AREA_CODE);
 	gtk_object_set_data(GTK_OBJECT(vbox), "area_code", entry_area);
 	gtk_entry_set_text(GTK_ENTRY(entry_area), str);
@@ -523,14 +567,14 @@ GtkWidget* configure()
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
-	label = gtk_label_new("Prefix for long distance calls :");
+	label = gtk_label_new(_("Prefix for long distance calls :"));
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table_phone), label, 0, 1, 3, 4,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
 	entry_ldc = gtk_entry_new();
-	str = get_config_str("actions", "net", "long_distance_code", \
+	str = get_config_str("actions", "net", "long_distance_code", 
 						DEFAULT_LONG_DISTANCE_CODE);
 	gtk_object_set_data(GTK_OBJECT(vbox), "long_distance_code", entry_ldc);
 	gtk_entry_set_text(GTK_ENTRY(entry_ldc), str);
@@ -540,14 +584,14 @@ GtkWidget* configure()
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
-	label = gtk_label_new("Prefix for international calls :");
+	label = gtk_label_new(_("Prefix for international calls :"));
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table_phone), label, 0, 1, 4, 5,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
 	entry_ic = gtk_entry_new();
-	str = get_config_str("actions", "net", "international_code", \
+	str = get_config_str("actions", "net", "international_code", 
 						DEFAULT_INTERNATIONAL_CODE);
 	gtk_object_set_data(GTK_OBJECT(vbox), "international_code", entry_ic);
 	gtk_entry_set_text(GTK_ENTRY(entry_ic), str);
@@ -578,7 +622,7 @@ static void configure_save()
 	st = gtk_entry_get_text(entry);
 	write_config_str("actions", "net", "cmd_phone", st );
 	
-	entry = gtk_object_get_data(GTK_OBJECT(configure_widget), \
+	entry = gtk_object_get_data(GTK_OBJECT(configure_widget), 
 							"country_code");
 	st = gtk_entry_get_text(entry);
 	write_config_str("actions", "net", "country_code", st );
@@ -587,12 +631,12 @@ static void configure_save()
 	st = gtk_entry_get_text(entry);
 	write_config_str("actions", "net", "area_code", st );
 	
-	entry = gtk_object_get_data(GTK_OBJECT(configure_widget), \
+	entry = gtk_object_get_data(GTK_OBJECT(configure_widget), 
 							"long_distance_code");
 	st = gtk_entry_get_text(entry);
 	write_config_str("actions", "net", "long_distance_code", st );
 	
-	entry = gtk_object_get_data(GTK_OBJECT(configure_widget), \
+	entry = gtk_object_get_data(GTK_OBJECT(configure_widget), 
 							"international_code");
 	st = gtk_entry_get_text(entry);
 	write_config_str("actions", "net", "international_code", st );
@@ -606,7 +650,7 @@ static void configure_save()
  *
  * Use and redistribution are subject to the GNU GENERAL PUBLIC LICENSE.
  *
- * Modified by Frederic Peters (fpeters@win.be) to work as a gaby
+ * Modified by Frederic Peters (fpeters@tiscalinet.be) to work as a gaby
  * action.
  */
 
@@ -746,9 +790,9 @@ mstatic void net_dtmfdial(struct action_param param[1], int *dec)
 			silent(DTMF_SLEEP_TIME, &bufidx, buf, &dialed,fd);
 		else {
 			if(dialed)
-				silent(DTMF_SILENT_TIME, &bufidx, buf,\
+				silent(DTMF_SILENT_TIME, &bufidx, buf,
 						&dialed, fd);
-			dial_digit(*cp, &speed, costab, buf, &bufidx,\
+			dial_digit(*cp, &speed, costab, buf, &bufidx,
 					fd, &dialed);
 		}
 		cp++;
@@ -766,67 +810,67 @@ static void dial_digit(int c, int *speed, signed short *costab,
 		       unsigned char *buf, int *bufidx, int fd, int *dialed) {
 	switch(c) {
 		case '0':
-			dial(941, 1336, DTMF_TONE_TIME, speed, \
+			dial(941, 1336, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case '1':
-			dial(697, 1209, DTMF_TONE_TIME, speed, \
+			dial(697, 1209, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 		break;
 		case '2':
-			dial(697, 1336, DTMF_TONE_TIME, speed, \
+			dial(697, 1336, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case '3':
-			dial(697, 1477, DTMF_TONE_TIME, speed, \
+			dial(697, 1477, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 		break;
 		case '4':
-			dial(770, 1209, DTMF_TONE_TIME, speed, \
+			dial(770, 1209, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case '5':
-			dial(770, 1336, DTMF_TONE_TIME, speed, \
+			dial(770, 1336, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case '6':
-			dial(770, 1477, DTMF_TONE_TIME, speed, \
+			dial(770, 1477, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case '7':
-			dial(852, 1209, DTMF_TONE_TIME, speed, \
+			dial(852, 1209, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case '8':
-			dial(852, 1336, DTMF_TONE_TIME, speed, \
+			dial(852, 1336, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case '9':
-			dial(852, 1477, DTMF_TONE_TIME, speed, \
+			dial(852, 1477, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case '*':
-			dial(941, 1209, DTMF_TONE_TIME, speed, \
+			dial(941, 1209, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 		break;
 		case '#':
-			dial(941, 1477, DTMF_TONE_TIME, speed, \
+			dial(941, 1477, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case 'A':
-			dial(697, 1633, DTMF_TONE_TIME, speed, \
+			dial(697, 1633, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case 'B':
-			dial(770, 1633, DTMF_TONE_TIME, speed, \
+			dial(770, 1633, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case 'C':
-			dial(852, 1633, DTMF_TONE_TIME, speed, \
+			dial(852, 1633, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 		case 'D':
-			dial(941, 1633, DTMF_TONE_TIME, speed, \
+			dial(941, 1633, DTMF_TONE_TIME, speed, 
 					costab, buf, bufidx, fd, dialed);
 			break;
 	}
