@@ -1,16 +1,20 @@
 
 from gtk import *
 
+
 # simple test function
-hello_world ();
+gaby.hello_world ();
 
 def ok_clicked(*args):
 	win.destroy()
 
 	# retrieving a record
-win = get_current_window()
+win = gaby.get_current_window()
 record = win.subtable.get_record_no(win.id)
 
+mainw = GtkWindow(_obj = win.gtkwindow)
+mainw.set_title('My title was cracked by evil Python script kiddies!')
+
 win = GtkWindow()
 win.set_title('Hello from Python/GTK+')	
 box = GtkVBox()
