@@ -1,3 +1,4 @@
+# /usr/bin/gabyscript --as gaby --interpreter python
 # Interpreter: python
 # Descfiles: gaby
 # Description: Sets the country field of every records
@@ -5,7 +6,7 @@
 # This script sets the country fields of every records to 'Belgium' if no
 # country was previously given.
 
-subtable = get_subtable_by_name('Address Book')
+subtable = gbay.get_subtable_by_name('Address Book')
 field_number = subtable.dict_fields['Country']
 
 for i in subtable.fast_records_list():
