@@ -16,9 +16,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#define NO_GUI
+#include <config.h>
+
+#ifndef NO_GUI
+#  define NO_GUI
+#endif
+
 #include <gaby.h>
 #include <tables.h>
-#include <config.h>
 #include <records.h>
 
