@@ -1,5 +1,5 @@
 /*  Gaby
- *  Copyright (C) 1998-1999 Frederic Peters
+ *  Copyright (C) 1998-2000 Frederic Peters
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,16 +21,28 @@
 #include <records.h>
 #include <files.h>
 #include <windows.h>	/* for update_bound_windows */
+#include <print_plg.h>
 
 #ifdef NO_GUI
 #  include <nogui_main.h>
 #else
+#  include <gtk_print_dlg.h>
 #  include <gtk_main.h>	/* for new_view_create */
 #  include <gtk_menu.h>	/* for gaby_quit */
 #endif
 
 #include <Python.h>
 
+#ifdef HAVE_PYGTK
+#include <pygtk/pygtk.h>
+#endif
+
+#ifdef HAVE_LIBGLADE
+#include <glade/glade.h>
+#endif
+
+static PyObject *gaby_module;
+
 typedef struct {
 	PyObject_HEAD
 	gabywindow *win;
@@ -53,9 +65,7 @@ static PyObject* PyGabyWindow_New(gabywindow *win)
 	PyGabyWindow_Object *self;
 
 	self = (PyGabyWindow_Object*)PyObject_NEW(PyGabyWindow_Object, &PyGabyWindow_Type);
-#ifdef DEBUG_GABY
 	debug_print("[PyGabyWindow_New] self : %p\n", self);
-#endif
 	if ( self == NULL )
 		return NULL;
 	self->win = win;
@@ -75,7 +85,7 @@ static int PyGabyWindow_print(PyGabyWindow_Object *self, FILE *f, int flags)
 	win = self->win;
 	v = win->view;
 			
-	fprintf(f, "GabyWindow, showing the subtable '%s' using the view '%s'",
+	fprintf(f,"<GabyWindow, showing the subtable '%s' using the view '%s'>",
 			v->subtable->name, v->type->name );
 	return 0;
 }
@@ -88,6 +98,7 @@ static PyObject* py_win_destroy(PyObject *self, PyObject *args);
 static PyObject* py_win_add_bound_window(PyObject *self, PyObject *args);
 static PyObject* py_win_remove_bound_window(PyObject *self, PyObject *args);
 static PyObject* py_win_set_records_list(PyObject *self, PyObject *args);
+static PyObject* py_win_get_widget(PyObject *self, PyObject *args);
 
 static PyMethodDef window_methods[] = {
 	{ "move",		(PyCFunction)py_win_move, 1 },
@@ -96,6 +107,7 @@ static PyMethodDef window_methods[] = {
 	{ "add_bound_window",	(PyCFunction)py_win_add_bound_window, 1 },
 	{ "remove_bound_window",(PyCFunction)py_win_remove_bound_window, 1 },
 	{ "set_records_list",	(PyCFunction)py_win_set_records_list, 1 },
+	{ "get_widget",		(PyCFunction)py_win_get_widget, 1 },
 	{ NULL,			NULL }
 };
 
@@ -104,6 +116,7 @@ static PyMethodDef window_methods[] = {
  *
  * Description:
  * This method moves the window to (i, i) (respectively x and y)
+ * OBSOLETE!: use gtk methods on window.gtkwindow
  **/
 static PyObject* py_win_move(PyObject *self, PyObject *args)
 {
@@ -129,6 +142,7 @@ static PyObject* py_win_move(PyObject *self, PyObject *args)
  *
  * Description:
  * This method resizes the window to (i, i) (respectively width and height)
+ * OBSOLETE!: use gtk methods on window.gtkwindow
  **/
 static PyObject* py_win_resize(PyObject *self, PyObject *args)
 {
@@ -190,7 +204,7 @@ static PyObject* py_win_add_bound_window(PyObject *self, PyObject *args)
 	
 	bound_windows = win1->bound_windows;
 	if ( g_list_find(bound_windows, win2) == NULL ) {
-		win1->bound_windows = g_list_append ( \
+		win1->bound_windows = g_list_append ( 
 				win1->bound_windows, win2 );
 	}
 
@@ -216,7 +230,7 @@ static PyObject* py_win_remove_bound_window(PyObject *self, PyObject *args)
 	
 	bound_windows = win1->bound_windows;
 	if ( g_list_find(bound_windows, win2) != NULL ) {
-		win1->bound_windows = g_list_remove( \
+		win1->bound_windows = g_list_remove( 
 						win1->bound_windows, win2);
 	}
 
@@ -277,6 +291,45 @@ static PyObject* py_win_set_records_list(PyObject *self, PyObject *args)
 	return Py_None;
 }
 
+/**
+ * <window>.get_widget(s)
+ *
+ * Description:
+ * This method returns the GUI widget (actually a GtkObject) matching the
+ * given string. The strings you can give depends upon the used view.
+ **/
+static PyObject* py_win_get_widget(PyObject *self, PyObject *args)
+{
+#ifndef HAVE_PYGTK
+	return Py_None;
+#else /* HAVE_PYGTK */
+	char *str;
+	GtkWidget *wid;
+	gabywindow *win;
+	ViewPluginData *vpd;
+	PyObject *ob;
+	
+	if ( ! PyArg_ParseTuple(args, "s", &str)) {
+		PyErr_SetString(PyExc_TypeError, 
+			"get_widget() requires 1 argument (string)");
+		return NULL;
+	}
+	
+	win = ((PyGabyWindow_Object*)self)->win;
+	vpd = win->view->type;
+	if ( vpd->view_get_widget == NULL ) {
+		puts("get_widget not implemented for this view");
+		return Py_None;
+	}
+	wid = vpd->view_get_widget(win, str);
+	
+	if ( wid == NULL ) return Py_None;
+	
+	ob = PyGtk_New(GTK_OBJECT(wid));
+	return ob;
+#endif
+}
+
 	/* Items */
 static PyObject *PyGabyWindow_getattr(PyGabyWindow_Object *self, char *name)
 {
@@ -330,7 +383,7 @@ static PyObject *PyGabyWindow_getattr(PyGabyWindow_Object *self, char *name)
 	 * this item holds the name of the window, as shown in its title bar
 	 **/
 	if ( strcmp(name, "name") == 0 ) {
-		return PyString_FromString(win->name);
+		return PyString_FromString( win->name ? win->name : "?" );
 	}
 
 	/**
@@ -343,6 +396,25 @@ static PyObject *PyGabyWindow_getattr(PyGabyWindow_Object *self, char *name)
 		/* this would need a specific attribute (FIXED) (optimally?) */
 		return PyInt_FromLong ( v->type->capabilities & FILTERABLE );
 	}
+
+#ifdef HAVE_PYGTK
+	/**
+	 * <window>.gtkwindow
+	 * Description:
+	 * this item holds a GtkWindow reprensenting the physical window itself
+	 **/
+
+	/*  this allows to use gtk functions on gaby windows (useful for move,
+	 *  resize, ...). move and resize are currently handled with {move,
+	 *  resize}_window but they are simple wrappers around gdk_window_{move,
+	 *  resize} but they are marked as obsolete
+	 */
+	if ( strcmp(name, "gtkwindow") == 0 ) {
+		PyObject *ob;
+		ob = PyGtk_New(GTK_OBJECT(win->parent));
+		return ob;
+	}
+#endif
 	
 	return Py_FindMethod(window_methods, (PyObject*)self, name);
 }
@@ -398,7 +470,7 @@ static int PyGabyWindow_setattr (PyGabyWindow_Object *self, char *name,
 				int j;
 				table *t = v->subtable->table;
 				for ( j=0; j < t->max_records; j++ ) {
-					if ( t->records[j] && \
+					if ( t->records[j] && 
 						t->records[j]->id == id )
 					{
 						id = j;
@@ -454,11 +526,9 @@ static PyObject* PyGabySubTable_New(subtable *st)
 {
 	PyGabySubTable_Object *self;
 
-	self = (PyGabySubTable_Object*)PyObject_NEW( \
+	self = (PyGabySubTable_Object*)PyObject_NEW( 
 				PyGabySubTable_Object, &PyGabySubTable_Type);
-#ifdef DEBUG_GABY
 	debug_print("[PyGabySubTable_New] self : %p\n", self);
-#endif
 	if ( self == NULL )
 		return NULL;
 	self->st = st;
@@ -474,13 +544,15 @@ static int PyGabySubTable_print(PyGabySubTable_Object *self, FILE *f, int flags)
 {
 	subtable *st;
 	st = self->st;
-	fprintf(f, "GabySubTable, name : %s, derived from table %s", \
+	fprintf(f, "<GabySubTable, name : %s, derived from table %s>",
 						st->name, st->table->name );
 	return 0;
 }
 
 	/* Methods */
 static PyObject* py_st_get_record_no(PyObject *self, PyObject *args);
+static PyObject* py_st_add_record(PyObject *self, PyObject *args);
+static PyObject* py_st_delete_record(PyObject *self, PyObject *args);
 static PyObject* py_st_set_record_no(PyObject *self, PyObject *args);
 static PyObject* py_st_fast_records_list(PyObject *self, PyObject *args);
 static PyObject* py_st_records_list(PyObject *self, PyObject *args);
@@ -493,6 +565,8 @@ static PyObject* py_st_save(PyObject *self, PyObject *args);
 
 static PyMethodDef subtable_methods[] = {
 	{ "get_record_no",	(PyCFunction)py_st_get_record_no, 1 },
+	{ "add_record",		(PyCFunction)py_st_add_record, 1 },
+	{ "delete_record",	(PyCFunction)py_st_delete_record, 1 },
 	{ "set_record_no",	(PyCFunction)py_st_set_record_no, 1 },
 	{ "get_first_record",	(PyCFunction)py_st_get_first_record, 1 },
 	{ "get_previous_record",(PyCFunction)py_st_get_previous_record, 1 },
@@ -557,13 +631,17 @@ static PyObject* py_st_get_record_no(PyObject *self, PyObject *args)
 			switch ( st->fields[i].type ) {
 				case T_INTEGER:
 				case T_BOOLEAN:
-					py_ob = PyInt_FromLong( (long) \
+					py_ob = PyInt_FromLong( (long)
 						r->cont[st->fields[i].no].i );
 					break;
 				case T_REAL:
-					py_ob = PyFloat_FromDouble( (double) \
+					py_ob = PyFloat_FromDouble( (double)
 						r->cont[st->fields[i].no].d );
 					break;
+				case T_DECIMAL:
+					py_ob = PyFloat_FromDouble( (double)
+						r->cont[st->fields[i].no].i / 100.0 );
+					break;
 				default: py_ob = NULL; /* this never happens */
 			}
 			if ( py_ob != NULL ) {
@@ -609,13 +687,65 @@ static PyObject* py_st_get_record_no(PyObject *self, PyObject *args)
 	return rec;
 }
 
+/**
+ * <subtable>.add_record(r)
+ *
+ * Description:
+ * This method adds the given record @r to the subtable. It returns the new
+ * record's id.
+ **/
+static PyObject* py_st_add_record(PyObject *self, PyObject *args)
+{
+	/* I miss good old Python way:
+	 * 	def add_record(r): return self.set_record_no(0,r)
+	 * sooo easier...
+	 */
+	PyObject *rec, *py_tuple;
+	
+	if ( ! PyArg_ParseTuple(args, "O", &rec)) return NULL;
+	
+	py_tuple = PyTuple_New(2);
+	PyTuple_SetItem(py_tuple, 0, PyInt_FromLong(0));
+	PyTuple_SetItem(py_tuple, 1, rec);
+	
+	return py_st_set_record_no(self, py_tuple);
+}
+
+/**
+ * <subtable>.delete_record(id)
+ *
+ * Description:
+ * This method removes the record whose id is @id from the subtable.
+ **/
+static PyObject* py_st_delete_record(PyObject *self, PyObject *args)
+{
+	/* I miss good old Python way:
+	 * 	def delete_record(id): return self.set_record_no(id, None)
+	 * sooo easier...
+	 */
+	/* note that I could tell to set_record_no that the second arg has a
+	 * default value == None but this would be cheating :) 
+	 * (I need correct type checking)
+	 */
+	PyObject *py_tuple;
+	int id;
+	
+	if ( ! PyArg_ParseTuple(args, "i", &id)) return NULL;
+	
+	py_tuple = PyTuple_New(2);
+	PyTuple_SetItem(py_tuple, 0, PyInt_FromLong(id));
+	PyTuple_SetItem(py_tuple, 1, Py_None);
+	
+	return py_st_set_record_no(self, py_tuple);
+}
+
 /**
  * <subtable>.set_record_no(i, r)
  * 
  * Description:
- * This methods sets the record whose id (or 'fast id') is i from the subtable
+ * This method sets the record whose id (or 'fast id') is i from the subtable
  * to the record (list of strings) r. If id is 0 then the record is added to
- * the table.
+ * the table. This method returns the _real_ id.
  *
  * Comment: it doesn't touch to 'Record' and 'Records' fields
  **/
@@ -637,6 +767,17 @@ static PyObject* py_st_set_record_no(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
+	if ( rec == Py_None ) { /* remove record */
+		debug_print("[st_set_record_no] removing record\n");
+		if ( id < 0 ) {
+			r = st->table->records[-id-1];
+			id = r->id;
+		}
+		record_remove_id(st->table, id);
+		
+		return Py_None;
+	}
+
 	if ( id == 0 ) { /* new record */
 		r = record_defaults(st->table);
 	} else {
@@ -652,32 +793,36 @@ static PyObject* py_st_set_record_no(PyObject *self, PyObject *args)
 	}
 
 	for ( i=0; i < st->nb_fields; i++ ) {
-		if ( st->fields[i].type == T_RECORD || 
-					st->fields[i].type == T_RECORDS )
+		if ( st->fields[i].type == T_RECORDS )
 			continue;
 
 		py_ob = PyList_GetItem(rec, i);
 		
 		if ( PyString_Check(py_ob) ) {
-			set_subtable_stringed_field(st, r, i, \
+			set_subtable_stringed_field(st, r, i, 
 					PyString_AsString(py_ob));
 		} else {
 			switch ( st->fields[i].type ) {
 				case T_INTEGER:
 				case T_RECORD:
 				{
-					/* FIXME: this is not cont[i]
-					 *  but st->fields[i].no */
-					if ( PyInt_Check(py_ob) || \
+					if ( PyInt_Check(py_ob) || 
 							PyLong_Check(py_ob)) {
-						r->cont[i].i = \
+						r->cont[st->fields[i].no].i = 
 							PyInt_AsLong(py_ob);
 					}
 				} break;
+				case T_DECIMAL:
+				{
+					if ( PyFloat_Check(py_ob) ) {
+						r->cont[i].i = 100.0 * 
+							PyFloat_AsDouble(py_ob);
+					}
+				}
 				case T_REAL:
 				{
 					if ( PyFloat_Check(py_ob) ) {
-						r->cont[i].d = \
+						r->cont[i].d = 
 							PyFloat_AsDouble(py_ob);
 					}
 				} break;
@@ -689,9 +834,10 @@ static PyObject* py_st_set_record_no(PyObject *self, PyObject *args)
 	if ( id == 0 ) {
 		if ( record_add(st->table, r, TRUE, TRUE ) == -1 ) {
 			record_free(st->table, r);
+			return NULL;
 		}
 	}
-	return Py_None;
+	return PyInt_FromLong( r->id );
 }
 
 /**
@@ -717,7 +863,7 @@ static PyObject* py_st_get_next_record(PyObject *self, PyObject *args)
 	}
 	
 	if ( id < 1 ) {
-		PyErr_SetString(PyExc_ValueError, \
+		PyErr_SetString(PyExc_ValueError, 
 			"this function does not work with fast ids");
 		return NULL;
 	}
@@ -756,7 +902,7 @@ static PyObject* py_st_get_previous_record(PyObject *self, PyObject *args)
 	}
 
 	if ( id < 1 ) {
-		PyErr_SetString(PyExc_ValueError, \
+		PyErr_SetString(PyExc_ValueError, 
 			"this function does not work with fast ids");
 		return NULL;
 	}
@@ -846,9 +992,9 @@ static PyObject* py_st_records_list(PyObject *self, PyObject *args)
 	
 	py_list = PyList_New(0);
 	for ( i=0; i<st->table->max_records; i++) {
-		if ( st->table->records[i] != NULL && \
+		if ( st->table->records[i] != NULL && 
 				st->table->records[i]->id != 0 ) {
-			PyList_Append(py_list, \
+			PyList_Append(py_list, 
 				PyInt_FromLong(st->table->records[i]->id));
 		}
 	}
@@ -870,11 +1016,20 @@ static PyObject* py_st_records_list(PyObject *self, PyObject *args)
  **/
 static PyObject* py_st_fast_records_list(PyObject *self, PyObject *args)
 {
+#ifndef USE_CURSOR
+//#  define USE_CURSOR
+#endif
 	subtable *st;
 	PyObject *py_list;
 	int i;
+#ifdef USE_CURSOR
+	gabycursor *cs;
+	record *r;
+#endif
 	
-	if ( ! PyArg_ParseTuple(args, "")) return NULL;
+	if ( args != NULL ) { /* NULL happens when called from C for printing */
+		if ( ! PyArg_ParseTuple(args, "")) return NULL;
+	}
 	
 	st = ((PyGabySubTable_Object*)self)->st;
 	
@@ -884,12 +1039,23 @@ static PyObject* py_st_fast_records_list(PyObject *self, PyObject *args)
 	}
 	
 	py_list = PyList_New(0);
+
+#ifndef USE_CURSOR /* old way; doesn't work with gabyqsl */
 	for ( i=0; i<st->table->max_records; i++) {
-		if ( st->table->records[i] != NULL && \
+		if ( st->table->records[i] != NULL && 
 				st->table->records[i]->id != 0 ) {
 			PyList_Append(py_list, 	PyInt_FromLong(-i-1));
 		}
 	}
+#else /* new way; using a cursor */
+	cs = cursor_declare(st->table);
+	r = cursor_get_first(cs);
+	while ( r ) {
+		PyList_Append(py_list, PyInt_FromLong(r->id));
+		r = cursor_get_next(cs);
+	}
+	cursor_free(cs);
+#endif /* USE_CURSOR */ 
 
 	return py_list;
 }
@@ -910,13 +1076,9 @@ static PyObject* py_st_create_new_window(PyObject *self, PyObject *args)
 	gabywindow *win;
 	struct window_info wi = { NULL, -1, -1, -1, -1, TRUE};
 	
-#ifdef DEBUG_GABY
 	debug_print("[py_st_create_new_window] -->\n");
-#endif
 	if ( ! PyArg_ParseTuple(args, "s", &view_name)) return NULL;
-#ifdef DEBUG_GABY
 	debug_print("[py_st_create_new_window] <--\n");
-#endif
 	
 	st = ((PyGabySubTable_Object*)self)->st;
 	
@@ -930,7 +1092,7 @@ static PyObject* py_st_create_new_window(PyObject *self, PyObject *args)
 		v = vi->data;
 		vi = g_list_next(vi);
 		if ( v->type == NULL ) continue;
-		if ( v->subtable == st && \
+		if ( v->subtable == st && 
 				strcmp(view_name, v->type->name) == 0 ) {
 			wi.view = v;
 			win = new_view_create(&wi);
@@ -1123,9 +1285,7 @@ static PyObject* PyGabyOutput_New(char *filename)
 
 static void PyGabyOutput_dealloc(PyGabyOutput_Object *self)
 {
-#ifdef DEBUG_GABY
 	debug_print("[PyGabyOutput_dealloc] called\n");
-#endif
 	PyMem_DEL(self);
 }
 
@@ -1150,9 +1310,7 @@ static PyObject* py_output_write(PyObject *self, PyObject *args)
 	FILE *f = ((PyGabyOutput_Object*)self)->file;
 	char *string;
 	
-#ifdef DEBUG_GABY
 	debug_print("[python] it printed something ! (but I catched it)\n");
-#endif
 
 #if 1
 	PyArg_ParseTuple(args, "s", &string);
@@ -1160,9 +1318,7 @@ static PyObject* py_output_write(PyObject *self, PyObject *args)
 	PyArg_Parse(args, "s", &string);
 #endif
 
-#ifdef DEBUG_GABY
 	debug_print("it was : %s\n", string);
-#endif
 	if ( f == NULL ) {
 		puts(string);
 		return Py_None;
@@ -1218,9 +1374,7 @@ static PyTypeObject PyGabyOutput_Type = {
  **/
 static PyObject* py_hello_world(PyObject *self, PyObject *args)
 {
-#ifdef DEBUG_GABY
 	debug_print("[gaby.hello_world()] --\n");
-#endif
 	if (!PyArg_ParseTuple(args, ""))
 		return NULL;
 		
@@ -1239,36 +1393,38 @@ static PyObject* py_hello_world(PyObject *self, PyObject *args)
 static PyObject* py_load_database(PyObject *self, PyObject *args)
 {
 	char *name;
-	GList *tables = g_list_alloc();
-	GList *subtables = g_list_alloc();
 
 	if ( ! PyArg_ParseTuple(args, "s", &name)) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"load_database() requires 1 argument (string)");
 		return NULL;
 	}
 
 	if ( appname != NULL ) {
+#if 1
+		free_everything();
+#else
 		PyErr_SetString(PyExc_SystemError, "a database is already there");
 		return NULL;
+#endif
 	}
 
-	list_tables = tables;
-	list_subtables = subtables;
+	list_tables = NULL;
+	list_subtables = NULL;
 	
 	appname = g_strdup(name);
-	if ( ! tables_load_struct(tables, name) ) {
+	if ( ! tables_load_struct(name) ) {
 		PyErr_SetString(PyExc_SystemError, "error in tables_load_struct");
 		appname = NULL;
 		return NULL;
 	}
-	if ( ! st_load_struct(tables, subtables, NULL, NULL, name ) ) {
+	if ( ! st_load_struct(NULL, name ) ) {
 		PyErr_SetString(PyExc_SystemError, "error in st_load_struct");
 		appname = NULL;
 		return NULL;
 	}
 	
-	tables_load(tables);
+	tables_load();
 	
 	return Py_None;
 }
@@ -1285,12 +1441,12 @@ static PyObject* py_get_subtable_by_name(PyObject *self, PyObject *args)
 	subtable *st;
 	
 	if ( ! PyArg_ParseTuple(args, "s", &subtable_name)) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"get_subtable_by_name() requires 1 argument (string)");
 		return NULL;
 	}
 	
-	st = get_subtable_pointer(list_subtables, subtable_name);
+	st = get_subtable_by_name(subtable_name);
 	if ( st == NULL ) return Py_None;
 	return PyGabySubTable_New(st);
 }
@@ -1305,12 +1461,10 @@ static PyObject* py_get_main_window (PyObject *self, PyObject *args)
 {
 	GList *aw = g_list_first(list_windows);
 
-#ifdef DEBUG_GABY
 	debug_print("py_get_main_window\n");
-#endif
 
 	if (!PyArg_ParseTuple(args, "")) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"get_main_window() doesn't accept arguments");
 		return NULL;
 	}
@@ -1342,7 +1496,7 @@ static PyObject* py_get_current_window(PyObject *self, PyObject *args)
 	GtkWidget *parent;
 
 	if (!PyArg_ParseTuple(args, "")) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"get_current_window() doesn't accept arguments");
 		return NULL;
 	}
@@ -1357,17 +1511,14 @@ static PyObject* py_get_current_window(PyObject *self, PyObject *args)
 		}
 		if ( ! win->focused ) continue;
 		
-#ifdef DEBUG_GABY
 		debug_print("current window : %p\n", aw->data);
-#endif
 		/*res = PyCObject_FromVoidPtr(aw->data, NULL);
 		return res;*/
 		return PyGabyWindow_New(win);
 	}
 
-#ifdef DEBUG_GABY
 	debug_print("No window has the focus right now\n");
-#endif
+
 	return py_get_main_window(self, args);
 #endif /* ! NO_GUI */
 }
@@ -1383,7 +1534,7 @@ static PyObject* py_exit_gaby(PyObject *self, PyObject *args)
 {
 	
 	if (!PyArg_ParseTuple(args, "")) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"exit_gaby() doesn't accept arguments");
 		return NULL;
 	}
@@ -1405,7 +1556,7 @@ static PyObject* py_get_subtables_list(PyObject *self, PyObject *args)
 	GList *tmp = list_subtables;
 	
 	if (!PyArg_ParseTuple(args, "")) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"get_subtables_list() doesn't accept arguments");
 		return NULL;
 	}
@@ -1420,6 +1571,38 @@ static PyObject* py_get_subtables_list(PyObject *self, PyObject *args)
 	return py_list;
 }
 
+/**
+ * get_windows_list()
+ *
+ * Description:
+ * This functions returns a list of GabyWindow objects
+ **/
+static PyObject* py_get_windows_list(PyObject *self, PyObject *args)
+{
+	gabywindow *win;
+	PyObject *py_list;
+	GList *tmp = g_list_first(list_windows);
+	
+	if (!PyArg_ParseTuple(args, "")) {
+		PyErr_SetString(PyExc_TypeError, 
+			"get_windows_list() doesn't accept arguments");
+		return NULL;
+	}
+
+	debug_print("[python:get_windows_list] -> adding... ");
+
+	py_list = PyList_New(0);
+	while ( tmp != NULL ) {
+		win = tmp->data;
+		debug_print("%s ", win->name);
+		PyList_Append(py_list, PyGabyWindow_New(win));
+		tmp = g_list_next(tmp);
+	}
+	debug_print("... <-\n");
+
+	return py_list;
+}
+
 /**
  * message_dialog(i, s)
  *
@@ -1434,7 +1617,7 @@ static PyObject* py_message_dialog(PyObject *self, PyObject *args)
 	char *message;
 	
 	if ( ! PyArg_ParseTuple(args, "is", &type, &message)) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"message_dialog() requires 2 arguments (int,string)");
 		return NULL;
 	}
@@ -1451,7 +1634,7 @@ static PyObject* py_new_output(PyObject *self, PyObject *args)
 	char *filename;
 	
 	if ( ! PyArg_ParseTuple(args, "s", &filename)) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"new_output() requires 1 argument (string)");
 		return NULL;
 	}
@@ -1467,7 +1650,7 @@ static void py_stdlg_row_changed( GtkCList *clist, gint row, gint column,
 				  GdkEventButton *event, GtkWidget *wid)
 {
 #ifdef USE_GNOME
-	gnome_dialog_set_sensitive(GNOME_DIALOG(wid), 0, \
+	gnome_dialog_set_sensitive(GNOME_DIALOG(wid), 0, 
 					( clist->selection != NULL ) );
 #else /* ! USE_GNOME */
 	gtk_widget_set_sensitive(wid, ( clist->selection != NULL ) );
@@ -1481,11 +1664,11 @@ void py_stdlg_ok_cb (GtkWidget *but, GtkWidget *dialog)
 	gchar *text;
 	GtkWidget *clist = gtk_object_get_data(GTK_OBJECT(dialog), "clist");
 		
-	gtk_clist_get_text(GTK_CLIST(clist), \
-			GPOINTER_TO_INT(GTK_CLIST(clist)->selection->data), \
+	gtk_clist_get_text(GTK_CLIST(clist), 
+			GPOINTER_TO_INT(GTK_CLIST(clist)->selection->data), 
 			0, &text );
 	
-	*st = get_subtable_pointer(list_subtables, text);
+	*st = get_subtable_by_name(text);
 		
 	gtk_widget_hide(dialog);
 #endif
@@ -1505,14 +1688,14 @@ static GtkWidget* py_subtable_dialog (gchar *text, subtable **st)
 	GList *subtables = list_subtables;
 
 #ifdef USE_GNOME
-	dialog = gnome_dialog_new(_("Select a subtable"), \
-				GNOME_STOCK_BUTTON_OK, \
-				GNOME_STOCK_BUTTON_CANCEL, \
+	dialog = gnome_dialog_new(_("Select a subtable"), 
+				GNOME_STOCK_BUTTON_OK, 
+				GNOME_STOCK_BUTTON_CANCEL, 
 				NULL );
 	gnome_dialog_set_close(GNOME_DIALOG(dialog), TRUE );
 	vbox = GNOME_DIALOG(dialog)->vbox;
 
-	gnome_dialog_button_connect(GNOME_DIALOG(dialog), 0, \
+	gnome_dialog_button_connect(GNOME_DIALOG(dialog), 0, 
 						py_stdlg_ok_cb, dialog);
 #else
 	dialog = gtk_dialog_new();
@@ -1521,14 +1704,14 @@ static GtkWidget* py_subtable_dialog (gchar *text, subtable **st)
 	
 	button = gtk_button_new_with_label(_("OK"));
 	gtk_widget_show(button);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, \
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, 
 				FALSE, FALSE, 5 );
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", py_stdlg_ok_cb, dialog );
 	buttonok = button;
 
 	button = gtk_button_new_with_label(_("Cancel"));
 	gtk_widget_show(button);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, \
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, 
 				FALSE, FALSE, 5 );
 /*	gtk_signal_connect(GTK_OBJECT(button), "clicked", close_dialog, dialog);
 */
@@ -1544,21 +1727,21 @@ static GtkWidget* py_subtable_dialog (gchar *text, subtable **st)
 	
 	subtables = g_list_first(subtables);
 	while ( subtables != NULL ) {
-		gtk_clist_append(GTK_CLIST(clist), \
+		gtk_clist_append(GTK_CLIST(clist), 
 				&((subtable*)subtables->data)->i18n_name );
 		subtables = g_list_next(subtables);
 	}
 
 #ifdef USE_GNOME
-	gtk_signal_connect(GTK_OBJECT(clist), "select_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "select_row", 
 					py_stdlg_row_changed, dialog );
-	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", 
 					py_stdlg_row_changed, dialog );
 	py_stdlg_row_changed(GTK_CLIST(clist), 0, 0, NULL, dialog);
 #else
-	gtk_signal_connect(GTK_OBJECT(clist), "select_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "select_row", 
 					py_stdlg_row_changed, buttonok );
-	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", 
 					py_stdlg_row_changed, buttonok );
 	py_stdlg_row_changed(GTK_CLIST(clist), 0, 0, NULL, buttonok);
 #endif
@@ -1583,12 +1766,12 @@ static PyObject* py_select_subtable(PyObject *self, PyObject *args)
 	gboolean *visible;
 	
 	if (!PyArg_ParseTuple(args, "")) {
-		PyErr_SetString(PyExc_TypeError, \
+		PyErr_SetString(PyExc_TypeError, 
 			"select_subtable() doesn't accept arguments");
 		return NULL;
 	}
 
-	if ( getenv("DISPLAY") == NULL ) {
+	if ( app == NULL || getenv("DISPLAY") == NULL ) {
 		GList *subtables = list_subtables;
 		subtable *tmpst;
 		int i = 1;
@@ -1606,9 +1789,7 @@ static PyObject* py_select_subtable(PyObject *self, PyObject *args)
 		visible = select_subtable_dialog(
 				_("Please select a subtable: "), NULL, &st);
 		wait_dialog_to_finish(visible);
-#ifdef DEBUG_GABY
 		debug_print("[py_select_subtable] window closed!\n");
-#endif
 	}
 
 	if ( st == NULL )
@@ -1617,6 +1798,25 @@ static PyObject* py_select_subtable(PyObject *self, PyObject *args)
 		return PyGabySubTable_New(st);
 }
 
+/**
+ * gettext(s)
+ *
+ * Description:
+ * This functions returns a translation of the given string
+ **/
+static PyObject* py_gettext(PyObject *self, PyObject *args)
+{
+	char *str;
+	
+	if ( ! PyArg_ParseTuple(args, "s", &str)) {
+		PyErr_SetString(PyExc_TypeError, 
+			"gettext() requires 1 argument (string)");
+		return NULL;
+	}
+	
+	return PyString_FromString( gettext(str) );
+}
+
 static PyMethodDef gaby_funcs[] = {
 	{ "hello_world",              py_hello_world, 1 },
 	{ "load_database",            py_load_database, 1 },
@@ -1625,6 +1825,7 @@ static PyMethodDef gaby_funcs[] = {
 	{ "get_main_window",          py_get_main_window, 1 },
 	{ "exit_gaby",                py_exit_gaby, 1 },
 	{ "get_subtables_list",       py_get_subtables_list, 1 },
+	{ "get_windows_list",         py_get_windows_list, 1 },
 	{ "message_dialog",           py_message_dialog, 1 },
 	{ "select_subtable",          py_select_subtable, 1 },
 
@@ -1649,16 +1850,8 @@ static PyMethodDef gaby_funcs[] = {
 	{ "add_bound_window",         py_add_bound_window, 1 },
 	{ "remove_bound_window",      py_remove_bound_window, 1 },
 #endif
-/* TODO: get_gtk_window()
- *  this would allow to use gtk functions on gaby windows (useful for move,
- *  resize, ...). The result shouldn't be the widget but its parent window
- *  (gtk_object_get_data(obj, "parent") (is this equal to GtkWidget->parent ?))
- *  move and resize are currently handled with {move,resize}_window but they
- *  are simple wrappers around gdk_window_{move,resize} (I suddenly wonder if
- *  there is a way to access widget->window with Python (get_window() is
- *  available with Gtkinter but what about straight GTK.py ?))
- */
 	{ "new_output",               py_new_output, 1},
+	{ "gettext",                  py_gettext, 1},
 	{ NULL, NULL, 0 }
 };
 
@@ -1666,11 +1859,15 @@ void initgaby()
 {
 	PyObject *d, *m, *private;
 	m = Py_InitModule("gaby", gaby_funcs);
+	gaby_module = m;
 	d = PyModule_GetDict(m);
 	
 	PyDict_SetItemString(d, "GabyWindowType", (PyObject *)&PyGabyWindow_Type);
 	PyDict_SetItemString(d, "GabySubTableType", (PyObject *)&PyGabySubTable_Type);
-	PyDict_SetItemString(d, "GabyOutputType", (PyObject *)&PyGabyOutput_Type);
+	if ( app != NULL ) {
+		PyDict_SetItemString(d, "GabyOutputType", 
+				(PyObject *)&PyGabyOutput_Type);
+	}
 	
 	private = PyDict_New();
 	PyDict_SetItemString(d, "_private", private); Py_DECREF(private);
@@ -1680,13 +1877,25 @@ void initgaby()
 	PyDict_SetItemString(private, "PyGabySubTable_New",
 			d=PyCObject_FromVoidPtr(PyGabySubTable_New,NULL));
 	Py_DECREF(d);
-	PyDict_SetItemString(private, "PyGabyOutput_New",
+	if ( app != NULL ) {
+		PyDict_SetItemString(private, "PyGabyOutput_New",
 			d=PyCObject_FromVoidPtr(PyGabyOutput_New,NULL));
-	Py_DECREF(d);
+		Py_DECREF(d);
+	}
+
+	if ( language[0] == 0 ) {
+		strcpy(language, "en");
+		if ( getenv("LANGUAGE") || getenv("LANG") ) {
+			char *t = g_strdup_printf("%s", getenv("LANGUAGE") ?
+							getenv("LANGUAGE")
+						   	: getenv("LANG")   );
+			t[2] = 0;
+			strcpy(language, t);
+			g_free(t);
+		}
+	}
 
-#ifdef DEBUG_GABY
 	debug_print("Python module initialized\n");
-#endif
 }
 
 int python_init_interpreter ( gchar *argv[] )
@@ -1708,9 +1917,7 @@ int python_init_interpreter ( gchar *argv[] )
 	}
 
 	if ( ! Py_IsInitialized() ) {
-#ifdef DEBUG_GABY
 		debug_print("[python:init_interpreter] initializing Python\n");
-#endif
 		Py_SetProgramName ("gaby");
 		Py_Initialize ();
 		initgaby();
@@ -1724,17 +1931,20 @@ int python_init_interpreter ( gchar *argv[] )
 		PySys_SetArgv(argc, real_argv);
 		
 		PyRun_SimpleString("import sys\n");
-		sprintf(path_gaby_py, \
+		sprintf(path_gaby_py, 
 			"sys.path.append('%s/interpreter')\n", SCRIPTS_DIR);
 		PyRun_SimpleString(path_gaby_py);
 #ifdef DEBUG_GABY
 		/*PyRun_SimpleString("print sys.path\n");*/
 #endif
-		PyRun_SimpleString("from gaby import *\n");
-	} else {
-#ifdef DEBUG_GABY
-		debug_print("[python:init_interpreter] already initialized\n");
+/*		PyRun_SimpleString("from gaby import *\n");*/
+		PyRun_SimpleString("import gaby\n");
+#ifdef HAVE_PYGTK
+		/* freaky macro contains return statements... */
+		init_pygtk();
 #endif
+	} else {
+		debug_print("[python:init_interpreter] already initialized\n");
 	}
 
 	return 0;
@@ -1742,13 +1952,9 @@ int python_init_interpreter ( gchar *argv[] )
 
 void python_close_interpreter ()
 {
-#ifdef DEBUG_GABY
 	debug_print("[python:close_interpreter] <--\n");
-#endif
 /*	Py_Finalize();	*/
-#ifdef DEBUG_GABY
 	debug_print("[python:close_interpreter] -->\n");
-#endif
 }
 
 void python_run_script(gchar *filename, action *act)
@@ -1757,11 +1963,9 @@ void python_run_script(gchar *filename, action *act)
 	int i;
 	char string[500], *s;
 	char filenam[PATH_MAX], *sfn;
-	gboolean textmode = getenv("DISPLAY") == NULL;
+	gboolean textmode = ( app == NULL ); /*getenv("DISPLAY") == NULL;*/
 	
-#ifdef DEBUG_GABY
 	debug_print("[python:run_script] %s\n", filename);
-#endif
 
 #ifdef DEBUG_GABY
 #if 0
@@ -1774,9 +1978,7 @@ void python_run_script(gchar *filename, action *act)
 	f = fopen(filename, "r");
 	
 	if ( f != NULL ) {
-#ifdef DEBUG_GABY
 		debug_print("[python:run_script] the file is present\n");
-#endif
 		/* this should be used to pop-up a dialog with errors (if
 		 * errors) or with the result 
 		 * But I don't know how to handle this for scripts that aren't
@@ -1794,7 +1996,7 @@ void python_run_script(gchar *filename, action *act)
 			sprintf(filenam, "%s/gabypy_XXXXXX", g_get_tmp_dir());
 			sfn = mktemp(filenam);
 #endif
-			g_snprintf(string, 499, "sys.stdout = new_output('%s')\n", sfn);
+			g_snprintf(string, 499, "sys.stdout = gaby.new_output('%s')\n", sfn);
 			PyRun_SimpleString(string);
 		}
 		
@@ -1805,17 +2007,17 @@ void python_run_script(gchar *filename, action *act)
 				case P_FIELD:
 				case P_FIELD_NO:
 				{
-					sprintf(s, "%d, ", \
+					sprintf(s, "%d, ", 
 						act->params[i].field_no);
 				} break;
 				case P_TABLE:
 				{
-					sprintf(s, "'%s', ", \
+					sprintf(s, "'%s', ", 
 						act->params[i].table->name );
 				} break;
 				case P_DIRECT:
 				{
-					sprintf(s, "'%s', ", \
+					sprintf(s, "'%s', ", 
 						act->params[i].val.str->str );
 				} break;
 			}
@@ -1824,9 +2026,7 @@ void python_run_script(gchar *filename, action *act)
 		s[-1] = ')';
 		s[0] = '\n';
 		s[1] = 0;
-#ifdef DEBUG_GABY
 		debug_print("[python:run_script] params : %s", string);
-#endif
 		PyRun_SimpleString(string);	/* sets the args */
 		
 		PyRun_SimpleFile(f, filename);	/* runs the script */
@@ -1838,14 +2038,10 @@ void python_run_script(gchar *filename, action *act)
 			f =  fopen(filenam, "r");
 			string[fread(string, 1, 500, f)] = 0;
 			fclose(f);
-#ifndef DEBUG_GABY
 			unlink(filenam);
-#endif
 			while ( string[strlen(string)-1] == '\n' )
 				string[strlen(string)-1] = 0;
-#ifdef DEBUG_GABY
 			debug_print("and we now show : %s\n", string);
-#endif
 			if ( strlen(string) > 0 ) {
 				gaby_message = g_strdup(string);
 				gaby_errno = CUSTOM_MESSAGE;
@@ -1854,17 +2050,187 @@ void python_run_script(gchar *filename, action *act)
 		}
 		
 	} else {
-#ifdef DEBUG_GABY
 		perror("oops");
-#endif
 	}
 	
-#ifdef DEBUG_GABY
 	debug_print("[python_run_script] done\n");
-#endif
 
 }
 
+
+int print_plugin_fct (char *pp_name, subtable *st, GList *names, gboolean fast)
+{
+	PyObject *d, *s, *py_dict, *obj, *ost;
+	FILE *f;
+	char filename[PATH_MAX];
+	int res;
+	
+	py_dict = PyDict_New();
+
+	obj = PyGabySubTable_New(st);
+	ost = obj;
+	PyDict_SetItemString(py_dict, "subtable", obj);
+	while ( names ) {
+		struct ref *r = names->data;
+		if ( ! fast ) {
+#ifndef NO_GUI
+			switch ( r->type ) {
+			case PAGE_FIELDS:
+			{
+				GabyPage *w = r->pointer;
+				GtkWidget *page = w->real_widget;
+				int i;
+				gboolean active;
+				int selected[st->nb_fields+1]; /* portable ? */
+				page_select_fields_get_info(st, page,
+							&active, selected);
+				i=0;
+				obj = PyList_New(0);
+				while ( selected[i] != -1 ) {
+					PyList_Append(obj,
+						PyInt_FromLong(selected[i]));
+					i++;
+				}
+				debug_print("selected: %d\n", i);
+				PyDict_SetItemString(py_dict, r->key, obj);
+			} break;
+			case PAGE_RECORDS:
+			{
+				GabyPage *w = r->pointer;
+				GtkWidget *page = w->real_widget;
+				GList *recs = NULL, *trecs;
+				gboolean all;
+
+				page_select_records_get_info(st, page,
+								&all, &recs);
+				if ( all ) {
+					PyDict_SetItemString(py_dict, r->key,
+						py_st_fast_records_list(ost, NULL));
+					break;
+				}
+				
+				trecs = recs;
+				obj = PyList_New(0);
+				while ( trecs ) {
+					int id = GPOINTER_TO_INT(trecs->data);
+					/* those are not ids, not even the
+					 * 'fast ids' as we know them: they
+					 * are records pos in t->records (fast
+					 * records for different people...)
+					 * How coherent...
+					 */
+					PyList_Append(obj,
+						PyInt_FromLong( -id-1 ));
+					trecs = g_list_next(trecs);
+				}
+				PyDict_SetItemString(py_dict, r->key, obj);
+				g_list_free(recs);
+
+			} break;
+			case PAGE_ORDER:
+			{
+				GabyPage *w = r->pointer;
+				GtkWidget *page = w->real_widget;
+				int field;
+				page_select_order_get_info(st, page, &field);
+				PyDict_SetItemString(py_dict, r->key,
+						PyInt_FromLong(field) );
+			} break;
+			case WIDGET_FILESEL:
+			case WIDGET_ENTRY:
+			{
+				GabyWidget *w = r->pointer;
+				GtkEntry *e = w->real_widget;
+				gchar *s = gtk_entry_get_text(e);
+				debug_print("value of the entry: %s\n", s);
+				PyDict_SetItemString(py_dict, r->key,
+							PyString_FromString(s));
+			} break;
+			case WIDGET_CHECKBOX:
+			{
+				GabyWidget *w = r->pointer;
+				GtkToggleButton *tb = w->real_widget;
+				debug_print("value of toggle button: %d\n",
+						tb->active );
+				PyDict_SetItemString(py_dict, r->key,
+						PyInt_FromLong(tb->active));
+			} break;
+			default: break;
+			}
+#endif /* ! NO_GUI */
+		} else {
+			switch ( r->type ) {
+			case PAGE_FIELDS:
+			{
+				GabyPageFields *w = r->pointer;
+				int sel = w->selection;
+				int i;
+				if ( sel == G_MAXINT ) {
+					sel = st->nb_fields;
+				}
+				obj = PyList_New(0);
+				if ( sel > 0 ) {
+					for ( i=0; i<sel; i++) {
+						PyList_Append(obj,
+							PyInt_FromLong(i));
+					}
+				} else {
+					for ( i=-sel; i>=0; i--) {
+						PyList_Append(obj,
+							PyInt_FromLong(i));
+					}
+				}
+				PyDict_SetItemString(py_dict, r->key, obj);
+			} break;
+			case PAGE_RECORDS: 
+			{
+				PyDict_SetItemString(py_dict, r->key,
+					py_st_fast_records_list(ost, NULL));
+			} break;
+			case PAGE_ORDER:
+			{
+				PyDict_SetItemString(py_dict, r->key,
+							PyInt_FromLong(0) );
+			} break;
+			case WIDGET_FILESEL:
+			case WIDGET_ENTRY:
+			{
+				PyDict_SetItemString(py_dict, r->key,
+						PyString_FromString("-"));
+			} break;
+			case WIDGET_CHECKBOX:
+			{
+				PyDict_SetItemString(py_dict, r->key,
+						PyInt_FromLong(0));
+			} break;
+			default: break;
+			}
+		}
+		names = g_list_next(names);
+	}
+	
+/*	for (i=0; i < st->nb_fields; i++) {
+		py_string = PyString_FromString(st->fields[i].name);
+		PyDict_SetItem(py_dict, py_string, PyInt_FromLong(i));
+	}*/
+
+	d = PyModule_GetDict(gaby_module);
+		
+	s = PyInt_FromLong(5);
+	PyDict_SetItemString(d, "PrintDict", (PyObject *)py_dict);
+
+#if 1
+	sprintf(filename, PLUGINS_DIR "/print/%s.py", pp_name);
+	f = fopen(filename, "r");
+	res = PyRun_SimpleFile(f, filename);	/* runs the script */
+	fclose(f);
+#else
+	PyRun_SimpleString("print gaby.PrintDict\n");
+#endif
+	
+	return res;
+}
+
 #ifndef FOLLOW_MIGUEL
 char* get_interpreter_name()
 {
