@@ -91,7 +91,7 @@ static GtkWidget* addresscanvas_create ( struct CommonInfos *ci, view *v,
 		
 	if ( strcmp(v->subtable->name, "Address Book") != 0 ) {
 #ifdef DEBUG_GABY
-		debug_print("[canvas_create] v->st->name == %s\n", \
+		debug_print("[canvas_create] v->st->name == %s\n",
 							v->subtable->name );
 #endif
 		return NULL;	/* and you should handle this ! */
@@ -113,13 +113,13 @@ static GtkWidget* addresscanvas_create ( struct CommonInfos *ci, view *v,
 
 	root = canvas_create_real(canvas);
 
-	gtk_signal_connect (GTK_OBJECT(canvas), "drag_data_received", \
+	gtk_signal_connect (GTK_OBJECT(canvas), "drag_data_received",
 			GTK_SIGNAL_FUNC(drag_data_received), NULL );
 
-	gtk_drag_dest_set (GTK_WIDGET(canvas), \
-			GTK_DEST_DEFAULT_MOTION | \
-			GTK_DEST_DEFAULT_HIGHLIGHT | \
-			GTK_DEST_DEFAULT_DROP, \
+	gtk_drag_dest_set (GTK_WIDGET(canvas),
+			GTK_DEST_DEFAULT_MOTION |
+			GTK_DEST_DEFAULT_HIGHLIGHT |
+			GTK_DEST_DEFAULT_DROP,
 			target_table, 1, GDK_ACTION_COPY );
 
 	/* all done */
@@ -139,9 +139,9 @@ static void update_box_color_bg(GList *items, gchar *color)
 	
 	while ( tmp != NULL ) {
 		item = tmp->data;
-		gnome_canvas_item_set( item, \
-				"fill_color", color, \
-				"outline_color", color, \
+		gnome_canvas_item_set( item,
+				"fill_color", color,
+				"outline_color", color,
 				NULL);
 		/*
 		 *  updating the configure box (if present)
@@ -160,9 +160,9 @@ static void drag_data_received(GtkWidget *widget, GdkDragContext *context,
 	guint16 *data = (guint16 *)selection_data->data;
 	char color[20];
 	int i;
-	GList *header_box_bg = gtk_object_get_data(GTK_OBJECT(widget), \
+	GList *header_box_bg = gtk_object_get_data(GTK_OBJECT(widget),
 							"header_box_bg" );
-	GList *label_box_bg = gtk_object_get_data(GTK_OBJECT(widget), \
+	GList *label_box_bg = gtk_object_get_data(GTK_OBJECT(widget),
 							"label_box_bg"  );
 	
 	if ( info == 1 ) {
@@ -174,7 +174,7 @@ static void drag_data_received(GtkWidget *widget, GdkDragContext *context,
 		debug_print("[drag_data_received] got a color at (%d,%d)\n", x, y);
 #endif
 
-		item = gnome_canvas_get_item_at(GNOME_CANVAS(widget), \
+		item = gnome_canvas_get_item_at(GNOME_CANVAS(widget),
 						(double)x, (double)y );
 
 		sprintf(color, "#%x%x%x",data[0]/256,data[1]/256,data[2]/256 ); 
@@ -215,8 +215,8 @@ static void drag_data_received(GtkWidget *widget, GdkDragContext *context,
 			/*
 			 *  update other text item
 			 */
-			gnome_canvas_item_set( item, \
-					"fill_color", color, \
+			gnome_canvas_item_set( item,
+					"fill_color", color,
 					NULL);
 			return;
 		}
@@ -229,8 +229,8 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 	GtkStyle *style;
 	GnomeCanvasGroup *root;
 	GdkFont *name_font, *title_font, *canvas_font, *comment_font;
-	GnomeCanvasItem *name_item, *street_item, *zipcity_item, \
-			*state_item, *country_item, *phone_item, \
+	GnomeCanvasItem *name_item, *street_item, *zipcity_item,
+			*state_item, *country_item, *phone_item,
 			*fax_item, *email_item, *web_item;
 	GList *header_box_bg = NULL;
 	GList *label_box_bg = NULL;
@@ -267,7 +267,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 	blue *= 256;
 
 #ifdef DEBUG_GABY
-	debug_print("[canvas_create_real] red : %hd, green : %hd, blue : %hd\n", \
+	debug_print("[canvas_create_real] red : %hd, green : %hd, blue : %hd\n",
 			red, green, blue );
 #endif
 
@@ -286,7 +286,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 	canvas_font = gdk_fontset_load (CANVAS_FONTSET);
 	comment_font = gdk_fontset_load (COMMENT_FONTSET);
 
-	header_box_bg = g_list_append(header_box_bg, \
+	header_box_bg = g_list_append(header_box_bg,
 		gnome_canvas_item_new(root, gnome_canvas_rect_get_type(),
 			"x1", 5.0,
 			"y1", 5.0,
@@ -348,7 +348,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 			NULL );
 	gtk_object_set_data(GTK_OBJECT(canvas), "country_item", country_item);
 	
-	header_box_bg = g_list_append(header_box_bg, \
+	header_box_bg = g_list_append(header_box_bg,
 		gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			"x1", 5.0,
 			"y1", 100.0,
@@ -369,7 +369,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 			"fill_color", header_text_color,
 			NULL);
 
-	label_box_bg = g_list_append(label_box_bg, \
+	label_box_bg = g_list_append(label_box_bg,
 		gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			"x1", 10.0,
 			"y1", 124.0,
@@ -400,7 +400,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 			NULL);
 	gtk_object_set_data(GTK_OBJECT(canvas), "privatephone_item",phone_item);
 	
-	label_box_bg = g_list_append(label_box_bg, \
+	label_box_bg = g_list_append(label_box_bg,
 		gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			"x1", 10.0,
 			"y1", 139.0,
@@ -430,7 +430,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 			NULL);
 	gtk_object_set_data(GTK_OBJECT(canvas), "workphone_item",phone_item);
 	
-	label_box_bg = g_list_append(label_box_bg, \
+	label_box_bg = g_list_append(label_box_bg,
 	gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			"x1", 10.0,
 			"y1", 154.0,
@@ -460,7 +460,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 			NULL);
 	gtk_object_set_data(GTK_OBJECT(canvas), "cellphone_item",phone_item);
 	
-	header_box_bg = g_list_append(header_box_bg, \
+	header_box_bg = g_list_append(header_box_bg,
 		gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			"x1", 5.0,
 			"y1", 170.0,
@@ -481,7 +481,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 			"fill_color", header_text_color,
 			NULL);
 
-	label_box_bg = g_list_append(label_box_bg, \
+	label_box_bg = g_list_append(label_box_bg,
 		gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			"x1", 10.0,
 			"y1", 194.0,
@@ -511,7 +511,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 			NULL);
 	gtk_object_set_data(GTK_OBJECT(canvas), "fax_item",fax_item);
 	
-	label_box_bg = g_list_append(label_box_bg, \
+	label_box_bg = g_list_append(label_box_bg,
 		gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			"x1", 10.0,
 			"y1", 209.0,
@@ -541,7 +541,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas)
 			NULL);
 	gtk_object_set_data(GTK_OBJECT(canvas), "email_item",email_item);
 	
-	label_box_bg = g_list_append(label_box_bg, \
+	label_box_bg = g_list_append(label_box_bg,
 		gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			"x1", 10.0,
 			"y1", 224.0,
@@ -680,62 +680,62 @@ static GtkWidget* addresscanvas_configure (ViewPluginData *vpd)
 
 	label = gtk_label_new(_("Header box color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			240, 230, 140, 0 );	/* khaki */
 	gtk_widget_show(color_picker);
 	gtk_object_set_data(GTK_OBJECT(table), "header_box", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 0, 1, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 0, 1,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Label box color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			189, 183, 107, 0 );	/* dark khaki */
 	gtk_widget_show(color_picker);
 	gtk_object_set_data(GTK_OBJECT(table), "label_box", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 1, 2, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 1, 2,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Header text color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			0, 0, 0, 0 );	/* black */
 	gtk_widget_show(color_picker);
 	gtk_object_set_data(GTK_OBJECT(table), "header_text", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 2, 3, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 2, 3,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Label text color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			0, 0, 0, 0 );	/* black */
 	gtk_widget_show(color_picker);
 	gtk_object_set_data(GTK_OBJECT(table), "label_text", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 3, 4, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 3, 4,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Body text color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			0, 0, 0, 0 );	/* black */
 	gtk_widget_show(color_picker);
 	gtk_object_set_data(GTK_OBJECT(table), "body_text", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 4, 5, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 4, 5,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	gtk_object_set_data(GTK_OBJECT(table), "name", vpd->i18n_name->str);
@@ -759,17 +759,17 @@ static void configure_save()
 
 static void addresscanvas_get_config()
 {
-	background_color = get_config_str("view", "addresscanvas", \
+	background_color = get_config_str("view", "addresscanvas",
 			"background_color",g_strdup(DEFAULT_BACKGROUND_COLOR) );
-	header_box_color = get_config_str("view", "addresscanvas", \
+	header_box_color = get_config_str("view", "addresscanvas",
 			"header_box_color",g_strdup(DEFAULT_HEADER_BOX_COLOR) );
-	label_box_color = get_config_str("view", "addresscanvas", \
+	label_box_color = get_config_str("view", "addresscanvas",
 			"label_box_color",g_strdup(DEFAULT_LABEL_BOX_COLOR) );
-	header_text_color = get_config_str("view", "addresscanvas", \
+	header_text_color = get_config_str("view", "addresscanvas",
 			"header_text_color",g_strdup(DEFAULT_HEADER_TEXT_COLOR));
-	label_text_color = get_config_str("view", "addresscanvas", \
+	label_text_color = get_config_str("view", "addresscanvas",
 			"label_text_color",g_strdup(DEFAULT_LABEL_TEXT_COLOR) );
-	body_text_color = get_config_str("view", "addresscanvas", \
+	body_text_color = get_config_str("view", "addresscanvas",
 			"body_text_color",g_strdup(DEFAULT_BODY_TEXT_COLOR) );
 
 }
