@@ -37,6 +37,7 @@ int init_view_plugin (ViewPluginData *vpd)
 {
 	vpd->view_create = canvas_create;
 	vpd->view_fill = canvas_fill;
+	vpd->view_records = NULL;
 	vpd->configure = canvas_configure;
 
 	vpd->name = "canvas";
@@ -108,9 +109,9 @@ mstatic void canvas_create ( gabywindow *window, gboolean first )
 	format = get_plugin_options(sectname);
 	if ( format == NULL ) {
 		gaby_errno = CUSTOM_ERROR;
-		gaby_message = g_strdup( \
+		gaby_message = g_strdup(
 			_("No canvas format were defined for this subtable.\n"\
-			  "Ask me (fpeters@win.be) how to write them"));
+			  "Ask me (fpeters@tiscalinet.be) how to write them"));
 		gaby_perror_in_a_box();
 		return;
 	}
@@ -128,21 +129,21 @@ mstatic void canvas_create ( gabywindow *window, gboolean first )
 	r = table_first(window->view->subtable->table, -1);
 	*id = ( r == NULL ? 0 : r->id );
 	
-	root = canvas_create_real(canvas, format, \
+	root = canvas_create_real(canvas, format,
 					window->view->subtable, &height);
 	g_list_free(format);
 	
 	gtk_widget_set_usize(canvas, -1, height);
 
-	gtk_signal_connect (GTK_OBJECT(canvas), "drag_data_received", \
+	gtk_signal_connect (GTK_OBJECT(canvas), "drag_data_received",
 			GTK_SIGNAL_FUNC(drag_data_received), NULL );
-	gtk_drag_dest_set (GTK_WIDGET(canvas), \
-			GTK_DEST_DEFAULT_MOTION | \
-			GTK_DEST_DEFAULT_HIGHLIGHT | \
-			GTK_DEST_DEFAULT_DROP, \
+	gtk_drag_dest_set (GTK_WIDGET(canvas),
+			GTK_DEST_DEFAULT_MOTION |
+			GTK_DEST_DEFAULT_HIGHLIGHT |
+			GTK_DEST_DEFAULT_DROP,
 			target_table, 1, GDK_ACTION_COPY );
 	
-	gtk_signal_connect (GTK_OBJECT(canvas), "button_release_event", \
+	gtk_signal_connect (GTK_OBJECT(canvas), "button_release_event",
 			GTK_SIGNAL_FUNC(canvas_clicked), NULL );
 
 	/* all done */
@@ -162,9 +163,9 @@ static void update_box_color_bg(GList *items, gchar *color)
 	
 	while ( tmp != NULL ) {
 		item = tmp->data;
-		gnome_canvas_item_set( item, \
-				"fill_color", color, \
-				"outline_color", color, \
+		gnome_canvas_item_set( item,
+				"fill_color", color,
+				"outline_color", color,
 				NULL);
 		tmp = g_list_next(tmp);
 	}
@@ -189,7 +190,6 @@ static void drag_data_received(GtkWidget *widget, GdkDragContext *context,
 			       gint x, gint y, GtkSelectionData *selection_data,
 			       guint info, guint time)
 {
-	/* FIXME : glib/gtk+ loops endlessly somewhere _after_ this function */
 	GnomeCanvasItem *item;
 	GtkStyle *style;
 	guint16 *data = (guint16 *)selection_data->data;
@@ -199,6 +199,12 @@ static void drag_data_received(GtkWidget *widget, GdkDragContext *context,
 	GList *h1h2_texts, *ftext_texts;
 	GList *items;
 	
+	/* TODO (post-2.0): reactivate color drag and drop
+	 * (disabled since it doesn't work when upper left corner is not (0,0)
+	 * (delayed since it is not useful)
+	 */
+	return;
+
 #ifdef DEBUG_GABY
 	debug_print("[drag_data_received] begin\n");
 #endif
@@ -217,7 +223,7 @@ static void drag_data_received(GtkWidget *widget, GdkDragContext *context,
 		debug_print("[drag_data_received] got a color at (%d,%d)\n", x, y);
 #endif
 
-		item = gnome_canvas_get_item_at(GNOME_CANVAS(widget), \
+		item = gnome_canvas_get_item_at(GNOME_CANVAS(widget),
 						(double)x, (double)y );
 
 		sprintf(color, "#%02x%02x%02x",data[0]/256,data[1]/256,data[2]/256 ); 
@@ -325,7 +331,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 	blue *= 256;
 
 #ifdef DEBUG_GABY
-	debug_print("[canvas_create_real] red : %hd, green : %hd, blue : %hd\n", \
+	debug_print("[canvas_create_real] red : %hd, green : %hd, blue : %hd\n",
 			red, green, blue );
 #endif
 
@@ -371,7 +377,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 	}
 
 #ifdef DEBUG_GABY
-	debug_print("[canvas_create_real] ascent %d, descent: %d\n", \
+	debug_print("[canvas_create_real] ascent %d, descent: %d\n",
 	      h1_font->ascent, h1_font->descent);
 #endif
 
@@ -439,11 +445,11 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 		type = 0;
 		if ( strncmp(stmp, "<h1>", 4) == 0 ) {
 			type = 2;
-			size = h1_font->ascent + h1_font->descent + \
+			size = h1_font->ascent + h1_font->descent +
 				BORDER_SIZE_2;
-			h1h2_boxes = g_list_append(h1h2_boxes, \
-				gnome_canvas_item_new(root, \
-					gnome_canvas_rect_get_type(), \
+			h1h2_boxes = g_list_append(h1h2_boxes,
+				gnome_canvas_item_new(root,
+					gnome_canvas_rect_get_type(),
 					"x1", 5.0,
 					"y1", y,
 					"x2", 200.0,
@@ -458,11 +464,11 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 			
 		if ( strncmp(stmp, "<h2>", 4) == 0 ) {
 			type = 3;
-			size = h2_font->ascent + h2_font->descent + \
+			size = h2_font->ascent + h2_font->descent +
 				BORDER_SIZE_2;
-			h1h2_boxes = g_list_append(h1h2_boxes, \
-				gnome_canvas_item_new(root, \
-					gnome_canvas_rect_get_type(), \
+			h1h2_boxes = g_list_append(h1h2_boxes,
+				gnome_canvas_item_new(root,
+					gnome_canvas_rect_get_type(),
 					"x1", 5.0,
 					"y1", y,
 					"x2", 200.0,
@@ -477,11 +483,11 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 
 		if ( strncmp(stmp, "<f ", 3) == 0 ) {
 			type = 1;
-			size = ftext_font->ascent + ftext_font->descent + \
+			size = ftext_font->ascent + ftext_font->descent +
 				BORDER_SIZE_2;
-			ftext_boxes = g_list_append(ftext_boxes, \
-				gnome_canvas_item_new(root, \
-					gnome_canvas_rect_get_type(), \
+			ftext_boxes = g_list_append(ftext_boxes,
+				gnome_canvas_item_new(root,
+					gnome_canvas_rect_get_type(),
 					"x1", 10.0,
 					"y1", y,
 					"x2", 62.0,
@@ -494,7 +500,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 			y += BORDER_SIZE;
 			strchr(stmp, '>')[0] = 0;
 			ftext_texts = g_list_append(ftext_texts,
-					gnome_canvas_item_new(root, \
+					gnome_canvas_item_new(root,
 					gnome_canvas_text_get_type(),
 					"text", stmp,
 					"x", 60.0,
@@ -509,7 +515,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 		switch ( type ) {
 			case 1: /* 'f'-text */
 			{
-				item = gnome_canvas_item_new(root, \
+				item = gnome_canvas_item_new(root,
 					gnome_canvas_text_get_type(),
 					"text", "",
 					"x", 70.0,
@@ -522,7 +528,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 			} break;
 			case 2: /* h1 text */
 			{
-				item = gnome_canvas_item_new(root, \
+				item = gnome_canvas_item_new(root,
 					gnome_canvas_text_get_type(),
 					"text", "",
 					"x", 10.0,
@@ -536,7 +542,7 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 			} break;
 			case 3: /* h2 text */
 			{
-				item = gnome_canvas_item_new(root, \
+				item = gnome_canvas_item_new(root,
 					gnome_canvas_text_get_type(),
 					"text", "",
 					"x", 10.0,
@@ -551,10 +557,10 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 			default:
 			case 0: /* normal text */
 			{
-				size = normal_font->ascent + \
-					normal_font->descent + \
+				size = normal_font->ascent +
+					normal_font->descent +
 					BORDER_SIZE_2;
-				item = gnome_canvas_item_new(root, \
+				item = gnome_canvas_item_new(root,
 					gnome_canvas_text_get_type(),
 					"text", "",
 					"x", 10.0,
@@ -567,12 +573,12 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 			} break;
 		}
 		
-		gtk_object_set_data(GTK_OBJECT(item), "type", \
+		gtk_object_set_data(GTK_OBJECT(item), "type",
 						GINT_TO_POINTER(type) );
 		
 		while ( *stmp == ' ') stmp++;
 		if ( strchr(stmp, '\n') ) strchr(stmp, '\n')[0] = 0;
-		if ( strchr(stmp, ',') != NULL || \
+		if ( strchr(stmp, ',') != NULL ||
 				subtable_get_field_no(st, stmp) != -2) {
 			
 			i=0;
@@ -588,8 +594,8 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 				/* the ultimate coding style
 				 * 
 				 * enjoy */
-				gtk_object_set_data(GTK_OBJECT(item), str, \
-					GINT_TO_POINTER( \
+				gtk_object_set_data(GTK_OBJECT(item), str,
+					GINT_TO_POINTER(
 						subtable_get_field_no(st, stmp)
 					));
 			
@@ -599,12 +605,12 @@ static GnomeCanvasGroup* canvas_create_real(GtkWidget *canvas, GList *format,
 			}
 			sprintf(str, "%d", i);
 			i++;
-			gtk_object_set_data(GTK_OBJECT(item), str, \
-				GINT_TO_POINTER( \
+			gtk_object_set_data(GTK_OBJECT(item), str,
+				GINT_TO_POINTER(
 					subtable_get_field_no(st, stmp)));
 			
 			sprintf(str, "%d", i);
-			gtk_object_set_data(GTK_OBJECT(item), str, \
+			gtk_object_set_data(GTK_OBJECT(item), str,
 						GINT_TO_POINTER(-2));
 			
 #ifdef DEBUG_GABY
@@ -664,10 +670,10 @@ mstatic void canvas_fill( gabywindow *window )
 		str = g_string_assign(str, "");
 		do {
 			sprintf(dstr, "%d", i);
-			field_no = GPOINTER_TO_INT( \
+			field_no = GPOINTER_TO_INT(
 				gtk_object_get_data(GTK_OBJECT(item), dstr ));
 #ifdef DEBUG_GABY
-			debug_print("[canvas_fill] field number : %d %s\n", \
+			debug_print("[canvas_fill] field number : %d %s\n",
 					field_no, dstr );
 #endif
 			if ( field_no == -2 ) break;
@@ -827,7 +833,7 @@ static void canvas_clicked(GtkWidget *canvas, GdkEventButton *event)
 		debug_print("[canvas_clicked] creating menu.\n");
 #endif
 		menu = gtk_menu_new();
-		gnome_app_fill_menu_with_data(&(GTK_MENU(menu)->menu_shell), \
+		gnome_app_fill_menu_with_data(&(GTK_MENU(menu)->menu_shell),
 				go_menu, NULL, FALSE, 0, window );
 		gtk_object_set_data(GTK_OBJECT(canvas), "menu", menu);
 	}
@@ -870,27 +876,27 @@ static void reset_defaults(GtkWidget *but, GtkWidget *table)
 	
 	color_picker = gtk_object_get_data ( GTK_OBJECT(table), "header_box");
 	stupid_XParseColor(DEFAULT_HEADER_BOX_COLOR, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	color_picker = gtk_object_get_data ( GTK_OBJECT(table), "label_box");
 	stupid_XParseColor(DEFAULT_LABEL_BOX_COLOR, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	color_picker = gtk_object_get_data ( GTK_OBJECT(table), "header_text");
 	stupid_XParseColor(DEFAULT_HEADER_TEXT_COLOR, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	color_picker = gtk_object_get_data ( GTK_OBJECT(table), "label_text");
 	stupid_XParseColor(DEFAULT_LABEL_TEXT_COLOR, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	color_picker = gtk_object_get_data ( GTK_OBJECT(table), "body_text");
 	stupid_XParseColor(DEFAULT_BODY_TEXT_COLOR, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	color_picker = gtk_object_get_data ( GTK_OBJECT(table), "background");
 	stupid_XParseColor(DEFAULT_BACKGROUND_COLOR, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 
 }
@@ -903,7 +909,7 @@ mstatic GtkWidget* canvas_configure (ViewPluginData *vpd)
 	guint8 red, green, blue;
 	
 #ifdef DEBUG_GABY
-	debug_print("[canvas:configure] red:%x, green:%x, blue:%x\n", \
+	debug_print("[canvas:configure] red:%x, green:%x, blue:%x\n",
 							red, green, blue );
 #endif
 	
@@ -911,100 +917,100 @@ mstatic GtkWidget* canvas_configure (ViewPluginData *vpd)
 
 	label = gtk_label_new(_("Background color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
 	stupid_XParseColor(background_color, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	gtk_widget_show(color_picker);
-	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set", \
+	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set",
 		GTK_SIGNAL_FUNC(gaby_property_box_changed), GTK_OBJECT(table) );
 	gtk_object_set_data(GTK_OBJECT(table), "background", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 0, 1, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 0, 1,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Header box color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
 	stupid_XParseColor(header_box_color, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	gtk_widget_show(color_picker);
-	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set", \
+	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set",
 		GTK_SIGNAL_FUNC(gaby_property_box_changed), GTK_OBJECT(table) );
 	gtk_object_set_data(GTK_OBJECT(table), "header_box", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 1, 2, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 1, 2,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Label box color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
 	stupid_XParseColor(label_box_color, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	gtk_widget_show(color_picker);
-	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set", \
+	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set",
 		GTK_SIGNAL_FUNC(gaby_property_box_changed), GTK_OBJECT(table) );
 	gtk_object_set_data(GTK_OBJECT(table), "label_box", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 2, 3, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 2, 3,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Header text color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
 	stupid_XParseColor(header_text_color, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	gtk_widget_show(color_picker);
-	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set", \
+	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set",
 		GTK_SIGNAL_FUNC(gaby_property_box_changed), GTK_OBJECT(table) );
 	gtk_object_set_data(GTK_OBJECT(table), "header_text", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 3, 4, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 3, 4,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Label text color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
 	stupid_XParseColor(label_text_color, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	gtk_widget_show(color_picker);
-	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set", \
+	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set",
 		GTK_SIGNAL_FUNC(gaby_property_box_changed), GTK_OBJECT(table) );
 	gtk_object_set_data(GTK_OBJECT(table), "label_text", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 4, 5, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 4, 5,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	label = gtk_label_new(_("Body text color"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 5, 6, \
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 5, 6,
 			GTK_FILL, 0, GNOME_PAD, GNOME_PAD );
 	color_picker = gnome_color_picker_new();
 	stupid_XParseColor(body_text_color, &red, &green, &blue);
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), \
+	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker),
 			red, green, blue, 0 );
 	gtk_widget_show(color_picker);
-	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set", \
+	gtk_signal_connect(GTK_OBJECT(color_picker), "color_set",
 		GTK_SIGNAL_FUNC(gaby_property_box_changed), GTK_OBJECT(table) );
 	gtk_object_set_data(GTK_OBJECT(table), "body_text", color_picker);
-	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 5, 6, \
+	gtk_table_attach(GTK_TABLE(table), color_picker, 1, 2, 5, 6,
 			0, 0, GNOME_PAD, GNOME_PAD );
 
 	button = gtk_button_new_with_label(_("Set back to defaults"));
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", reset_defaults,table);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked", \
+	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(gaby_property_box_changed), GTK_OBJECT(table) );
 	gtk_widget_show(button);
-	gtk_table_attach(GTK_TABLE(table), button, 0, 2, 6, 7, \
+	gtk_table_attach(GTK_TABLE(table), button, 0, 2, 6, 7,
 			0, 0, GNOME_PAD, GNOME_PAD );
 	
 	gtk_object_set_data(GTK_OBJECT(table), "name", vpd->i18n_name);
@@ -1032,42 +1038,42 @@ static void configure_apply()
 	debug_print("[canvas::configure_apply] ...\n");
 #endif
 	
-	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget), \
+	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget),
 				"header_box");
 	gnome_color_picker_get_i8( GNOME_COLOR_PICKER(color_picker),
 				&red, &green, &blue, NULL );
 	sprintf(color, "#%02x%02x%02x", red, green, blue ); 
 	strcpy(header_box_color, color);
 	
-	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget), \
+	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget),
 				"label_box");
 	gnome_color_picker_get_i8( GNOME_COLOR_PICKER(color_picker),
 				&red, &green, &blue, NULL );
 	sprintf(color, "#%02x%02x%02x", red, green, blue ); 
 	strcpy(label_box_color, color);
 
-	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget), \
+	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget),
 				"header_text");
 	gnome_color_picker_get_i8( GNOME_COLOR_PICKER(color_picker),
 				&red, &green, &blue, NULL );
 	sprintf(color, "#%02x%02x%02x", red, green, blue ); 
 	strcpy(header_text_color, color);
 	
-	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget), \
+	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget),
 				"label_text");
 	gnome_color_picker_get_i8( GNOME_COLOR_PICKER(color_picker),
 				&red, &green, &blue, NULL );
 	sprintf(color, "#%02x%02x%02x", red, green, blue ); 
 	strcpy(label_text_color, color);
 	
-	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget), \
+	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget),
 				"body_text");
 	gnome_color_picker_get_i8( GNOME_COLOR_PICKER(color_picker),
 				&red, &green, &blue, NULL );
 	sprintf(color, "#%02x%02x%02x", red, green, blue ); 
 	strcpy(body_text_color, color);
 	
-	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget), \
+	color_picker = gtk_object_get_data ( GTK_OBJECT(configure_widget),
 				"background");
 	gnome_color_picker_get_i8( GNOME_COLOR_PICKER(color_picker),
 				&red, &green, &blue, NULL );
@@ -1089,23 +1095,23 @@ static void configure_apply()
 			}
 			gtk_widget_set_style(wid, style);
 
-			items = gtk_object_get_data ( \
+			items = gtk_object_get_data (
 					GTK_OBJECT(wid), "h1h2_boxes");
 			update_box_color_bg(items, header_box_color);
 						
-			items = gtk_object_get_data ( \
+			items = gtk_object_get_data (
 					GTK_OBJECT(wid), "ftext_boxes");
 			update_box_color_bg(items, label_box_color);
 			
-			items = gtk_object_get_data ( \
+			items = gtk_object_get_data (
 					GTK_OBJECT(wid), "h1h2_texts");
 			update_text_color(items, header_text_color, FALSE);
 
-			items = gtk_object_get_data ( \
+			items = gtk_object_get_data (
 					GTK_OBJECT(wid), "ftext_texts");
 			update_text_color(items, label_text_color, FALSE);
 
-			items = gtk_object_get_data( \
+			items = gtk_object_get_data(
 					GTK_OBJECT(wid), "items");
 			update_text_color(items, body_text_color, TRUE);
 		}
@@ -1130,25 +1136,25 @@ static void configure_save()
 
 mstatic void canvas_get_config()
 {
-	background_color = get_config_str("view", "canvas", \
+	background_color = get_config_str("view", "canvas",
 			"background_color",g_strdup(DEFAULT_BACKGROUND_COLOR) );
-	header_box_color = get_config_str("view", "canvas", \
+	header_box_color = get_config_str("view", "canvas",
 			"header_box_color",g_strdup(DEFAULT_HEADER_BOX_COLOR) );
-	label_box_color = get_config_str("view", "canvas", \
+	label_box_color = get_config_str("view", "canvas",
 			"label_box_color",g_strdup(DEFAULT_LABEL_BOX_COLOR) );
-	header_text_color = get_config_str("view", "canvas", \
+	header_text_color = get_config_str("view", "canvas",
 			"header_text_color",g_strdup(DEFAULT_HEADER_TEXT_COLOR));
-	label_text_color = get_config_str("view", "canvas", \
+	label_text_color = get_config_str("view", "canvas",
 			"label_text_color",g_strdup(DEFAULT_LABEL_TEXT_COLOR) );
-	body_text_color = get_config_str("view", "canvas", \
+	body_text_color = get_config_str("view", "canvas",
 			"body_text_color",g_strdup(DEFAULT_BODY_TEXT_COLOR) );
-	h1_fontset = get_config_str("view", "canvas", \
+	h1_fontset = get_config_str("view", "canvas",
 		"h1_fontset", g_strdup(DEFAULT_H1_FONTSET));
-	h2_fontset = get_config_str("view", "canvas", \
+	h2_fontset = get_config_str("view", "canvas",
 		"h2_fontset", g_strdup(DEFAULT_H2_FONTSET));
-	normal_fontset = get_config_str("view", "canvas", \
+	normal_fontset = get_config_str("view", "canvas",
 		"normal_fontset", g_strdup(DEFAULT_NORMAL_FONTSET));
-	ftext_fontset = get_config_str("view", "canvas", \
+	ftext_fontset = get_config_str("view", "canvas",
 		"ftext_fontset", g_strdup(DEFAULT_FTEXT_FONTSET));
 }
 
@@ -1168,12 +1174,12 @@ static void update_configure_box()
 
 	if ( GTK_IS_WIDGET(configure_widget) ) {
 		for (i=0; i<5; i++) {
-			color_picker = gtk_object_get_data ( \
+			color_picker = gtk_object_get_data (
 				GTK_OBJECT(configure_widget), items_names[i]);
 			if ( GNOME_IS_COLOR_PICKER(color_picker) ) {
 				stupid_XParseColor(color[i],&red,&green,&blue);
 				gnome_color_picker_set_i8(
-					GNOME_COLOR_PICKER(color_picker), \
+					GNOME_COLOR_PICKER(color_picker),
 					red, green, blue, 0 );
 			}
 		}
