@@ -41,6 +41,7 @@ int init_view_plugin (ViewPluginData *vpd)
 	vpd->view_create = gnomecard_create;
 	vpd->view_fill = gnomecard_fill;
 	vpd->configure = NULL;
+	vpd->view_records = NULL;
 
 	vpd->name = "gnomecard";
 	vpd->i18n_name = _("GnomeCard");
@@ -239,7 +240,7 @@ mstatic void gnomecard_create ( gabywindow *window, gboolean first )
 		vtmp = tmp->data;
 		tmp = g_list_next(tmp);
 #ifdef DEBUG_GABY
-		debug_print("[gnomecard_create] name : %s\n", \
+		debug_print("[gnomecard_create] name : %s\n",
 						vtmp->type->name );
 #endif
 		if ( strcmp(vtmp->type->name, "xlist") == 0 ) {
@@ -304,7 +305,7 @@ mstatic void gnomecard_create ( gabywindow *window, gboolean first )
 	/* we don't want our form window to be destroyed by an irresponsable
 	 * user so we disconnect the default handler and put our that hides the
 	 * window instead of destroying it. */
-	gtk_signal_disconnect_by_func(GTK_OBJECT(wform->parent), \
+	gtk_signal_disconnect_by_func(GTK_OBJECT(wform->parent),
 					GTK_SIGNAL_FUNC(delete_view), NULL );
 	gtk_signal_connect(GTK_OBJECT(wform->parent), "delete_event",
 			GTK_SIGNAL_FUNC(gnomecard_form_delete), NULL);
@@ -325,7 +326,7 @@ mstatic void gnomecard_create ( gabywindow *window, gboolean first )
 #endif
 	gtk_box_pack_start(GTK_BOX(bbox), button, TRUE, TRUE, 0);
 	gtk_widget_show(button);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked", \
+	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(gnomecard_commit), wform);
 /*	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	gtk_widget_grab_default(button);*/
@@ -337,7 +338,7 @@ mstatic void gnomecard_create ( gabywindow *window, gboolean first )
 #endif
 	gtk_box_pack_start(GTK_BOX(bbox), button, TRUE, TRUE, 0);
 	gtk_widget_show(button);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked", \
+	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(gnomecard_cancel), wform);
 	
 	gnome_app_create_menus(GNOME_APP(window->parent), gnomecard_menu);
@@ -525,7 +526,7 @@ static void gnomecard_cancel(GtkWidget *w, gabywindow *window)
 	
 	if ( *id == 0 ) {
 		/* Assume new card - remove. */
-		sort_by = gtk_object_get_data(GTK_OBJECT(window->widget), \
+		sort_by = gtk_object_get_data(GTK_OBJECT(window->widget),
 			"sort_by");
 		r = table_last(t, *sort_by);
 		if ( r != NULL ) *id = r->id;
@@ -541,9 +542,9 @@ static void gnomecard_cancel(GtkWidget *w, gabywindow *window)
 
 mstatic void gnomecard_fill ( gabywindow *window )
 {
-	gabywindow *wcanvas = gtk_object_get_data( \
+	gabywindow *wcanvas = gtk_object_get_data(
 				GTK_OBJECT(window->widget), "canvas" );
-	gabywindow *wlist = gtk_object_get_data( \
+	gabywindow *wlist = gtk_object_get_data(
 				GTK_OBJECT(window->widget), "list" );
 #ifdef DEBUG_GABY
 	debug_print("[gnomecard_fill] filling gnomecard\n");
@@ -703,7 +704,7 @@ static void preferences_clicked(GtkWidget *w, gpointer data)
 {
 	GtkWidget *a;
 	
-	a = configure_dialog ();
+	a = configure_dialog (NULL);
 	if ( a != NULL ) gtk_widget_show(a);
 }
 
