@@ -16,7 +16,8 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* TODO : _one_ header file for plug-ins */
+/* TODO (post-2.0): it would be nice if there was _one_ header file for plug-ins
+ * delayed since this is a code wishlist issue */
 #include <gaby.h>
 #include <tables.h>
 #include <records.h>
@@ -30,6 +31,7 @@ mstatic void xlist_create ( gabywindow *window, gboolean first );
 mstatic void xlist_fill ( gabywindow *window );
 mstatic GtkWidget* xlist_configure (ViewPluginData *vpd);
 mstatic void xlist_get_config();
+mstatic void xlist_get_records(gabywindow *window, GList **records);
 
 #ifndef FOLLOW_MIGUEL
 int init_view_plugin (ViewPluginData *vpd)
@@ -37,6 +39,7 @@ int init_view_plugin (ViewPluginData *vpd)
 	vpd->view_create = xlist_create;
 	vpd->view_fill = xlist_fill;
 	vpd->configure = xlist_configure;
+	vpd->view_records = xlist_get_records;
 	
 	vpd->name = "xlist";
 	vpd->i18n_name = _("Extended List");
@@ -105,7 +108,7 @@ mstatic void xlist_create ( gabywindow *window, gboolean first )
 	gtk_widget_show(vbox);
 	
 	sclwin = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sclwin), \
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sclwin),
 			GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 	gtk_widget_show(sclwin);
 
@@ -117,13 +120,13 @@ mstatic void xlist_create ( gabywindow *window, gboolean first )
 	gtk_clist_set_compare_func(GTK_CLIST(clist), xlist_compare);
 	gtk_object_set_data(GTK_OBJECT(clist), "window", window);
 	
-	gtk_signal_connect(GTK_OBJECT(clist), "click_column", \
+	gtk_signal_connect(GTK_OBJECT(clist), "click_column",
 			GTK_SIGNAL_FUNC(clist_click_column), window );
-	gtk_signal_connect(GTK_OBJECT(clist), "button_press_event", \
+	gtk_signal_connect(GTK_OBJECT(clist), "button_press_event",
 			GTK_SIGNAL_FUNC(clist_mouse_event), window);
-	gtk_signal_connect(GTK_OBJECT(clist), "select_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "select_row",
 			GTK_SIGNAL_FUNC(select_record), window);
-	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row",
 			GTK_SIGNAL_FUNC(unselect_record), id);
 	
 	gtk_widget_show(clist);
@@ -134,7 +137,7 @@ mstatic void xlist_create ( gabywindow *window, gboolean first )
 	for ( i=1; i< subt->nb_fields+1;i++ ) {
 		char buf[100];
 		int width;
-		gtk_clist_set_column_title( GTK_CLIST (clist), i , \
+		gtk_clist_set_column_title( GTK_CLIST (clist), i ,
 				subt->fields[i-1].i18n_name );
 #ifdef DEBUG_GABY
 		debug_print("[xlist:create] col %d : %s\n", i, subt->fields[i-1].i18n_name);
@@ -152,12 +155,12 @@ mstatic void xlist_create ( gabywindow *window, gboolean first )
 #ifdef USE_GNOME
 	if ( GNOME_IS_APP(window->parent)) {
 		/* EXCLUSIVE means it will fill the whole width */
-		dock_item = gnome_dock_item_new ( "Search box", \
-				GNOME_DOCK_ITEM_BEH_EXCLUSIVE | \
+		dock_item = gnome_dock_item_new ( "Search box",
+				GNOME_DOCK_ITEM_BEH_EXCLUSIVE |
 				GNOME_DOCK_ITEM_BEH_NEVER_VERTICAL);
 		gtk_container_add(GTK_CONTAINER(dock_item), hbox);
-		gnome_dock_layout_add_item(GNOME_APP(window->parent)->layout, \
-				GNOME_DOCK_ITEM(dock_item), \
+		gnome_dock_layout_add_item(GNOME_APP(window->parent)->layout,
+				GNOME_DOCK_ITEM(dock_item),
 				GNOME_DOCK_BOTTOM, 0, 0, 0 );
 	} else {
 		/* back to the gtk behaviour */
@@ -168,7 +171,7 @@ mstatic void xlist_create ( gabywindow *window, gboolean first )
 #endif
 
 	gtk_object_set_data(GTK_OBJECT(vbox), "clist", clist );
-	gtk_object_set_data(GTK_OBJECT(vbox), "actmenu", \
+	gtk_object_set_data(GTK_OBJECT(vbox), "actmenu",
 						create_popup_menu(window));
 
 	gtk_widget_set_usize(vbox, 400, 400);
@@ -188,11 +191,11 @@ static void save_column_width ( GtkWidget *mi, gabywindow *window)
 	for ( i=1; i<clist->columns; i++ ) {
 		col = &(clist->column[i]);
 #ifdef DEBUG_GABY
-		debug_print("[xlist:save_column_width] col %d: %d\n", i, \
+		debug_print("[xlist:save_column_width] col %d: %d\n", i,
 				col->width );
 #endif
 		sprintf(buf, "col%d_width", i);
-		write_config_int("gaby_xlist", window->view->subtable->name, \
+		write_config_int("gaby_xlist", window->view->subtable->name,
 				buf, col->width );
 	}
 	
@@ -204,9 +207,13 @@ static GtkWidget* create_popup_menu( gabywindow *window )
 	
 	menu = actions_menu_for_table(window->view->subtable->table,window);
 	
-	item = gtk_menu_item_new();
-	gtk_menu_append(GTK_MENU(menu), item);
-	gtk_widget_show(item);
+	if ( menu != NULL ) {
+		item = gtk_menu_item_new();
+		gtk_menu_append(GTK_MENU(menu), item);
+		gtk_widget_show(item);
+	} else {
+		menu = gtk_menu_new();
+	}
 
 	item = gtk_menu_item_new_with_label( _("Save columns' width") );
 	gtk_signal_connect(GTK_OBJECT(item), "activate", 
@@ -232,7 +239,7 @@ static GtkWidget* create_search_box( gabywindow *window )
 
 	entry = gtk_entry_new();
 	gtk_widget_show(entry);
-	gtk_signal_connect (GTK_OBJECT(entry), "changed", \
+	gtk_signal_connect (GTK_OBJECT(entry), "changed",
 			GTK_SIGNAL_FUNC(search_event), window);
 	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, FALSE, 5);
 	
@@ -241,7 +248,7 @@ static GtkWidget* create_search_box( gabywindow *window )
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 5);
 
 	field_list = gtk_option_menu_new();
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(field_list), \
+	gtk_option_menu_set_menu(GTK_OPTION_MENU(field_list),
 					create_field_list_menu(window));
 	gtk_widget_show(field_list);
 	gtk_box_pack_start (GTK_BOX (hbox), field_list, TRUE, FALSE, 5);	
@@ -259,9 +266,9 @@ static gint xlist_compare(GtkCList *clist, gconstpointer p1, gconstpointer p2)
 	GtkCListRow *row1 = (GtkCListRow*)p1;
 	GtkCListRow *row2 = (GtkCListRow*)p2;
 #if 0	/* this would be better but isn't fast enough */
-	record *r1 = get_record_no(v->subtable->table, \
+	record *r1 = get_record_no(v->subtable->table,
 				atoi( GTK_CELL_TEXT(row1->cell[0])->text ));
-	record *r2 = get_record_no(v->subtable->table, \
+	record *r2 = get_record_no(v->subtable->table,
 				atoi( GTK_CELL_TEXT(row2->cell[0])->text ));
 #endif
 	int field_no = v->subtable->fields[clist->sort_column-1].no;
@@ -292,6 +299,7 @@ static gint xlist_compare(GtkCList *clist, gconstpointer p1, gconstpointer p2)
 			return ( atoi(text1) < atoi(text2) ) ? -1 : 1 ;
 		} break;
 		case T_REAL:
+		case T_DECIMAL:
 		{
 			return ( atof(text1) < atof(text2) ) ? -1 : 1 ;
 		} break;
@@ -317,7 +325,7 @@ static void clist_click_column (GtkCList *clist, gint column, gabywindow *win)
 	view *v = win->view;
 
 #ifdef DEBUG_GABY
-	debug_print("[clist_click_column] Sorting %s\n", \
+	debug_print("[clist_click_column] Sorting %s\n",
 			v->subtable->fields[column-1].i18n_name );
 #endif
 
@@ -367,7 +375,7 @@ mstatic void xlist_fill ( gabywindow *window )
 	
 #ifdef DEBUG_GABY
 	debug_print("[xlist_fill] clist informations:\n");
-	debug_print(" width:%d, height:%d, hoffset:%d, voffset:%d\n", \
+	debug_print(" width:%d, height:%d, hoffset:%d, voffset:%d\n",
 			GTK_CLIST(clist)->clist_window_width,
 			GTK_CLIST(clist)->clist_window_height,
 			GTK_CLIST(clist)->hoffset,
@@ -390,7 +398,7 @@ mstatic void xlist_fill ( gabywindow *window )
 			what = get_conditional_records_list(v->subtable, c);
 			foo = TRUE;
 		}
-		list_fill_real_some(clist, l, search_string, what, \
+		list_fill_real_some(clist, l, search_string, what, 
 							search_field, *id);
 	}
 
@@ -400,7 +408,7 @@ mstatic void xlist_fill ( gabywindow *window )
 
 #ifdef DEBUG_GABY
 	debug_print("[xlist_fill] clist informations (after):\n");
-	debug_print(" width:%d, height:%d, hoffset:%d, voffset:%d\n", \
+	debug_print(" width:%d, height:%d, hoffset:%d, voffset:%d\n",
 			GTK_CLIST(clist)->clist_window_width,
 			GTK_CLIST(clist)->clist_window_height,
 			GTK_CLIST(clist)->hoffset,
@@ -408,16 +416,29 @@ mstatic void xlist_fill ( gabywindow *window )
 #endif
 }
 
+#define USE_CURSOR
+
+#ifdef USE_SQL
+#  ifndef USE_CURSOR
+#    define USE_CURSOR
+#  endif
+#endif
+
 static void list_fill_real_all (GtkWidget *cl, subtable *l, gchar *ss,
 				gint sf, gint id)
 {
 	record *r;
-	int i, j;
+	int j;
 	int row;
 	table *p;
 	GString *strs[l->nb_fields];
 	gchar *a_line[l->nb_fields+1];
 	int len_ss;
+#ifdef USE_CURSOR
+	gabycursor *cs;
+#endif
+	int i=0;
+
 #ifdef DEBUG_GABY
 	debug_print("[xlist:lfra] begin, sf:%d\n", sf);
 #endif
@@ -443,19 +464,25 @@ static void list_fill_real_all (GtkWidget *cl, subtable *l, gchar *ss,
 	 * doesn't already exist.
 	 */
 	
+#ifndef USE_CURSOR
 	for ( i=0; i < p->max_records; i++ ) {
-		
 		r = p->records[i];
 		if ( r == NULL || r->id == 0 )
 			continue;
-		
+#else
+	cs = cursor_declare(p);
+
+	r = cursor_get_first(cs);
+	while ( r ) {
+#endif	
 		sprintf(a_line[0], "%d", r->id);
+
 #ifdef DEBUG_GABY
-		if ( l->table->nb_records < 30 ) {
+/*		if ( l->table->nb_records > 5 && l->table->nb_records < 30 ) {
 			debug_print("[xlist:lfra] id : %d\n", r->id);
 			debug_print("[xlist:lfra] %d (i) on %d (p->max_records)\n",
 					i, p->max_records);
-		}
+		}*/
 #endif
 		
 		for ( j=0; j<l->nb_fields; j++) {
@@ -472,7 +499,7 @@ static void list_fill_real_all (GtkWidget *cl, subtable *l, gchar *ss,
 		}
 
 #ifdef DEBUG_GABY
-		if ( l->table->nb_records < 30 ) {
+		if ( l->table->nb_records > 5 && l->table->nb_records < 30 ) {
 			debug_print("[xlist:lfra] a_line[sf+1] : %s, ss : %s\n",
 					a_line[sf+1], ss );
 		}
@@ -481,11 +508,13 @@ static void list_fill_real_all (GtkWidget *cl, subtable *l, gchar *ss,
 		if ( strncmp_fct(a_line[sf+1], ss, len_ss) == 0 ) {
 #ifdef DEBUG_GABY
 			if ( l->table->nb_records < 30 ) {
-				debug_print("[xlist:lfra] adding %s, %s\n", \
+				debug_print("[xlist:lfra] adding %s, %s\n",
 							a_line[1], a_line[2] );
 			}
 #endif
 			row = gtk_clist_append(GTK_CLIST(cl), a_line);
+			gtk_clist_set_row_data(GTK_CLIST(cl), row, 
+						GINT_TO_POINTER(i));
 			
 			if ( r->id == id ) {
 				/* when using gnomecard the focus stays on the
@@ -494,34 +523,28 @@ static void list_fill_real_all (GtkWidget *cl, subtable *l, gchar *ss,
 				 * change its structure */
 				GTK_CLIST(cl)->focus_row = row;
 				gtk_clist_select_row(GTK_CLIST(cl), row, 0);
-				gtk_clist_moveto(GTK_CLIST(cl), row, -1, \
+				gtk_clist_moveto(GTK_CLIST(cl), row, -1,
 						0.5, 0.5 );
 			}
-#ifdef DEBUG_GABY
-/*			debug_print("[xlist:lfra] we just added %s, %s\n", a_line[1], a_line[2] );*/
-#endif
 		}
 		
 		for ( j=0; j<l->nb_fields; j++) {
-#ifdef DEBUG_GABY
-/*			debug_print("[xlist:lfra] %d, freeing %s (%p)", j, strs[j]->str, strs[j]);*/
-#endif
 			g_string_free(strs[j], 1);
-#ifdef DEBUG_GABY
-/*			debug_print(" ... ok\n");*/
-#endif
 		}
+#ifdef USE_CURSOR
+		r = cursor_get_next(cs);
+		i++;
+#endif
 	}
-#ifdef DEBUG_GABY
-	debug_print("[xlist:lfra] a_line[0] : %p, a_line : %p\n", a_line[0], a_line);
-#endif
 
+	debug_print("[xlist:lfra] a_line[0] : %p, a_line : %p\n", a_line[0], a_line);
+
+	cursor_free(cs);
 	g_free(a_line[0]);
-	
+
 	gtk_clist_thaw(GTK_CLIST(cl));
-#ifdef DEBUG_GABY
+
 	debug_print("[xlist:lfra] finished\n");
-#endif
 }
 
 static void list_fill_real_some (GtkWidget *cl, subtable *l, gchar *ss,
@@ -533,6 +556,7 @@ static void list_fill_real_some (GtkWidget *cl, subtable *l, gchar *ss,
 	table *p;
 	GString *strs[l->nb_fields];
 	int row;
+	int numrec;
 	
 	gtk_clist_freeze(GTK_CLIST(cl));
 	gtk_clist_clear(GTK_CLIST(cl));
@@ -544,10 +568,11 @@ static void list_fill_real_some (GtkWidget *cl, subtable *l, gchar *ss,
 	what = g_list_first(what);
 	
 	while ( what != NULL ) {
-		if ( GPOINTER_TO_INT(what->data) == -1 )
+		numrec = GPOINTER_TO_INT(what->data);
+		if ( numrec == -1 )
 			break;
 		
-		r = p->records[GPOINTER_TO_INT(what->data)];
+		r = p->records[numrec];
 		what = g_list_next(what);
 		
 		sprintf(a_line[0], "%d", r->id);
@@ -560,6 +585,8 @@ static void list_fill_real_some (GtkWidget *cl, subtable *l, gchar *ss,
 		if ( strncmp_fct(a_line[sf+1], ss, strlen(ss)) == 0 ) {
 			
 			row = gtk_clist_append(GTK_CLIST(cl), a_line);
+			gtk_clist_set_row_data(GTK_CLIST(cl), row, 
+						GINT_TO_POINTER(numrec));
 			
 			if ( r->id == id ) {
 				gtk_clist_select_row(GTK_CLIST(cl), row, 0);
@@ -592,7 +619,7 @@ static GtkWidget* create_field_list_menu ( gabywindow *win )
 				GTK_RADIO_MENU_ITEM(menu_item));
 		gtk_object_set_data(GTK_OBJECT(menu_item), "which", 
 				GINT_TO_POINTER(i));
-		gtk_signal_connect(GTK_OBJECT(menu_item), "activate", \
+		gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
 				GTK_SIGNAL_FUNC(search_field_selected), win);
 		gtk_widget_show(menu_item);
 		gtk_menu_append(GTK_MENU(menu), menu_item);
@@ -698,7 +725,7 @@ static void clist_mouse_event (GtkWidget *clist, GdkEventButton *event,
 	/* we only want to catch the 3rd button */
 	if ( event == NULL || event->button != 3 )
 		return;
-	if ( gtk_clist_get_selection_info(GTK_CLIST(clist), \
+	if ( gtk_clist_get_selection_info(GTK_CLIST(clist),
 			(gint)(event->x), (gint)(event->y), &row, &col) == 0 )
 		return;
 #ifdef DEBUG_GABY
@@ -758,6 +785,24 @@ static void search_field_selected ( GtkWidget *mi, gabywindow *window)
 		xlist_fill(window);
 }
 
+mstatic void xlist_get_records(gabywindow *window, GList **records)
+{
+	GtkCList *clist;
+	int i;
+	
+	clist = GTK_CLIST(gtk_object_get_data(GTK_OBJECT(window->widget),
+				"clist"));
+	*records = NULL;
+	for ( i=0; i<clist->rows; i++ ) {
+		*records = g_list_append(*records,
+					 gtk_clist_get_row_data(clist,i));
+	}
+	/* TODO (post-2.0): xlist_get_records working with gabysql
+	 * currently it doesn't because it uses 'fast ids' which are
+	 * a total non-sense in an sql world...
+	 */
+}
+
 /*
  * Below are configurations functions; should they be moved in a
  * different source file ?
@@ -775,11 +820,11 @@ mstatic GtkWidget* xlist_configure (ViewPluginData *vpd)
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox);
 
-	case_check = gtk_check_button_new_with_label( \
+	case_check = gtk_check_button_new_with_label(
 					_("Case sensitive search"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(case_check), \
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(case_check),
 				( (void*)strncmp_fct == (void*)strncmp) );
-	gtk_signal_connect_object(GTK_OBJECT(case_check), "clicked", \
+	gtk_signal_connect_object(GTK_OBJECT(case_check), "clicked",
 		GTK_SIGNAL_FUNC(gaby_property_box_changed), GTK_OBJECT(vbox) );
 	
 	gtk_widget_show (case_check);
@@ -814,7 +859,7 @@ static void configure_save()
 #ifdef USE_GNOME
 	configure_apply();
 #endif
-	write_config_bool("view", "xlist", "case_sensitive_search", \
+	write_config_bool("view", "xlist", "case_sensitive_search",
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(case_check)) );
 
 }
