@@ -1,5 +1,5 @@
 /*  Gaby
- *  Copyright (C) 1998-1999 Frederic Peters
+ *  Copyright (C) 1998-2000 Frederic Peters
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+void do_action_plugin(action *act);
 void do_action_script(action *act);
-void do_action_script_fu (action *act, GList *tables, GList *subtables,
-			  GList *views);
+void do_action_script_fu (action *act);
 
-void launch_startup_scripts(GList *actions, gboolean first_time);
+void launch_startup_scripts(gboolean first_time);
 
 GModule* get_interpreter (gchar *which, gchar *argv[]);
 
