@@ -1,5 +1,5 @@
 /*  Gaby
- *  Copyright (C) 1998-1999 Frederic Peters
+ *  Copyright (C) 1998-2000 Frederic Peters
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ static void close_clicked(GtkButton *button, GtkWidget *win);
 
 static gboolean delete_event(GtkWidget *win, gpointer data);
 
-GtkWidget* configure_dialog ()
+GtkWidget* configure_dialog (gchar *active_page)
 {
 	GList *configureboxes = NULL;
 	GtkWidget *notebook;
@@ -50,6 +50,7 @@ GtkWidget* configure_dialog ()
 	GtkWidget *buttonbox;
 	GtkWidget *ok, *apply, *save, *close;
 #endif
+	int i;
 	
 	gchar *page_name;
 	
@@ -91,11 +92,12 @@ GtkWidget* configure_dialog ()
 	
 	gtk_window_set_title(GTK_WINDOW(configure_window), _("Preferences"));
 	
-	gtk_signal_connect(GTK_OBJECT(configure_window), "delete_event", \
+	gtk_signal_connect(GTK_OBJECT(configure_window), "delete_event", 
 			GTK_SIGNAL_FUNC(delete_event), NULL);
-	gtk_object_set_data(GTK_OBJECT(configure_window), "pages", \
+	gtk_object_set_data(GTK_OBJECT(configure_window), "pages", 
 			configureboxes);
 	
+	i = 0;
 	while ( configureboxes != NULL ) {
 		page_box = configureboxes->data;
 		page_name = gtk_object_get_data(GTK_OBJECT(page_box), "name");
@@ -105,15 +107,19 @@ GtkWidget* configure_dialog ()
 #endif
 		page_label = gtk_label_new(page_name);
 		gtk_widget_show(page_label);
-		gtk_notebook_append_page(GTK_NOTEBOOK(notebook), \
+		gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
 				GTK_WIDGET(page_box), GTK_WIDGET(page_label));
 		configureboxes = g_list_next(configureboxes);
+		if ( active_page && strcmp(active_page, page_name) == 0 ) {
+			gtk_notebook_set_page(GTK_NOTEBOOK(notebook), i);
+		}
+		i++;
 	}
 
 #ifdef USE_GNOME
-	gtk_signal_connect(GTK_OBJECT(configure_window), "apply", \
+	gtk_signal_connect(GTK_OBJECT(configure_window), "apply", 
 			GTK_SIGNAL_FUNC(gnome_apply_clicked), configure_window);
-	gtk_signal_connect(GTK_OBJECT(configure_window), "close", \
+	gtk_signal_connect(GTK_OBJECT(configure_window), "close", 
 			GTK_SIGNAL_FUNC(close_clicked), configure_window );
 	
 #else
@@ -126,24 +132,24 @@ GtkWidget* configure_dialog ()
 	ok = gtk_button_new_with_label(_("OK"));
 	gtk_widget_show(ok);
 	gtk_container_add(GTK_CONTAINER(buttonbox), ok);
-	gtk_signal_connect(GTK_OBJECT(ok), "clicked", \
+	gtk_signal_connect(GTK_OBJECT(ok), "clicked", 
 			GTK_SIGNAL_FUNC(ok_clicked), configure_window);
 
 	apply = gtk_button_new_with_label(_("Apply"));
 	gtk_widget_show(apply);
 	gtk_container_add(GTK_CONTAINER(buttonbox), apply);
-	gtk_signal_connect(GTK_OBJECT(apply), "clicked", \
+	gtk_signal_connect(GTK_OBJECT(apply), "clicked", 
 			GTK_SIGNAL_FUNC(apply_clicked), configure_window);
 
 	save = gtk_button_new_with_label(_("Save"));
 	gtk_widget_show(save);
 	gtk_container_add(GTK_CONTAINER(buttonbox), save);
-	gtk_signal_connect(GTK_OBJECT(save), "clicked", \
+	gtk_signal_connect(GTK_OBJECT(save), "clicked", 
 			GTK_SIGNAL_FUNC(save_clicked), configure_window);
 
 	close = gtk_button_new_with_label(_("Close"));
 	gtk_widget_show(close);
-	gtk_signal_connect(GTK_OBJECT(close), "clicked", \
+	gtk_signal_connect(GTK_OBJECT(close), "clicked", 
 			GTK_SIGNAL_FUNC(close_clicked), configure_window);
 	gtk_container_add(GTK_CONTAINER(buttonbox), close);
 #endif /* ! USE_GNOME */
@@ -166,24 +172,26 @@ static GList* get_actions_configure_boxes(GList *boxes)
 		if ( a->type != PLUG_IN ) continue;
 		if ( ! already_done(a->what.plugin->name, done) ) {
 #ifdef DEBUG_GABY
-			debug_print("Loading %s configuration box\n", \
+			debug_print("Loading %s configuration box\n", 
 						a->what.plugin->name);
 #endif
 			apd = a->what.plugin;
 
 #ifdef FOLLOW_MIGUEL
 			sprintf(plugin_name, "%s_configure", apd->name );
-			g_module_symbol( \
-				g_module_open(NULL, G_MODULE_BIND_LAZY), \
+			g_module_symbol( 
+				g_module_open(NULL, G_MODULE_BIND_LAZY), 
 				plugin_name, (gpointer)&apd->configure );
 #else
 			if ( apd->loaded == 0 ) {
-				sprintf(plugin_name, "%s/actions/lib%s.so", \
-						PLUGINS_DIR, apd->name);
+				sprintf(plugin_name, PLUGINS_DIR "/actions/lib%s" SO_EXTENSION,
+						apd->name);
 				apd->handle = g_module_open(plugin_name, 0);
 				if ( apd->handle == NULL )
 					continue;
-				g_module_symbol(apd->handle, "configure", \
+			}
+			if ( apd->configure == NULL ) {
+				g_module_symbol(apd->handle, "configure", 
 						(gpointer)&apd->configure );
 				if ( apd->configure == NULL ) {
 					g_module_close(apd->handle);
@@ -192,15 +200,12 @@ static GList* get_actions_configure_boxes(GList *boxes)
 				}
 			}
 #endif
-			if ( apd->configure == NULL )
-				continue;
-			
 			box = apd->configure();
 			if ( box != NULL ) {
-				gtk_object_set_data(GTK_OBJECT(box), "type", \
+				gtk_object_set_data(GTK_OBJECT(box), "type", 
 						GINT_TO_POINTER(1) );
 				gtk_object_set_data(GTK_OBJECT(box),"apd",apd);
-				gtk_object_set_data(GTK_OBJECT(box), \
+				gtk_object_set_data(GTK_OBJECT(box), 
 						"gaby_name", a->what.plugin->name);
 				boxes = g_list_append(boxes, box);
 				apd->loaded++;
@@ -267,24 +272,24 @@ static GList* get_views_configure_boxes (GList *boxes)
 
 static void configure_common_save ()
 {
-	GList *pages = gtk_object_get_data( \
+	GList *pages = gtk_object_get_data( 
 			GTK_OBJECT(configure_window), "pages");
 	GtkWidget *common = pages->data;
 	GtkWidget *check;
 
 	check = gtk_object_get_data(GTK_OBJECT(common), "fastprint" );
-	write_config_bool ("common", "print", "fast", \
+	write_config_bool ("common", "print", "fast", 
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check)));
 
 	check = gtk_object_get_data(GTK_OBJECT(common), "tips" );
-	write_config_bool ("common", "misc", "tips", \
+	write_config_bool ("common", "misc", "tips", 
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check)));
 	
 }
 
 static void files_properties_save ()
 {
-	GList *pages = gtk_object_get_data( \
+	GList *pages = gtk_object_get_data( 
 			GTK_OBJECT(configure_window), "pages");
 	GtkWidget *fileprop = pages->next->data;
 	GList *tables = gtk_object_get_data(GTK_OBJECT(fileprop), "tables");
@@ -300,11 +305,11 @@ static void files_properties_save ()
 		tables = g_list_next(tables);
 		while ( tmp != NULL ) {
 			loc = tmp->data;
-			check = gtk_object_get_data(GTK_OBJECT(fileprop), \
+			check = gtk_object_get_data(GTK_OBJECT(fileprop), 
 					loc->filename);
-			loc->disabled = gtk_toggle_button_get_active( \
+			loc->disabled = gtk_toggle_button_get_active( 
 						GTK_TOGGLE_BUTTON(check));
-			write_config_bool("app", appname, loc->filename, \
+			write_config_bool("app", appname, loc->filename, 
 						loc->disabled );
 			tmp = g_list_next(tmp);
 		}
@@ -424,25 +429,25 @@ static GtkWidget* files_properties_box(GList *tables)
 			l = tmp2->data;
 			tmp2 = g_list_next(tmp2);
 			strcpy(plugin_name, l->type);
-			sprintf(str, "%s (%s)", l->filename, \
+			sprintf(str, "%s (%s)", l->filename, 
 					get_plugin_real_name(0,f,plugin_name)) ;
 			check = gtk_check_button_new_with_label (str);
-			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), \
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), 
 							l->disabled);
-			gtk_signal_connect_object(GTK_OBJECT(check), "clicked",\
-				GTK_SIGNAL_FUNC(gaby_property_box_changed), \
+			gtk_signal_connect_object(GTK_OBJECT(check), "clicked",
+				GTK_SIGNAL_FUNC(gaby_property_box_changed), 
 				GTK_OBJECT(vbox) );
 			gtk_widget_show(check);
-			gtk_object_set_data(GTK_OBJECT(vbox), l->filename, \
+			gtk_object_set_data(GTK_OBJECT(vbox), l->filename, 
 					check);
-			gtk_box_pack_start(GTK_BOX(vbox2), check, \
+			gtk_box_pack_start(GTK_BOX(vbox2), check, 
 							FALSE, FALSE, 0);
 		}
 	}
 	
 #else
 	clist = gtk_clist_new(1);
-	gtk_signal_connect(GTK_OBJECT(clist), "select_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "select_row", 
 			GTK_SIGNAL_FUNC(select_location), vbox );
 
 	while ( tmp != NULL ) {
@@ -480,7 +485,7 @@ static GtkWidget* files_properties_box(GList *tables)
 
 	check = gtk_check_button_new (); gtk_widget_show(check);
 	gtk_table_attach_defaults(GTK_TABLE(table), check, 1, 2, 1, 2);
-	gtk_signal_connect(GTK_OBJECT(check), "clicked", \
+	gtk_signal_connect(GTK_OBJECT(check), "clicked", 
 			GTK_SIGNAL_FUNC(loc_disabled_clicked), vbox);
 	gtk_object_set_data(GTK_OBJECT(vbox), "check_disabled", check);
 
@@ -505,27 +510,28 @@ static GList* get_common_configure_boxes(GList *boxes)
 	gtk_widget_show(vbox);
 
 	check = gtk_check_button_new_with_label(_("Use \"fast\" printing"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), \
+	gtk_widget_set_sensitive(check, FALSE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), 
 			get_config_bool("common", "print", "fast", FALSE ) );
-	gtk_signal_connect_object(GTK_OBJECT(check), "clicked", \
-			GTK_SIGNAL_FUNC(gaby_property_box_changed), \
+	gtk_signal_connect_object(GTK_OBJECT(check), "clicked", 
+			GTK_SIGNAL_FUNC(gaby_property_box_changed), 
 			GTK_OBJECT(vbox) );
 	gtk_widget_show(check);
 	gtk_object_set_data(GTK_OBJECT(vbox), "fastprint", check);
 	gtk_box_pack_start(GTK_BOX(vbox), check, TRUE, TRUE, 0 );
 	
 	check = gtk_check_button_new_with_label(_("Show tips on startup"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), \
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), 
 			get_config_bool("common", "misc", "tips", TRUE ) );
-	gtk_signal_connect_object(GTK_OBJECT(check), "clicked", \
-			GTK_SIGNAL_FUNC(gaby_property_box_changed), \
+	gtk_signal_connect_object(GTK_OBJECT(check), "clicked", 
+			GTK_SIGNAL_FUNC(gaby_property_box_changed), 
 			GTK_OBJECT(vbox) );
 	gtk_widget_show(check);
 	gtk_object_set_data(GTK_OBJECT(vbox), "tips", check);
 	gtk_box_pack_start(GTK_BOX(vbox), check, TRUE, TRUE, 0 );
 
 	
-	gtk_object_set_data(GTK_OBJECT(vbox), "cfg_save", \
+	gtk_object_set_data(GTK_OBJECT(vbox), "cfg_save", 
 							configure_common_save);
 	gtk_object_set_data(GTK_OBJECT(vbox), "name", _("Misc"));
 	boxes = g_list_append(boxes, vbox);
@@ -538,6 +544,7 @@ static GList* get_common_configure_boxes(GList *boxes)
 
 static GList* get_print_configure_boxes(GList *boxes)
 {
+#if 0
 	PrintPluginData *ppd;
 	GtkWidget* (*configure) ();
 	GtkWidget *box;
@@ -598,13 +605,14 @@ static GList* get_print_configure_boxes(GList *boxes)
 #if 1
 			gtk_object_set_data(GTK_OBJECT(box), "ppd", ppd);
 			if ( ! gtk_object_get_data(GTK_OBJECT(box), "name") ) {
-				gtk_object_set_data(GTK_OBJECT(box), "name", \
+				gtk_object_set_data(GTK_OBJECT(box), "name", 
 							ppd->i18n_name);
 			}
 #endif /* 0 */
 			boxes = g_list_append(boxes, box);
 		}
 	}
+#endif
 	
 	return boxes;
 }
@@ -736,6 +744,7 @@ static void free_one(GtkWidget *page, gpointer data)
 		}
 	}
 
+#if 0
 	ppd = gtk_object_get_data(GTK_OBJECT(page), "ppd");
 	if ( ppd != NULL ) {
 		ppd->loaded--;
@@ -747,6 +756,7 @@ static void free_one(GtkWidget *page, gpointer data)
 			ppd->handle = NULL;
 		}
 	}
+#endif
 #endif /* ! FOLLOW_MIGUEL */
 }
 
