@@ -16,7 +16,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-GtkWidget* configure_dialog (void);
+GtkWidget* configure_dialog (gchar *active_page);
 
 void gaby_property_box_changed (gpointer data);
 
