@@ -17,19 +17,13 @@
  */
 
 #include "gtk_config_dlg.h"
+#include "gtk_print_dlg.h"
 
 GtkWidget* windows_binding_dialog();
 
-
 GtkWidget* management_dialog(GList *tables);
 
 void import_export_dialog(subtable *st, int type);
 void import_real_callback(subtable *st);
 void export_real_callback(subtable *st);
 
-char* get_plugin_real_name(int type, FILE *f, char *name);
-
-GList* print_plugin_get_list(gchar *name);
-
-GtkWidget* print_dialog (PrintPluginData *ppd);
-
