@@ -76,7 +76,7 @@ GtkWidget* management_dialog(GList *tables)
 	int i;
 
 #ifndef USE_GNOME
-	gaby_errno = ONLY_IN_GNOME;
+	gaby_errno = ONLY_IN_GNOME;	/* useless, skip it */
 	gaby_perror_in_a_box();
 	return NULL;
 #endif
@@ -84,7 +84,7 @@ GtkWidget* management_dialog(GList *tables)
 		return dialog;
 
 #ifdef USE_GNOME
-	dialog = gnome_dialog_new(_("Files management"), \
+	dialog = gnome_dialog_new(_("Files management"), 
 			GNOME_STOCK_BUTTON_CLOSE, NULL );
 	gnome_dialog_set_close(GNOME_DIALOG(dialog), TRUE );
 	vbox = GNOME_DIALOG(dialog)->vbox;
@@ -99,7 +99,7 @@ GtkWidget* management_dialog(GList *tables)
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 0 );
 	
 	list = gtk_clist_new(1);
-	gtk_signal_connect(GTK_OBJECT(list), "select_row", \
+	gtk_signal_connect(GTK_OBJECT(list), "select_row", 
 			GTK_SIGNAL_FUNC(row_selected), dialog );
 	gtk_widget_set_usize(list, 200, -1);
 	gtk_object_set_data(GTK_OBJECT(dialog), "list", list);
@@ -204,7 +204,7 @@ static void row_changed( GtkCList *clist, gint row, gint column,
 			 GdkEventButton *event, GtkWidget *wid)
 {
 #ifdef USE_GNOME
-	gnome_dialog_set_sensitive(GNOME_DIALOG(wid), 0, \
+	gnome_dialog_set_sensitive(GNOME_DIALOG(wid), 0, 
 					( clist->selection != NULL ) );
 #else
 	gtk_widget_set_sensitive(wid, ( clist->selection != NULL ) );
@@ -221,9 +221,9 @@ void select_subtable_dialog(GList *subtables, GtkSignalFunc ok_cb, gchar *text )
 #endif
 
 #ifdef USE_GNOME
-	dialog = gnome_dialog_new(_("Select a subtable"), \
-				GNOME_STOCK_BUTTON_OK, \
-				GNOME_STOCK_BUTTON_CANCEL, \
+	dialog = gnome_dialog_new(_("Select a subtable"), 
+				GNOME_STOCK_BUTTON_OK, 
+				GNOME_STOCK_BUTTON_CANCEL, 
 				NULL );
 	gnome_dialog_set_close(GNOME_DIALOG(dialog), TRUE );
 	vbox = GNOME_DIALOG(dialog)->vbox;
@@ -235,14 +235,14 @@ void select_subtable_dialog(GList *subtables, GtkSignalFunc ok_cb, gchar *text )
 	
 	button = gtk_button_new_with_label(_("OK"));
 	gtk_widget_show(button);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, \
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, 
 				FALSE, FALSE, 0 );
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", ok_cb, dialog );
 	buttonok = button;
 
 	button = gtk_button_new_with_label(_("Cancel"));
 	gtk_widget_show(button);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, \
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, 
 				FALSE, FALSE, 0 );
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", close_dialog, dialog);
 #endif
@@ -256,21 +256,21 @@ void select_subtable_dialog(GList *subtables, GtkSignalFunc ok_cb, gchar *text )
 	
 	subtables = g_list_first(subtables);
 	while ( subtables != NULL ) {
-		gtk_clist_append(GTK_CLIST(clist), \
+		gtk_clist_append(GTK_CLIST(clist), 
 				&((subtable*)subtables->data)->i18n_name );
 		subtables = g_list_next(subtables);
 	}
 
 #ifdef USE_GNOME
-	gtk_signal_connect(GTK_OBJECT(clist), "select_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "select_row", 
 						row_changed, dialog );
-	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", 
 						row_changed, dialog );
 	row_changed(GTK_CLIST(clist), 0, 0, NULL, dialog);
 #else
-	gtk_signal_connect(GTK_OBJECT(clist), "select_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "select_row", 
 						row_changed, buttonok );
-	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", \
+	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row", 
 						row_changed, buttonok );
 	row_changed(GTK_CLIST(clist), 0, 0, NULL, buttonok);
 #endif
@@ -305,11 +305,14 @@ static void import_really_real_callback(GtkWidget *but, GtkWidget *dialog)
 	GList *orig = plugin_list;
 	subtable *st = gtk_object_get_data(GTK_OBJECT(dialog), "subtable");
 	struct location locat;
-	struct location *loc, *new_loc;
+	struct location *new_loc;
 	char plugin_file[PATH_MAX];
 #ifndef FOLLOW_MIGUEL
 	GModule *handle;
 	gboolean (*load_file) (struct location *loc);
+	char fctname[100];
+#else
+	struct location *loc;
 #endif
 	gboolean success = FALSE;
 	int i;
@@ -323,14 +326,14 @@ static void import_really_real_callback(GtkWidget *but, GtkWidget *dialog)
 
 	plugin = (char*)gtk_object_get_data(GTK_OBJECT(dialog), "plugin");
 	
-	sprintf(plugin_file, "%s/formats/lib%s.so", PLUGINS_DIR, plugin);
+	sprintf(plugin_file, PLUGINS_DIR "/formats/lib%s" SO_EXTENSION, plugin);
 #ifdef DEBUG_GABY
 	debug_print("[irrc] importing with %s\n", plugin_file );
 #endif
 
 	new_loc = g_list_first(st->table->locations)->data;
 	
-	locat.filename = gtk_file_selection_get_filename ( \
+	locat.filename = gtk_file_selection_get_filename ( 
 						GTK_FILE_SELECTION(dialog));
 	locat.type = g_strdup(plugin);
 	locat.offset = new_loc->max_index + 1;
@@ -339,7 +342,8 @@ static void import_really_real_callback(GtkWidget *but, GtkWidget *dialog)
 #ifndef FOLLOW_MIGUEL
 	handle = g_module_open(plugin_file, 0 );
 	if ( handle != NULL ) {
-		g_module_symbol(handle, "load_file", (gpointer)&load_file);
+		sprintf(fctname, "%s_load_file", plugin);
+		g_module_symbol(handle, fctname, (gpointer)&load_file);
 		if ( load_file != NULL ) {
 			success = load_file(&locat);
 		}
@@ -392,9 +396,15 @@ static void export_really_real_callback(GtkWidget *but, GtkWidget *dialog)
 	GList *orig = plugin_list;
 	subtable *st = gtk_object_get_data(GTK_OBJECT(dialog), "subtable");
 	char plugin_file[PATH_MAX];
-	struct location loc;
+	struct location locat;
+#ifndef FOLLOW_MIGUEL
 	GModule *handle;
 	gboolean (*save_file) (struct location *loc);
+	char fctname[100];
+#else
+	struct location *loc;
+#endif
+	char *plugin;
 	gboolean success = FALSE;
 
 	/* 
@@ -402,28 +412,34 @@ static void export_really_real_callback(GtkWidget *but, GtkWidget *dialog)
 	 *  look this to know if they save only the records from a given
 	 *  location (!= NULL) or every record (==NULL)
 	 */
-	sprintf(plugin_file, "%s/formats/lib%s.so", PLUGINS_DIR, \
-		(char*)gtk_object_get_data(GTK_OBJECT(dialog), "plugin") );
+	plugin = (char*)gtk_object_get_data(GTK_OBJECT(dialog), "plugin");
+	sprintf(plugin_file, PLUGINS_DIR "/formats/lib%s" SO_EXTENSION, plugin);
 #ifdef DEBUG_GABY
 	debug_print("[irrc] exporting with %s\n", plugin_file );
 #endif
 
-	loc.filename = gtk_file_selection_get_filename ( \
+	locat.filename = gtk_file_selection_get_filename ( 
 						GTK_FILE_SELECTION(dialog));
-	loc.type = NULL;
-	loc.offset = 0;
-	loc.table = st->table;
+	locat.type = NULL;
+	locat.offset = 0;
+	locat.table = st->table;
 		
+#ifndef FOLLOW_MIGUEL
 	handle = g_module_open(plugin_file, 0 );
 	if ( handle != NULL ) {
-		g_module_symbol(handle, "save_file", (gpointer)&save_file);
+		sprintf(fctname, "%s_save_file", plugin);
+		g_module_symbol(handle, fctname, (gpointer)&save_file);
 		if ( save_file != NULL ) {
-			success = save_file(&loc);
+			success = save_file(&locat);
 		}
 		g_module_close(handle);
 	}
+#else
+	loc = &locat;
+#include "py_lf.c"
+	success = TRUE;
+#endif
 
-	/* we allocated them, it's now time to free them */
 	while ( plugin_list != NULL ) {
 		g_free(plugin_list->data);
 		plugin_list = g_list_next(plugin_list);
@@ -453,7 +469,7 @@ static void format_selected(GtkWidget *item, GtkWidget *dialog)
 void import_export_dialog(subtable *st, gint type)
 {
 	GtkWidget *dialog;
-	GtkWidget *hbox;
+	GtkWidget *hbox, *frame;
 	GtkWidget *label, *om, *om_menu, *om_item;
 #ifndef FOLLOW_MIGUEL
 	DIR *dir;
@@ -461,10 +477,12 @@ void import_export_dialog(subtable *st, gint type)
 	char dirname[PATH_MAX];
 	char message[1000];
 #endif
+	gboolean is_first = TRUE;
 	int flg = 0;
 	char *plugin;
 	GList *plugin_list = NULL;
 	FILE *f;
+	int lensoext = strlen(SO_EXTENSION);
 
 	if ( type == 0 ) {
 		dialog = gtk_file_selection_new(_("Import from"));
@@ -472,19 +490,19 @@ void import_export_dialog(subtable *st, gint type)
 		dialog = gtk_file_selection_new(_("Export to"));
 	}
 
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button), \
-			"clicked", \
-			( type == 0 ) ? import_really_real_callback : \
+	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button), 
+			"clicked", 
+			( type == 0 ) ? import_really_real_callback : 
 					export_really_real_callback,
 			dialog );
-	gtk_signal_connect( \
-			GTK_OBJECT(GTK_FILE_SELECTION(dialog)->cancel_button),\
+	gtk_signal_connect( 
+			GTK_OBJECT(GTK_FILE_SELECTION(dialog)->cancel_button),
 			"clicked", close_dialog, dialog );
 			
 	
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_widget_show(hbox);
-	gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(dialog)->main_vbox), \
+	gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(dialog)->main_vbox), 
 				hbox, TRUE, TRUE, 3 );
 	
 	label = gtk_label_new(_("Format :"));
@@ -511,25 +529,30 @@ void import_export_dialog(subtable *st, gint type)
 	while ( 1 ) {
 		ent = readdir(dir);
 		if ( ent == NULL ) break;
-		if ( strncmp(ent->d_name, "lib", 3) == 0 && \
-			strncmp( ent->d_name + strlen(ent->d_name) - 3, \
-				".so", 3) == 0 ) {
+		if ( strncmp(ent->d_name, "lib", 3) == 0 && 
+			strncmp( ent->d_name + strlen(ent->d_name) - lensoext,
+				SO_EXTENSION, lensoext) == 0 ) {
 			strcpy(dirname, ent->d_name+3);
 			strchr(dirname, '.')[0] = 0;
 			if (! format_plugin_can_do(f, dirname, st->table, type))
 				continue;
 			plugin = g_strdup(dirname);
-			om_item = gtk_menu_item_new_with_label( \
+			om_item = gtk_menu_item_new_with_label( 
 					get_plugin_real_name(0, f, dirname) );
 			plugin_list = g_list_append(plugin_list, plugin);
 			
+			if ( is_first ) {
+				gtk_object_set_data(GTK_OBJECT(dialog),
+						"plugin", plugin );
+				is_first = FALSE;
+			}
 			if ( flg == 0 ) {
-				gtk_object_set_data(GTK_OBJECT(dialog), \
+				gtk_object_set_data(GTK_OBJECT(dialog), 
 						"plugin", plugin );
 			}
-			gtk_object_set_data(GTK_OBJECT(om_item), "plugin", \
+			gtk_object_set_data(GTK_OBJECT(om_item), "plugin", 
 					plugin );
-			gtk_signal_connect(GTK_OBJECT(om_item), "activate", \
+			gtk_signal_connect(GTK_OBJECT(om_item), "activate", 
 					format_selected, dialog );
 			gtk_widget_show(om_item);
 			gtk_menu_append(GTK_MENU(om_menu), om_item);
@@ -553,17 +576,22 @@ void import_export_dialog(subtable *st, gint type)
 			if (! format_plugin_can_do(f, name, st->table, type))
 				continue;
 			plugin = g_strdup(name);
-			om_item = gtk_menu_item_new_with_label( \
+			om_item = gtk_menu_item_new_with_label( 
 					get_plugin_real_name(0, f, name) );
 			plugin_list = g_list_append(plugin_list, plugin);
 			
+			if ( is_first ) {
+				gtk_object_set_data(GTK_OBJECT(dialog),
+						"plugin", plugin );
+				is_first = FALSE;
+			}
 			if ( flg == 0 ) {
-				gtk_object_set_data(GTK_OBJECT(dialog), \
+				gtk_object_set_data(GTK_OBJECT(dialog), 
 						"plugin", plugin );
 			}
-			gtk_object_set_data(GTK_OBJECT(om_item), "plugin", \
+			gtk_object_set_data(GTK_OBJECT(om_item), "plugin", 
 					plugin );
-			gtk_signal_connect(GTK_OBJECT(om_item), "activate", \
+			gtk_signal_connect(GTK_OBJECT(om_item), "activate", 
 					format_selected, dialog );
 			gtk_widget_show(om_item);
 			gtk_menu_append(GTK_MENU(om_menu), om_item);
@@ -578,6 +606,19 @@ void import_export_dialog(subtable *st, gint type)
 	gtk_widget_show(om);
 	gtk_box_pack_start(GTK_BOX(hbox), om, TRUE, TRUE, 0 );
 
+	if ( type == 0 ) { /* import */
+		frame = gtk_frame_new("");
+		gtk_widget_show(frame);
+		label = gtk_label_new(
+			_("Please note that the fields of the imported file\n"
+			  "have to be the same as the ones of the table."));
+		gtk_widget_show(label);
+		gtk_container_add(GTK_CONTAINER(frame), label);
+		gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION
+						(dialog)->main_vbox),
+						frame, TRUE, TRUE, 0 );
+	}
+
 	gtk_object_set_data(GTK_OBJECT(dialog), "subtable", st);
 	gtk_object_set_data(GTK_OBJECT(dialog), "plugin_list", plugin_list );
 	gtk_widget_show(dialog);
@@ -603,8 +644,8 @@ void import_real_callback(subtable *st)
 		return;
 	}
 	
-	gtk_clist_get_text(GTK_CLIST(clist), \
-			GPOINTER_TO_INT(GTK_CLIST(clist)->selection->data), \
+	gtk_clist_get_text(GTK_CLIST(clist), 
+			GPOINTER_TO_INT(GTK_CLIST(clist)->selection->data), 
 			0, &text );
 	
 	st = get_subtable_pointer(subtables, text);
@@ -637,8 +678,8 @@ void export_real_callback(subtable *st)
 		return;
 	}
 
-	gtk_clist_get_text(GTK_CLIST(clist), \
-			GPOINTER_TO_INT(GTK_CLIST(clist)->selection->data), \
+	gtk_clist_get_text(GTK_CLIST(clist), 
+			GPOINTER_TO_INT(GTK_CLIST(clist)->selection->data), 
 			0, &text );
 	
 	st = get_subtable_pointer(subtables, text);
