@@ -1,5 +1,5 @@
 /*  Gaby
- *  Copyright (C) 1998-1999 Frederic Peters
+ *  Copyright (C) 1998-2000 Frederic Peters
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,3 +30,11 @@ void wait_dialog_to_finish(gboolean *val) { return; }
 
 gboolean gaby_quit() { exit(0); return TRUE; }
 
+void page_select_fields_get_info(subtable *st, void *page,
+				 gboolean *active, int *selected) {}
+void page_select_records_get_info(subtable *st, void *page,
+				  gboolean *all, GList **recs) {}
+void page_select_order_get_info(subtable *st, void *page, int *order) {}
+
+int debug_mode;
+
