@@ -20,8 +20,16 @@
 #include "f_desc.h"
 #include "records.h"
 
-extern gboolean updated;        /* defined in tables.c */
+#ifdef USE_SQL
+#  include <postgres.h>
+#  include <libpq-fe.h>
+extern PGconn *sqlconn;
+extern void create_record_from_sql_res(table *t, PGresult *res, int n);
+#endif
 
+#include <math.h>
+
+#ifdef USE_SQL
 /**
  * get_record_no
  * @t: table in which the record is searched
@@ -32,7 +40,23 @@ extern gboolean updated;        /* defined in tables.c */
  *
  * Returns: Pointer to a record (NULL if not found)
  **/
+record* get_record_no(table *t, int id)
+{
+	PGresult *res;
+	char sqlstr[1024];
 
+	debug_print("get_record_no called with id == %d\n", id);
+	if ( id <= 0 ) return NULL;
+
+	sprintf(sqlstr, "SELECT * from %s WHERE id = %d", t->name, id);
+	res = PQexec(sqlconn, sqlstr);
+
+	create_record_from_sql_res(t, res, 0);
+	t->records[0]->id = id;
+
+	return t->records[0];
+}
+#else /* ! USE_SQL */
 record* get_record_no(table *t, int id)
 {
 	int i;
@@ -43,11 +67,10 @@ record* get_record_no(table *t, int id)
 		if ( t->records[i]->id == id )
 			return t->records[i];
 	}
-#ifdef DEBUG_GABY
 	debug_print("Sorry, record didn't exist.\n");
-#endif
 	return NULL;
 }
+#endif /* ! USE_SQL */
 
 #if 0
 /* it's currently best to use get_subtable_linked_field (see below) */
@@ -70,8 +93,8 @@ void get_subtable_record(subtable *st, int id, record *r)
 		if ( st->table->fields[st->fields[i].no].type == T_RECORD ) {
 			r->cont[i].str = g_string_new("");
 			id_inside = intable->cont[st->fields[i].no].i;
-			t = (field_get_property( \
-				&st->table->fields[st->fields[i].no], \
+			t = (field_get_property( 
+				&st->table->fields[st->fields[i].no], 
 				"from"))->val;
 /*			t = st->table->fields[st->fields[i].no].more.from; */
 			riot = get_record_no(t, id_inside);
@@ -81,7 +104,7 @@ void get_subtable_record(subtable *st, int id, record *r)
 			/* the caller will have to free this */
 			s = r->cont[i].str;
 			while ( l != NULL ) {
-				s = g_string_append(s, \
+				s = g_string_append(s, 
 					riot->cont[GPOINTER_TO_INT(l->data)].str->str);
 				s = g_string_append(s, " ");
 				l = g_list_next(l);
@@ -101,7 +124,7 @@ GString* get_subtable_record_field(subtable *st, record *riot, int field_no)
 	l = st->fields[field_no].link_format;
 	
 	while ( l != NULL ) {
-		str = g_string_append(str, \
+		str = g_string_append(str, 
 			riot->cont[GPOINTER_TO_INT(l->data)].str->str);
 		str = g_string_append(str, " ");
 		l = g_list_next(l);
@@ -156,11 +179,13 @@ GString* get_stringed_date(GDate *date)
 	GString *str;
 	gchar st[128];
 
-	/* TODO : internal support for more date formats
+	/* TODO (post-2.0): internal support for more date formats
 	 *  this is really easy, let's make it harder :)
 	 *  it would be cool to provide the user a way to define exactly
 	 *  how he wants dates, this setup is good for a default value but
 	 *  something complex must be done (oh no :) )
+	 *
+	 * delayed since we can rely on glib for now
 	 */
 	st[0] = 0;
 	
@@ -197,6 +222,28 @@ GString* get_table_stringed_field(table *t, record *r, int field_no)
 	debug_print("[gssf] record %d (%p)\n", id, r );
 	*/
 #endif
+	if ( r == NULL ) {
+		property *p;
+		p = field_get_property(&t->fields[field_no], "default");
+		if ( p != NULL ) {
+			if ( t->fields[field_no].type == T_STRING ) {
+				str = g_string_new(((GString*)(p->val))->str);
+				return str;
+			} else {
+				/* TODO (post-2.0): default value for other
+				 * types; actually I would need a function who
+				 * would take 'union data*, field_type' and
+				 * return a string; much like this function but
+				 * with a smaller scope (this function would
+				 * use it)
+				 * Delayed after 2.0 since it is really not
+				 * critical */
+				return g_string_new("");
+			}
+		} else {
+			return g_string_new("");
+		}
+	}
 
 	id = r->id;
 
@@ -204,8 +251,13 @@ GString* get_table_stringed_field(table *t, record *r, int field_no)
 		case T_STRING:
 		case T_STRINGS:
 		case T_MULTIMEDIA:
+		case T_FILE:
 		{
-			str = g_string_new(r->cont[field_no].str->str);
+			if ( r->cont[field_no].str ) {
+				str = g_string_new(r->cont[field_no].str->str);
+			} else {
+				str = g_string_new("");
+			}
 		} break;
 		case T_RECORD:
 		case T_INTEGER:
@@ -230,6 +282,13 @@ GString* get_table_stringed_field(table *t, record *r, int field_no)
 				str = g_string_new(_("no"));
 			}
 		} break;
+		case T_DECIMAL:
+		{
+			/* TODO (post-2.0): decimal, handling precision */
+			str = g_string_new("");
+			g_string_sprintf(str, "%.2f", r->cont[field_no].i/100.0);
+			debug_print("[get_table_stringed_field] decimal: %s\n", str->str);
+		} break;
 		default:
 		{
 			str = g_string_new("");
@@ -390,7 +449,9 @@ gboolean record_check(table *t, record *r)
 		NULL,			/* T_BOOLEAN	*/
 		NULL,			/* T_RECORD	*/
 		NULL,			/* T_RECORDS	*/
-		NULL			/* T_MULTIMEDIA */
+		NULL,			/* T_MULTIMEDIA */
+		NULL,			/* T_DECIMAL	*/
+		NULL			/* T_FILE	*/
 	};
 
 	for ( i=0; i < t->nb_fields; i++ ) {
@@ -417,8 +478,9 @@ gboolean record_check(table *t, record *r)
  * Returns: a GList filled with positions (not id !) of records in the related
  * table (or filled with -1 if no related records)
  */
-	/* FIXME: why not simply return NULL for an empty list ? */
 GList* get_related_records(st_field *sf, int id)
+	/* why not simply return NULL for an empty list ?
+	 * (because NULL is sometimes interpreted as 'every records') */
 {
 	/*
 	 * the GList _have_ to be freed by the caller !
@@ -455,7 +517,7 @@ GList* get_related_records(st_field *sf, int id)
 #ifdef DEBUG_GABY
 				debug_print("[grr] found : %d\n", i);
 #endif
-				list = g_list_append(list, \
+				list = g_list_append(list, 
 						GINT_TO_POINTER(i));
 			}
 		}
@@ -488,7 +550,7 @@ GList* get_conditional_records_list(subtable *st, condition *other)
 	record *r;
 	
 	c.type = C_AND;
-	c.true = TRUE;
+	c.val_true = TRUE;
 	c.field_no = 0;
 	c.c.conditions = NULL;
 	if ( st->cond != NULL ) {
@@ -513,8 +575,8 @@ GList* get_conditional_records_list(subtable *st, condition *other)
 }
 
 /*
- * starting today (May 20th 1999), I begin to test these functions (they exist
- * since March 29th).
+ * starting today (May 20th 1999), I begin to test the comparison functions
+ * (they exist since March 29th).
  *
  * The current status is :
  *
@@ -536,17 +598,9 @@ GList* get_conditional_records_list(subtable *st, condition *other)
  *  (example: 15972 and 1.1237 both start with 1 -- useful ?)
  */
 
-static gboolean cnd_is		(union data a, GString *b, field_type type);
-static gboolean cnd_is_not	(union data a, GString *b, field_type type);
-static gboolean cnd_is_greater	(union data a, GString *b, field_type type);
-static gboolean cnd_is_less	(union data a, GString *b, field_type type);
-static gboolean cnd_start_with	(union data a, GString *b, field_type type);
-static gboolean cnd_has		(union data a, GString *b, field_type type);
-static gboolean cnd_regex	(union data a, GString *b, field_type type);
-
 gboolean record_meets_condition(table *t, record *r, condition *c)
 {
-	typedef gboolean (*cnd_fct) (union data, GString*, field_type);
+	typedef gboolean (*cnd_fct) (union data, char*, field_type);
 	cnd_fct function[] = {
 		NULL,			/* C_OR */
 		NULL,			/* C_AND */
@@ -568,34 +622,34 @@ gboolean record_meets_condition(table *t, record *r, condition *c)
 		
 		case C_OR:
 		{
-			if ( c->c.conditions == NULL ) return c->true;
+			if ( c->c.conditions == NULL ) return c->val_true;
 			tmp = g_list_first(c->c.conditions);
 			while ( tmp != NULL ) {
 				c2 = tmp->data;
 				if ( record_meets_condition(t, r, c2) )
-					return c->true;
+					return c->val_true;
 				tmp = g_list_next(tmp);
 			}
-			return (! c->true);
+			return (! c->val_true);
 		} break;
 		
 		case C_AND:
 		{
-			if ( c->c.conditions == NULL ) return c->true;
+			if ( c->c.conditions == NULL ) return c->val_true;
 			tmp = g_list_first(c->c.conditions);
 			while ( tmp != NULL ) {
 				c2 = tmp->data;
 				if ( ! record_meets_condition(t, r, c2) )
-					return ( ! c->true );
+					return ( ! c->val_true );
 				tmp = g_list_next(tmp);
 			}
-			return c->true;
+			return c->val_true;
 		} break;
 		
 		case C_IS:
 		case C_IS_NOT: /*
 				*  this should be removed and
-				*  c->true = FALSE used instead
+				*  c->val_true = FALSE used instead
 				*
 				*  this may also stay like this : "there's more
 				*  than one way to do it" - Larry Wall
@@ -606,37 +660,37 @@ gboolean record_meets_condition(table *t, record *r, condition *c)
 		case C_HAS:
 		case C_REGEX:
 		{
-			return ( function[c->type] ( r->cont[c->field_no], \
-						c->c.val, \
+			return ( function[c->type] ( r->cont[c->field_no], 
+						c->c.val->str, 
 						t->fields[c->field_no].type
-						   ) == c->true );
+						   ) == c->val_true );
 		} break;
 #if 0
-			return cnd_is( r->cont[c->field_no], \
+			return cnd_is( r->cont[c->field_no], 
 				c->c.vals.v1, t->fields[c->field_no].type );
 		case C_IS_NOT:
 		{
-			return cnd_is_not( r->cont[c->field_no], \
+			return cnd_is_not( r->cont[c->field_no], 
 				c->c.vals.v1, t->fields[c->field_no].type );
 		} break;
 		case C_IS_GREATER:
 		{
-			return cnd_is_greater( r->cont[c->field_no], \
+			return cnd_is_greater( r->cont[c->field_no], 
 				c->c.vals.v1, t->fields[c->field_no].type );
 		} break;
 		case C_IS_LESS:
 		{
-			return cnd_is_less( r->cont[c->field_no], \
+			return cnd_is_less( r->cont[c->field_no], 
 				c->c.vals.v1, t->fields[c->field_no].type );
 		} break;
 		case C_START_WITH:
 		{
-			return cnd_start_with( r->cont[c->field_no], \
+			return cnd_start_with( r->cont[c->field_no], 
 				c->c.vals.v1, t->fields[c->field_no].type );
 		} break;
 		case C_HAS:
 		{
-			return cnd_has( r->cont[c->field_no], \
+			return cnd_has( r->cont[c->field_no], 
 				c->c.vals.v1, t->fields[c->field_no].type );
 		} break;
 #endif
@@ -648,7 +702,7 @@ gboolean record_meets_condition(table *t, record *r, condition *c)
 	return TRUE;
 }
 
-static gboolean cnd_is (union data a, GString *b, field_type type)
+gboolean cnd_is (union data a, char *b, field_type type)
 {
 	int t;
 	GDate *dt;
@@ -656,22 +710,25 @@ static gboolean cnd_is (union data a, GString *b, field_type type)
 	switch ( type ) {
 		case T_STRING:
 		case T_STRINGS:
+		case T_MULTIMEDIA:
+		case T_FILE:
 		{
-			return ( strcmp(a.str->str, b->str) == 0 );
+			return ( strcmp(a.str->str, b) == 0 );
 		} break;
 		case T_INTEGER:
 		case T_RECORD:
+		case T_DECIMAL:
 		{
-			return ( a.i == atoi(b->str) );
+			return ( a.i == atoi(b) );
 		} break;
 		case T_REAL:
 		{
-			return ( a.d == atof(b->str) );
+			return ( a.d == atof(b) );
 		} break;
 		case T_DATE:
 		{
 			dt = g_date_new();
-			g_date_set_parse(dt, b->str);
+			g_date_set_parse(dt, b);
 			if ( dt->month == G_DATE_BAD_MONTH ) {
 				t = 17;	/* doesn't matter */
 			} else {
@@ -682,8 +739,8 @@ static gboolean cnd_is (union data a, GString *b, field_type type)
 		} break;
 		case T_BOOLEAN:
 		{
-			if ( strcmp(b->str, _("yes")) == 0 || \
-					strcmp(b->str, _("true")) == 0 ) {
+			if ( strcmp(b, _("yes")) == 0 || 
+					strcmp(b, _("true")) == 0 ) {
 				return ( a.b == TRUE );
 			} else {
 				return ( a.b == FALSE );
@@ -703,12 +760,12 @@ static gboolean cnd_is (union data a, GString *b, field_type type)
 	}
 }
 
-static gboolean cnd_is_not(union data a, GString *b, field_type type)
+gboolean cnd_is_not(union data a, char *b, field_type type)
 {
 	return ! ( cnd_is(a, b, type) );
 }
 
-static gboolean cnd_start_with (union data a, GString *b, field_type type)
+gboolean cnd_start_with (union data a, char *b, field_type type)
 {
 	if ( type != T_STRING && type != T_STRINGS ) {
 #ifdef DEBUG_GABY
@@ -717,10 +774,10 @@ static gboolean cnd_start_with (union data a, GString *b, field_type type)
 		return TRUE;
 	}
 
-	return ( strncmp(a.str->str, b->str, strlen(b->str)) == 0 );
+	return ( strncmp(a.str->str, b, strlen(b)) == 0 );
 }
 
-static gboolean cnd_has (union data a, GString *b, field_type type)
+gboolean cnd_has (union data a, char *b, field_type type)
 {
 	if ( type != T_STRING && type != T_STRINGS ) {
 #ifdef DEBUG_GABY
@@ -729,10 +786,10 @@ static gboolean cnd_has (union data a, GString *b, field_type type)
 		return TRUE;
 	}
 
-	return ( strstr(a.str->str, b->str) != NULL );
+	return ( strstr(a.str->str, b) != NULL );
 }
 
-static gboolean cnd_regex (union data a, GString *b, field_type type)
+gboolean cnd_regex (union data a, char *b, field_type type)
 {
 #ifdef HAVE_REGEX_H
 	regex_t regex;
@@ -745,7 +802,7 @@ static gboolean cnd_regex (union data a, GString *b, field_type type)
 		return TRUE;
 	}
 
-	regcomp(&regex, b->str, REG_EXTENDED);
+	regcomp(&regex, b, REG_EXTENDED);
 	result = ( regexec(&regex, a.str->str, 0, NULL, 0) == 0 );
 	regfree(&regex);
 
@@ -755,7 +812,7 @@ static gboolean cnd_regex (union data a, GString *b, field_type type)
 #endif
 }
 
-static gboolean cnd_is_greater (union data a, GString *b, field_type type)
+gboolean cnd_is_greater (union data a, char *b, field_type type)
 {
 	int t;
 	GDate *dt;
@@ -764,20 +821,21 @@ static gboolean cnd_is_greater (union data a, GString *b, field_type type)
 		case T_STRING:
 		case T_STRINGS:
 		{
-			return ( strcmp(a.str->str, b->str) > 0 );
+			return ( strcmp(a.str->str, b) > 0 );
 		} break;
 		case T_INTEGER:
+		case T_DECIMAL:
 		{
-			return ( a.i > atoi(b->str) );
+			return ( a.i > atoi(b) );
 		} break;
 		case T_REAL:
 		{
-			return ( a.d > atof(b->str) );
+			return ( a.d > atof(b) );
 		} break;
 		case T_DATE:
 		{
 			dt = g_date_new();
-			g_date_set_parse(dt, b->str);
+			g_date_set_parse(dt, b);
 			t = g_date_compare(a.date, dt);
 			g_date_free(dt);
 			return ( t > 0 );
@@ -792,7 +850,7 @@ static gboolean cnd_is_greater (union data a, GString *b, field_type type)
 	}
 }
 
-static gboolean cnd_is_less (union data a, GString *b, field_type type)
+gboolean cnd_is_less (union data a, char *b, field_type type)
 {
 	int t;
 	GDate *dt;
@@ -801,20 +859,21 @@ static gboolean cnd_is_less (union data a, GString *b, field_type type)
 		case T_STRING:
 		case T_STRINGS:
 		{
-			return ( strcmp(a.str->str, b->str) < 0 );
+			return ( strcmp(a.str->str, b) < 0 );
 		} break;
 		case T_INTEGER:
+		case T_DECIMAL:
 		{
-			return ( a.i < atoi(b->str) );
+			return ( a.i < atoi(b) );
 		} break;
 		case T_REAL:
 		{
-			return ( a.d < atof(b->str) );
+			return ( a.d < atof(b) );
 		} break;
 		case T_DATE:
 		{
 			dt = g_date_new();
-			g_date_set_parse(dt, b->str);
+			g_date_set_parse(dt, b);
 			t = g_date_compare(a.date, dt);
 			g_date_free(dt);
 			return ( t < 0 );
@@ -841,7 +900,7 @@ int id_record_field(gchar *str, subtable *st, int field_no)
 	GString *thisr;
 
 /*	t = st->table->fields[st->fields[field_no].no].more.from;*/
-	t = (field_get_property( &st->table->fields[st->fields[field_no].no], \
+	t = (field_get_property( &st->table->fields[st->fields[field_no].no], 
 			"from"))->val;
 
 	for ( i=0; i < t->max_records; i++ ) {
@@ -879,6 +938,7 @@ void get_value_for_that_string(union data *val, field_type type, gchar *str)
 		case T_STRING:
 		case T_STRINGS:
 		case T_MULTIMEDIA:
+		case T_FILE:
 		{
 			if ( val->str == NULL )
 				val->str = g_string_new("");
@@ -893,6 +953,10 @@ void get_value_for_that_string(union data *val, field_type type, gchar *str)
 		{
 			val->d = atof(str);
 		} break;
+		case T_DECIMAL:
+		{
+			val->i = (int)(rint(atof(str)*100));
+		} break;
 		case T_DATE:
 		{
 			if ( str && strlen(str) != 0 ) {
@@ -903,6 +967,8 @@ void get_value_for_that_string(union data *val, field_type type, gchar *str)
 					g_date_free(val->date);
 					val->date = NULL;
 				}
+			} else {
+				val->date = NULL;
 			}
 		} break;
 		case T_BOOLEAN:
@@ -910,10 +976,11 @@ void get_value_for_that_string(union data *val, field_type type, gchar *str)
 			/* we assume FALSE unless it is TRUE */
 			val->b = FALSE;
 			
-			/* TODO : strings for boolean type
+			/* TODO (post-2.0) : strings for boolean type
 			 * we only support 'yes' and 'true' as a valid answer,
 			 * should things like 'true', 0, 'on', ... be valid ?
 			 * note that this will need to be handled in cnd_is
+			 * Delayed since it is 'oh so stupid'
 			 */
 			if ( strcmp(str, "yes") == 0 ) {
 				val->b = TRUE;
@@ -949,7 +1016,13 @@ void set_table_stringed_field(table *t, record *r, int field_no, gchar *str)
 	
 	dt = &r->cont[field_no];
 	get_value_for_that_string(dt, t->fields[field_no].type, str);
-	/* updated = TRUE; */
+
+	/* 991227: this was commented (with a global 'updated'). Why ? */
+	/* 000104: 'cause the form plug-in creates a temporary record and use
+	 * this function to set its content */
+	/* Note: those comments were subject to the y2k-bug. What a pain :) */
+	
+	t->updated = t->updated || (r->id != 0);
 }
 
 /**
@@ -976,7 +1049,7 @@ void set_subtable_stringed_field(subtable *st, record *r, int field_no,
 	
 	if ( st->fields[field_no].type == T_RECORD ) {
 		dt->i = id_record_field(str, st, field_no);
-		updated = TRUE;
+		st->table->updated = TRUE;
 		return;
 	}
 	if ( st->fields[field_no].type == T_RECORDS ) return;
@@ -995,6 +1068,8 @@ gboolean records_are_different(table *t, record *r1, record *r2)
 	for ( i=0; i<t->nb_fields; i++ ) {
 		f1 = &r1->cont[i];
 		f2 = &r2->cont[i];
+		if ( f1->anything == f2->anything ) continue;
+						/* this would mean == NULL */
 		if ( ( ! f1->anything &&   f2->anything ) || 
 		     (   f1->anything && ! f2->anything ) ) {
 			return TRUE;
@@ -1003,12 +1078,14 @@ gboolean records_are_different(table *t, record *r1, record *r2)
 			case T_STRING:
 			case T_STRINGS:
 			case T_MULTIMEDIA:
+			case T_FILE:
 			{
 				if ( strcmp(f1->str->str, f2->str->str) != 0 )
 					return TRUE;
 			} break;
 			case T_INTEGER:
 			case T_RECORD:
+			case T_DECIMAL:
 			{
 				if ( f1->i != f2->i ) return TRUE;
 			} break;
