@@ -21,16 +21,20 @@
 #include "tables.h"
 #include "records.h"
 
+#ifdef USE_SQL
+#  include <postgres.h>
+#  include <libpq-fe.h>
+PGconn *sqlconn;        /* connection to the PostgreSQL database */
+#endif
+
 /* how much records do we want to reserve memory for ? */
 #define OPTIMUM_NUMBER	256
 
 /* this allows to popup a dialog asking to save the files when leaving gaby
  * I should add a field to struct table with this information so I won't have
  * to save every thing (ie not my 2845 records long zipcode file)
- * TODO: put the updated flag in struct table
+ * ODOT: put the updated flag in struct table [DONE:991227]
  */
-gboolean updated;
-
 
 #ifdef INDEXES_ARE_ARRAYS
 
@@ -62,7 +66,7 @@ gboolean record_check(table *t, record *r);
  * record_add
  * @t: the table you want to add a record in
  * @r: the record you want to add to the table
- * @check: whether you want to check the new record
+ * @check: whether you want to check the new record against integrity rules
  * @loading: whether you are a loading function
  *
  * Description:
@@ -79,6 +83,63 @@ int record_add(table *t, record *r, gboolean check, gboolean loading)
 	 *  readable information.
 	 *  you can disable the check with the 3rd param
 	 */
+#ifdef USE_SQL
+	char buf[1000];
+	PGresult *res;
+	int i;
+	int new_id;
+
+	debug_print("[record_add (SQL)] --\n");
+
+	g_snprintf(buf, 1000, "SELECT MAX(id)+1 FROM %s", t->name);
+	debug_print("sql statement is %s\n", buf);
+	res = PQexec(sqlconn, buf);
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		debug_print("[record_add (sql)] unable to get new_id :(\n");
+		if (res)
+			PQclear(res);
+		return -1;
+	}
+	new_id = atoi(PQgetvalue(res, 0, 0));
+	PQclear(res);
+
+	if ( new_id == 0 ) new_id++;
+	
+	debug_print("[record_add (sql)] new_id will be %d\n", new_id);
+
+	g_snprintf(buf, 1000, "INSERT INTO %s VALUES ( %d, ", t->name, new_id );
+	
+	for ( i=0; i<t->nb_fields; i++) {
+		GString *str;
+		str = get_table_stringed_field(t, r, i);
+		if ( strlen(str->str) == 0 ) {
+			strcat(buf, "NULL, ");
+		} else {
+			strcat(buf, "'");
+			strcat(buf, str->str);
+			strcat(buf, "', ");
+		}
+		g_string_free(str, 1);
+	}
+	strcpy(buf+strlen(buf)-2, " )");
+
+	debug_print("[record_add] sql statement is:\n%s\n", buf);
+	res = PQexec(sqlconn, buf);
+	if (res == NULL || PQresultStatus(res) != PGRES_COMMAND_OK) {
+		debug_print("[record_add (sql)] add failed :(\n");
+		if (res) {
+			debug_print("[record_add (sql)] reason: %s\n",
+					PQresultErrorMessage(res) );
+			PQclear(res);
+		}
+		return -1;
+	}
+	PQclear(res);
+	
+	r->id = new_id;
+	
+	return 0;
+#else /* ! USE_SQL */
 	int i;
 	struct location *loc;
 	static int last_found_empty = 0;
@@ -93,26 +154,26 @@ int record_add(table *t, record *r, gboolean check, gboolean loading)
 	}
 
 	if ( t->max_records % OPTIMUM_NUMBER == 0 ) {
-		t->records = g_realloc(t->records, sizeof(record*)* \
+		t->records = g_realloc(t->records, sizeof(record*)* 
 			((t->max_records/OPTIMUM_NUMBER)+1)*OPTIMUM_NUMBER);
 #if 1
 	/* I don't know which is better so I kept the old one that I know is
 	 * working. The later _looks_ faster but it didn't show a real
 	 * improvement (gain less than 5ms :) ) after a few tests */
 		for ( i=0; i < OPTIMUM_NUMBER; i++) {
-			t->records[ ((t->max_records/OPTIMUM_NUMBER))* \
+			t->records[ ((t->max_records/OPTIMUM_NUMBER))* 
 					OPTIMUM_NUMBER+i ] = NULL;
 		}
 #else
-		memset( t->records + OPTIMUM_NUMBER * \
-					( t->max_records / OPTIMUM_NUMBER ) , \
+		memset( t->records + OPTIMUM_NUMBER * 
+					( t->max_records / OPTIMUM_NUMBER ) , 
 				0, sizeof(record*) * OPTIMUM_NUMBER);
 #endif
 	}
 
 	if ( r->id == 0 ) {
 		loc = (g_list_first(t->locations))->data;
-		r->id = ++loc->max_index + loc->offset;
+		r->id = (loc->max_index++) + loc->offset;
 	}
 	
 	if ( r->file_loc == NULL) {
@@ -139,8 +200,8 @@ int record_add(table *t, record *r, gboolean check, gboolean loading)
 	if ( ! loading ) {
 		/* half the time spent loading a file was consumed
 		 * in those two lines */
-#ifndef INDEXES_ARE_ARRAYS
-		g_list_insert_sorted(t->indexes[0], r, \
+#  ifndef INDEXES_ARE_ARRAYS
+		g_list_insert_sorted(t->indexes[0], r, 
 					(GCompareFunc)index_sort_id);
 		t->indexes[0] = g_list_first(t->indexes[0]);
 
@@ -152,23 +213,26 @@ int record_add(table *t, record *r, gboolean check, gboolean loading)
 			switch ( t->fields[gl_no_field].type ) {
 				case T_STRING:
 				case T_STRINGS:
+				case T_MULTIMEDIA:
+				case T_FILE:
 				{
-				g_list_insert_sorted(t->indexes[i], r, \
+				g_list_insert_sorted(t->indexes[i], r, 
 					(GCompareFunc)index_sort_str);
 				} break;
 				case T_DATE:
 				{
-				g_list_insert_sorted(t->indexes[i], r, \
+				g_list_insert_sorted(t->indexes[i], r, 
 						(GCompareFunc)g_date_compare);
 				} break;
 				case T_INTEGER:
+				case T_DECIMAL:
 				{
-				g_list_insert_sorted(t->indexes[i], r, \
+				g_list_insert_sorted(t->indexes[i], r, 
 						(GCompareFunc)index_sort_int);
 				} break;
 				case T_REAL:
 				{
-				g_list_insert_sorted(t->indexes[i], r, \
+				g_list_insert_sorted(t->indexes[i], r, 
 						(GCompareFunc)index_sort_real);
 				} break;
 				default:
@@ -177,13 +241,13 @@ int record_add(table *t, record *r, gboolean check, gboolean loading)
 				} break;
 			}
 		}
-#else
+#  else /* INDEXES_ARE_ARRAYS */
 		/* let's add this new record's id to indexes */;
 	
 		
 		for ( i=0; i<t->nb_fields; i++ ) {
 			if ( t->indexes[i] != NULL || i== 0) {
-				t->indexes[i] = g_realloc(t->indexes[i], \
+				t->indexes[i] = g_realloc(t->indexes[i], 
 						t->nb_records * sizeof(int*));
 			}
 		}
@@ -194,17 +258,19 @@ int record_add(table *t, record *r, gboolean check, gboolean loading)
 			
 			if ( t->indexes[i] == NULL ) continue;
 			p = index_find(t, i-1, r, FALSE);
-			memmove(t->indexes[i] + p + 1, t->indexes[i] + p, \
+			memmove(t->indexes[i] + p + 1, t->indexes[i] + p, 
 					sizeof(int) * p );
 			t->indexes[i][p] = last_found_empty;
 		}
 
-#endif
+#  endif /* INDEXES_ARE_ARRAYS */
+		t->updated = TRUE;
+		debug_print("[record_add] table %s marked as updated\n",
+				t->name );
 	}
 
-	updated = TRUE;
-		
 	return r->id;
+#endif /* ! USE_SQL */
 }
 
 /**
@@ -224,16 +290,22 @@ void record_free(table *t, record *r)
 			case T_STRING:
 			case T_STRINGS:
 			case T_MULTIMEDIA:
+			case T_FILE:
 			{
-				if ( r->cont[j].str )
+				if ( r->cont[j].str ) {
 					g_string_free(r->cont[j].str,1);
+					r->cont[j].str = NULL;
+				}
 			} break;
 			case T_DATE:
 			{
-				if ( r->cont[j].date )
+				if ( r->cont[j].date ) {
 					g_date_free(r->cont[j].date);
+					r->cont[j].date = NULL;
+				}
 			} break;
 			case T_INTEGER:
+			case T_DECIMAL:
 			case T_REAL:
 			case T_BOOLEAN:
 			case T_RECORD:
@@ -254,10 +326,30 @@ void record_free(table *t, record *r)
  * Description:
  * This function delete the record with the id @id from the table @t.
  *
- * Returns: TRUE if this works, FALSE if it doesn't.
+ * Returns: TRUE if it worked, FALSE if it didn't.
  **/
 gboolean record_remove_id(table *t, int id)
 {
+#ifdef USE_SQL
+	char sqlcmd[100];
+	PGresult *res;
+
+	g_snprintf(sqlcmd, 100, "DELETE FROM %s WHERE id = %d", t->name, id);
+	res = PQexec(sqlconn, sqlcmd);
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		debug_print("[record_remove_id (sql)] sql error (?)\n");
+		if (res)
+			PQclear(res);
+		return FALSE;
+	}
+	PQclear(res);
+
+	return TRUE;
+#else /* ! USE_SQL */
+	/* TODO (post-2.0, not really important): speed up record_remove_id
+	 * it could use sth similar to Python fast_record_ids
+	 * actually this code should/could be moved to record_remove 
+	 * and locating the record would be done by get_record_no() */
 	int i, j;
 	record *r;
 
@@ -277,13 +369,13 @@ gboolean record_remove_id(table *t, int id)
 						t->indexes[i] + p+1,
 						sizeof(int) * (t->nb_records-p-1));
 #endif
-				memmove( t->indexes[i] + p , \
-					t->indexes[i] + p+1, \
+				memmove( t->indexes[i] + p , 
+					t->indexes[i] + p+1, 
 					sizeof(int) * (t->nb_records-p-1) );
 			}
 			for ( i=0; i<t->nb_fields; i++ ) {
 				if ( t->indexes[i] == NULL ) continue;
-				t->indexes[i] = g_realloc(t->indexes[i], \
+				t->indexes[i] = g_realloc(t->indexes[i], 
 						t->nb_records * sizeof(int*));
 			}
 #endif
@@ -291,32 +383,32 @@ gboolean record_remove_id(table *t, int id)
 			r->id = 0;
 #if 1
 
-#ifdef DEBUG_GABY
 			debug_print("record: %p\n", r);
-#endif
 			for ( j=0; j < t->nb_fields; j++ ) {
-#ifdef DEBUG_GABY
-				debug_print("r->cont[%d].data: %p\n", j, \
+				debug_print("r->cont[%d].data: %p\n", j, 
 						r->cont[j].anything );
-#endif
 				switch ( t->fields[j].type ) {
 					case T_STRING:
 					case T_STRINGS:
 					case T_MULTIMEDIA:
+					case T_FILE:
 					{
-#ifdef DEBUG_GABY
-						debug_print("%s\n", \
+						debug_print("%s\n", 
 							r->cont[j].str->str );
-#endif
-						if ( r->cont[j].str )
+						if ( r->cont[j].str ) {
 							g_string_free(r->cont[j].str,1);
+							r->cont[j].str = NULL;
+						}
 					} break;
 					case T_DATE:
 					{
-						if ( r->cont[j].date )
+						if ( r->cont[j].date ) {
 							g_date_free(r->cont[j].date);
+							r->cont[j].date = NULL;
+						}
 					} break;
 					case T_INTEGER:
+					case T_DECIMAL:
 					case T_REAL:
 					case T_BOOLEAN:
 					case T_RECORD:
@@ -326,21 +418,25 @@ gboolean record_remove_id(table *t, int id)
 			}
 			g_free(r->cont);
 			r->cont = NULL;
-#else
+#else /* ! 1 */
 			record_free(t, r);
-#endif
-			/* TODO : scan for T_RECORDS referring this record
+#endif /* ! 1 */
+			/* TODO (post-2.0): scan for T_RECORDS referring this
+			 * record
 			 * the value could be replaced by 0 (understood as
 			 * 'none') or deleted. Customizable ?
+			 * Delayed since referential integrity is not a goal
+			 * for now...
 			 */
 
 			t->nb_records--;
-			updated = TRUE;
+			t->updated = TRUE;
 
 			return TRUE;
 		}
 	}
 	return FALSE;
+#endif /* ! USE_SQL */
 }
 
 /**
@@ -355,7 +451,7 @@ gboolean record_remove_id(table *t, int id)
  **/
 gboolean record_remove(table *t, record *r)
 {
-	/* is this really efficient ? */
+	/* is this really efficient ? (answer: no :) ) */
 	return (record_remove_id(t, r->id));
 }
 
@@ -372,24 +468,116 @@ gboolean record_remove(table *t, record *r)
  */
 gboolean record_modify(table *t, record *r)
 {
+#ifdef USE_SQL
+	PGresult *res;
+	char sqlstr[2000]; /* TODO (post-2.0): no fixed length strings !!!
+			    * delayed since sql won't be advertized */
+	char tmp[200];
 	int i;
+
+	debug_print("[record_modify] --\n");
+	g_snprintf(sqlstr, 2000, "SELECT * from %s WHERE id = %d", t->name, r->id);
+	res = PQexec(sqlconn, sqlstr);
+
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		/* should I deal differently in case of error and in case of
+		 * no result ? */
+		debug_print("SELECT command didn't return tuples properly\n");
+		if (res)
+			PQclear(res);
+		return FALSE;
+	}
+
+	if ( PQntuples(res) == 0 ) {
+		PQclear(res);
+		return FALSE;
+	}
+
+	g_snprintf(sqlstr, 2000, "UPDATE %s SET ", t->name);
+	for ( i=0; i<t->nb_fields; i++) {
+		GString *str = get_table_stringed_field(t, r, i);
+		g_snprintf(tmp, 200, "%s = \'%s\', ", PQfname(res, i+1), str->str);
+		g_string_free(str, 1);
+		strcat(sqlstr, tmp);
+	}
+	sqlstr[strlen(sqlstr)-2] = ' '; /* removing ',' */
+	g_snprintf(tmp, 200, "WHERE id = %d", r->id);
+	strcat(sqlstr, tmp);
+
+	PQclear(res);
+
+	res = PQexec(sqlconn, sqlstr);
+	if (res == NULL || PQresultStatus(res) != PGRES_COMMAND_OK) {
+		/* should I deal differently in case of error and in case of
+		 * no result ? */
+		debug_print("UPDATE command failed\n");
+		if (res)
+			PQclear(res);
+		return FALSE;
+	}
+	PQclear(res);
+
+	return TRUE;
+#else /* ! USE_SQL */
+	int i, j;
 	gboolean one=FALSE;
+	record *oldr;
+
 	for (i=0; i<t->max_records; i++) {
 		if ( r->id == t->records[i]->id ) {
 			one = TRUE;
 			break;
 		}
 	}
-	if ( one == FALSE ) return FALSE;
+	if ( one == FALSE ) {
+		debug_print("[record_modify] id (%d) doesn't exist !\n", r->id);
+		return FALSE;
+	}
+
+	debug_print("[record_modify] -- 1\n");
 	
+	/* let's free the old 'cont' */
+	oldr = t->records[i];
+	for ( j=0; j < t->nb_fields; j++ ) {
+		switch ( t->fields[j].type ) {
+			case T_STRING:
+			case T_STRINGS:
+			case T_MULTIMEDIA:
+			case T_FILE:
+			{
+				if ( oldr->cont[j].str ) {
+					g_string_free(oldr->cont[j].str,1);
+					oldr->cont[j].str = NULL;
+				}
+			} break;
+			case T_DATE:
+			{
+				if ( oldr->cont[j].date ) {
+					g_date_free(oldr->cont[j].date);
+					oldr->cont[j].date = NULL;
+				}
+			} break;
+			case T_INTEGER:
+			case T_REAL:
+			case T_DECIMAL:
+			case T_BOOLEAN:
+			case T_RECORD:
+			case T_RECORDS:
+			{ ; } break;
+		}
+	}
+	g_free(oldr->cont);
+	oldr->cont = NULL;
+	
+	debug_print("[record_modify] -- 2\n");
 	t->records[i]->cont = r->cont;
-	updated = TRUE;
+	t->updated = TRUE;
 	
-	/* TODO: resort index when modifying record
-	 *	 (this should be done in an optimized way) */
+	/* TODO (post-2.0):optimize index resorting when a record is modified */
 	indexes_create (t);
 
 	return TRUE;
+#endif /* ! USE_SQL */
 }
 
 /**
@@ -445,6 +633,111 @@ record* record_defaults(table *t)
 	return r;
 }
 
+/**
+ * record_duplicate
+ * @t: table
+ * @r: record to duplicate
+ *
+ * Description
+ * This function returns a new record filled with the values previously in @r
+ *
+ * Returns: the new record (record*)
+ **/
+record* record_duplicate(table *t, record *r)
+{
+	/* it's the caller's task to g_free what is returned */
+	int i;
+	record *rnew = g_new0(record, 1);
+	
+	rnew->cont = g_new0(union data, t->nb_fields);
+	rnew->id = 0;
+	
+	for ( i=0; i<t->nb_fields; i++ ) {
+		switch ( t->fields[i].type ) {
+			case T_STRING:
+			case T_STRINGS:
+			case T_MULTIMEDIA:
+			case T_FILE:
+			{
+				rnew->cont[i].str = g_string_new ( 
+							r->cont[i].str->str );
+			} break;
+			case T_DATE:
+			{
+				if ( r->cont[i].date == NULL ) {
+					rnew->cont[i].date = NULL;
+				} else {
+					rnew->cont[i].date = g_date_new();
+					memcpy(rnew->cont[i].date, 
+						r->cont[i].date, sizeof(GDate));
+				}
+			} break;
+			default:
+			{
+				memcpy(&(rnew->cont[i].anything), 
+					&(r->cont[i].anything),
+					sizeof(gpointer));
+			} break;
+		}
+	}
+
+	return rnew;
+}
+
+/**
+ * table_search_record
+ * @t: concerned table
+ * @nf: field number
+ * @what: string to search for
+ * @from: record id the search should start from
+ *
+ * Description:
+ * This functions searchs for a record whose field @nf matches (actually starts
+ * with) @what in table @t
+ *
+ * Returns: record position in table->records, -1 if not found
+ **/
+int table_search_record(table *t, int nf, char* what, int from)
+{
+	int i = from;
+	/*union data val;*/
+	field_type type = t->fields[nf].type;
+	
+
+	/*get_value_for_that_string(&val, t->fields[nf].type, what);*/
+	
+	for ( i=from; i<t->max_records; i++ ) {
+		record *r = t->records[i];
+		if ( r == NULL ) continue;
+		if ( r->id == 0 ) continue;
+		if ( cnd_is( r->cont[nf], what, type) )
+			return i;
+		if ( cnd_start_with( r->cont[nf], what, type) )
+			return i;
+	}
+	
+	return -1;
+}
+
+/**
+ * subtable_search_record
+ * @st: concerned subtable
+ * @nf: field number
+ * @what: string to search for
+ * @from: record id the search should start from
+ *
+ * Description:
+ * This functions searchs for a record whose field @nf matches (actually starts
+ * with) @what in subtable @st. (this is actually a stupid wrapper for
+ * table_search_record)
+ *
+ * Returns: record position in subtable->table->records, -1 if not found
+ **/
+int subtable_search_record(subtable *st, int nf, char* what, int from)
+{
+	return table_search_record(st->table, st->fields[nf].no, what, from);
+}
+
 #ifndef INDEXES_ARE_ARRAYS
 static int index_sort_id(record *a, record *b)
 {
@@ -456,7 +749,7 @@ static int index_sort_str(record *a, record *b)
 {
 	if ( a == NULL || b == NULL ) return 0;
 
-	return ( strcmp(	a->cont[gl_no_field].str->str, \
+	return ( strcmp(	a->cont[gl_no_field].str->str, 
 				b->cont[gl_no_field].str->str)
 			 );	
 }
@@ -557,22 +850,22 @@ static GList* index_create(table *t, int no)
 			case T_STRING:
 			case T_STRINGS:
 			{
-				g_list_insert_sorted(t->indexes[no+1], r, \
+				g_list_insert_sorted(t->indexes[no+1], r, 
 					(GCompareFunc)index_sort_str);
 			} break;
 			case T_DATE:
 			{
-				g_list_insert_sorted(t->indexes[no+1], r, \
+				g_list_insert_sorted(t->indexes[no+1], r, 
 					(GCompareFunc)g_date_compare);
 			} break;
 			case T_INTEGER:
 			{
-				g_list_insert_sorted(t->indexes[no+1], r, \
+				g_list_insert_sorted(t->indexes[no+1], r, 
 					(GCompareFunc)index_sort_int);
 			} break;
 			case T_REAL:
 			{
-				g_list_insert_sorted(t->indexes[no+1], r, \
+				g_list_insert_sorted(t->indexes[no+1], r, 
 					(GCompareFunc)index_sort_real);
 			} break;
 			default:
@@ -580,7 +873,7 @@ static GList* index_create(table *t, int no)
 				g_list_append(t->indexes[no+1], r);
 			}
 		}
-/*		g_list_insert_sorted(t->indexes[no+1], r, \
+/*		g_list_insert_sorted(t->indexes[no+1], r, 
 				(GCompareFunc)index_sort_str);	*/
 		t->indexes[no+1] = g_list_first(t->indexes[no+1]);
 	}
@@ -626,7 +919,7 @@ static GList* index_create(table *t, int no)
 	}
 
 #ifdef DEBUG_GABY
-	debug_print("[index_create] t->nb_records:%d, j:%d\n", \
+	debug_print("[index_create] t->nb_records:%d, j:%d\n", 
 				t->nb_records, j );
 #endif
 
@@ -640,25 +933,27 @@ static GList* index_create(table *t, int no)
 		case T_STRING:
 		case T_STRINGS:
 		case T_MULTIMEDIA:
+		case T_FILE:
 		{
-			qsort(ids, (size_t)j, sizeof(ids[0]), \
+			qsort(ids, (size_t)j, sizeof(ids[0]), 
 						(int (*)())string_compare);
 		} break;
 		case T_INTEGER:
 		case T_RECORD:
 		case T_BOOLEAN:
+		case T_DECIMAL:
 		{
-			qsort(ids, (size_t)j, sizeof(ids[0]), \
+			qsort(ids, (size_t)j, sizeof(ids[0]), 
 						(int (*)())int_compare);
 		} break;
 		case T_REAL:
 		{
-			qsort(ids, (size_t)j, sizeof(ids[0]), \
+			qsort(ids, (size_t)j, sizeof(ids[0]), 
 						(int (*)())real_compare);
 		} break;
 		case T_DATE:
 		{
-			qsort(ids, (size_t)j, sizeof(ids[0]), \
+			qsort(ids, (size_t)j, sizeof(ids[0]), 
 						(int (*)())date_compare);
 		} break;
 		case T_RECORDS: {/* not possible in table */} break;
@@ -666,7 +961,7 @@ static GList* index_create(table *t, int no)
 
 #ifndef INDEXES_ARE_ARRAYS
 	for (i=j-1; i>=0; i--) {
-		t->indexes[no] = g_list_prepend(t->indexes[no], \
+		t->indexes[no] = g_list_prepend(t->indexes[no], 
 							t->records[ids[i].i]);
 	}
 	t->indexes[no] = g_list_first(t->indexes[no]);
@@ -740,12 +1035,14 @@ static int index_find ( table *t, int num_field, record *r, gboolean exact )
 		case T_STRING:
 		case T_STRINGS:
 		case T_MULTIMEDIA:
+		case T_FILE:
 		{
 			compar = string_compare;
 		} break;
 		case T_INTEGER:
 		case T_RECORD:
 		case T_BOOLEAN:
+		case T_DECIMAL:
 		{
 			compar = int_compare;
 		} break;
@@ -834,7 +1131,36 @@ static int index_find ( table *t, int num_field, record *r, gboolean exact )
 record* table_next(table *t, record *r, int no_field)
 {
 	/* nofield : -1 for id else field number */ 
-#ifndef INDEXES_ARE_ARRAYS
+#ifdef USE_SQL
+	PGresult *res;
+	char sqlstr[1024];
+	char *id_str;
+
+	g_snprintf(sqlstr, 1024, "SELECT * from %s WHERE id > %d ORDER BY id "
+			"LIMIT 1", t->name, r->id);
+	res = PQexec(sqlconn, sqlstr);
+
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		/* should I deal differently in case of error and in case of
+		 * no result ? */
+		debug_print("SELECT command didn't return tuples properly\n");
+		if (res)
+			PQclear(res);
+		return NULL;
+	}
+
+	if ( PQntuples(res) == 0 ) {
+		PQclear(res);
+		return table_last(t, no_field);
+	}
+
+	id_str = (char *) PQgetvalue(res, 0, 0);
+	t->records[0]->id = atoi(id_str);
+	get_record_no(t, atoi(id_str));
+
+	return t->records[0];
+#else /* ! USE_SQL */
+#  ifndef INDEXES_ARE_ARRAYS
 	GList *index;
 	GList *new_index;
 	
@@ -857,32 +1183,26 @@ record* table_next(table *t, record *r, int no_field)
 		index = new_index;
 	} while ( index->data != NULL && ((record*)index->data)->id == 0 );
 
-#ifdef DEBUG_GABY
+#    ifdef DEBUG_GABY
 	if ( index != NULL && index->data != NULL ) {
 		debug_print("new id : %d\n", ((record*)index->data)->id);
 	} else {
 		debug_print("new id : -- (index->data : %p)\n", index->data);
 		debug_print("index->prev : %p\n", index->prev);
 	}
-#endif /* DEBUG_GABY */
+#     endif /* DEBUG_GABY */
 	
 	if ( index->data == NULL && index->prev != NULL ) {
-#ifdef DEBUG_GABY
 		debug_print("I am in the if\n");
-#endif
 		do {
 			index = g_list_previous(index);
-#ifdef DEBUG_GABY
 			debug_print("I am in the loop\n");
-#endif
 		} while (((record*)index->data)->id == 0);
-#ifdef DEBUG_GABY
 		debug_print("and the new id is ... %d !\n", ((record*)index->data)->id);
-#endif
 	}
 	return index->data;
 	
-#else /* RECORDS_ARE_ARRAYS  */
+#  else /* INDEXES_ARE_ARRAYS  */
 	int cur_pos, new_pos;
 	int *index;
 
@@ -900,7 +1220,8 @@ record* table_next(table *t, record *r, int no_field)
 	index = t->indexes[no_field+1];
 	
 	return ( t->records[ index[new_pos] ] );
-#endif
+#  endif /* INDEXES_ARE_ARRAYS */
+#endif /* ! USE_SQL */
 }
 
 /**
@@ -923,7 +1244,36 @@ record* table_next(table *t, record *r, int no_field)
 record* table_prev(table *t, record *r, int no_field)
 {
 	/* nofield : -1 for id else field number */ 
-#ifndef INDEXES_ARE_ARRAYS
+#ifdef USE_SQL
+	PGresult *res;
+	char sqlstr[1024];
+	char *id_str;
+
+	g_snprintf(sqlstr, 1024, "SELECT * from %s WHERE id < %d ORDER BY id DESC "
+			"LIMIT 1", t->name, r->id);
+	res = PQexec(sqlconn, sqlstr);
+
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		/* should I deal differently in case of error and in case of
+		 * no result ? */
+		debug_print("SELECT command didn't return tuples properly\n");
+		if (res)
+			PQclear(res);
+		return NULL;
+	}
+
+	if ( PQntuples(res) == 0 ) {
+		PQclear(res);
+		return table_first(t, no_field);
+	}
+
+	id_str = (char *) PQgetvalue(res, 0, 0);
+	t->records[0]->id = atoi(id_str);
+	get_record_no(t, atoi(id_str));
+
+	return t->records[0];
+#else /* ! USE_SQL */
+#  ifndef INDEXES_ARE_ARRAYS
 	GList *index;
 	GList *new_index;
 	
@@ -952,14 +1302,12 @@ record* table_prev(table *t, record *r, int no_field)
 	} else {
 		while (((record*)index->data)->id == 0) {
 			index = g_list_next(index);
-#ifdef DEBUG_GABY
 			debug_print("I am in a loop\n");
-#endif
 		}
 	}
 		
 	return index->data;
-#else /* INDEXES_ARE_ARRAYS */
+#  else /* INDEXES_ARE_ARRAYS */
 	int cur_pos, new_pos;
 	int *index;
 
@@ -978,7 +1326,8 @@ record* table_prev(table *t, record *r, int no_field)
 	
 	return ( t->records[ index[new_pos] ] );
 
-#endif
+#  endif /* INDEXES_ARE_ARRAYS */
+#endif /* ! USE_SQL */
 }
 
 /**
@@ -999,10 +1348,37 @@ record* table_prev(table *t, record *r, int no_field)
  **/
 record* table_first(table *t, int no_field)
 {
-#ifndef INDEXES_ARE_ARRAYS
+#ifdef USE_SQL
+	PGresult *res;
+	char sqlstr[1024];
+	char *id_str;
+
+	g_snprintf(sqlstr, 1024, "SELECT * from %s ORDER BY id LIMIT 1 ", t->name);
+	res = PQexec(sqlconn, sqlstr);
+
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		fprintf(stderr, "SELECT command didn't return tuples properly\n");
+		if (res)
+			PQclear(res);
+		return NULL;
+	}
+
+	if ( PQntuples(res) == 0 ) {
+		PQclear(res);
+		return NULL;
+	}
+
+	id_str = (char *) PQgetvalue(res, 0, 0);
+	t->records[0]->id = atoi(id_str);
+	get_record_no(t, atoi(id_str));
+
+	return t->records[0];
+
+#else /* ! USE_SQL */
+#  ifndef INDEXES_ARE_ARRAYS
 	GList *index;
 	GList *new_index;
-	
+
 	index = t->indexes[no_field+1];
 	if ( index == NULL )
 		index = index_create(t, no_field+1);
@@ -1020,7 +1396,7 @@ record* table_first(table *t, int no_field)
 	if ( index->data == NULL ) return NULL;
 
 	return (record *)(index->data);
-#else
+#  else /* INDEXES_ARE_ARRAY */
 	int *index;
 
 	if ( t->nb_records == 0 ) return NULL;
@@ -1030,7 +1406,8 @@ record* table_first(table *t, int no_field)
 		index = index_create(t, no_field+1);
 	
 	return ( t->records[ index[0] ] );
-#endif
+#  endif /* INDEXES_ARE_ARRAY */
+#endif /* ! USE_SQL */
 }
 
 /**
@@ -1051,7 +1428,33 @@ record* table_first(table *t, int no_field)
  **/
 record* table_last(table *t, int no_field)
 {
-#ifndef INDEXES_ARE_ARRAYS
+#ifdef USE_SQL
+	PGresult *res;
+	char sqlstr[1024];
+	char *id_str;
+
+	g_snprintf(sqlstr, 1024, "SELECT * from %s ORDER BY id DESC LIMIT 1 ", t->name);
+	res = PQexec(sqlconn, sqlstr);
+
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		fprintf(stderr, "SELECT command didn't return tuples properly\n");
+		if (res)
+			PQclear(res);
+		return NULL;
+	}
+
+	if ( PQntuples(res) == 0 ) {
+		PQclear(res);
+		return NULL;
+	}
+
+	id_str = (char *) PQgetvalue(res, 0, 0);
+	t->records[0]->id = atoi(id_str);
+	get_record_no(t, atoi(id_str));
+
+	return t->records[0];
+#else /* ! USE_SQL */
+#  ifndef INDEXES_ARE_ARRAYS
 	GList *index;
 	GList *new_index;
 
@@ -1074,7 +1477,7 @@ record* table_last(table *t, int no_field)
 
 	return (record *)(index->data);
 
-#else
+#  else /* INDEXES_ARE_ARRAYS */
 	int *index;
 
 	if ( t->nb_records == 0 ) return NULL;
@@ -1084,7 +1487,8 @@ record* table_last(table *t, int no_field)
 		index = index_create(t, no_field+1);
 	
 	return ( t->records[ index[t->nb_records-1] ] );
-#endif
+#  endif /* INDEXES_ARE_ARRAYS */
+#endif /* ! USE_SQL */
 }
 
 /**
@@ -1215,6 +1619,176 @@ record* table_last_with_conditions( table *t, int no_field, condition *c)
 	
 }
 
+/**
+ * table_get_records_count
+ * @t: table
+ *
+ * Description:
+ * This function counts the number of records in a given table.
+ **/
+int table_get_records_count(table *t)
+{
+#ifdef USE_SQL
+	PGresult *res;
+	char sqlstr[1024];
+	char *id_str;
+
+	g_snprintf(sqlstr, 1024, "SELECT count(*) from %s", t->name);
+	res = PQexec(sqlconn, sqlstr);
+
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		fprintf(stderr, "SELECT command didn't return tuples properly\n");
+		if (res)
+			PQclear(res);
+		return 0;
+	}
+
+	id_str = (char *) PQgetvalue(res, 0, 0);
+	return atoi(id_str);
+#else
+	return t->nb_records;
+#endif
+}
+
+gabycursor* cursor_declare(table *t)
+{
+#ifdef USE_SQL
+	gabycursor *cs;
+	PGresult *res;
+	char sqlcmd[200];
+	
+	res = PQexec(sqlconn, "BEGIN");
+	if (PQresultStatus(res) != PGRES_COMMAND_OK) {
+		PQclear(res);
+		return NULL;
+	}
+	PQclear(res);
+
+	g_snprintf(sqlcmd, 200, "DECLARE mycursor CURSOR FOR select * from %s",t->name);
+	res = PQexec(sqlconn, sqlcmd);
+	if (res == NULL || PQresultStatus(res) != PGRES_COMMAND_OK) {
+		if (res)
+			PQclear(res);
+		return NULL;
+	}
+	PQclear(res);
+	
+	cs = g_new0(gabycursor, 1);
+	cs->table = t;
+	cs->position = -1;
+	
+	return cs;
+#else /* ! USE_SQL */
+	gabycursor *cs = g_new0(gabycursor, 1);
+	cs->table = t;
+	cs->position = -1;
+	return cs;
+#endif /* ! USE_SQL */
+}
+
+#ifdef USE_SQL
+void create_record_from_sql_res(table *t, PGresult *res, int n)
+{
+	int i;
+	
+	for ( i=0; i<t->nb_fields; i++) {
+		char *str = (char*) PQgetvalue(res, n, i+1);
+		switch ( t->fields[i].type ) {
+			case T_DATE:
+			{
+				debug_print("date field received: %s\n", str);
+			} break;
+			default:
+			{
+				;
+			}
+		}
+		set_table_stringed_field(t, t->records[0], i, str);
+	}
+
+}
+#endif /* USE_SQL */
+
+record* cursor_get_first(gabycursor *cs)
+{
+#ifdef USE_SQL
+	PGresult *res;
+
+	res = PQexec(sqlconn, "FETCH ALL in mycursor");
+	if (res == NULL || PQresultStatus(res) != PGRES_TUPLES_OK) {
+		if ( res ) PQclear(res);
+		return NULL;
+	}
+	
+	cs->sqlres = res;
+	cs->position = 0;
+	cs->number = PQntuples(res);
+
+	create_record_from_sql_res(cs->table, cs->sqlres, 0);
+
+	return cs->table->records[0];
+
+#else /* ! USE_SQL */
+	table *t = cs->table;
+	int i = 0;
+
+	while ( i < t->max_records && (t->records[i] == NULL ||
+					t->records[i]->id == 0) ) i++;
+	cs->position = i;
+	if ( i >= t->max_records ) return NULL;
+	
+	return t->records[i];
+#endif /* ! USE_SQL */
+}
+
+record* cursor_get_next(gabycursor *cs)
+{
+#ifdef USE_SQL
+	cs->position++;
+	if ( cs->position == cs->number ) return NULL;
+
+	create_record_from_sql_res(cs->table, cs->sqlres, cs->position);
+
+	return cs->table->records[0];
+#else /* ! USE_SQL */
+	int i;
+	table *t = cs->table;
+	
+	i = cs->position + 1;
+	
+	while ( i < t->max_records && (t->records[i] == NULL ||
+					t->records[i]->id == 0) ) i++;
+	cs->position = i;
+	if ( i >= t->max_records ) return NULL;
+	
+	return t->records[i];
+#endif /* ! USE_SQL */
+}
+
+void cursor_free(gabycursor *cs)
+{
+#ifdef USE_SQL
+	PGresult *res;
+
+	res = PQexec(sqlconn, "CLOSE mycursor");
+	if (PQresultStatus(res) != PGRES_COMMAND_OK) {
+		PQclear(res);
+		return;
+	}
+	PQclear(res);
+	
+	res = PQexec(sqlconn, "COMMIT");
+	if (PQresultStatus(res) != PGRES_COMMAND_OK) {
+		PQclear(res);
+		return;
+	}
+	PQclear(res);
+	
+#else /* ! USE_SQL */
+	g_free(cs);
+#endif /* ! USE_SQL */
+}
+
 /* loading and saving functions (previously known as f_tables.c) */
 
 void table_maxindex(table *t)
@@ -1251,12 +1825,12 @@ gboolean table_load_file(table *t)
 #ifdef FOLLOW_MIGUEL
 #include "py_lf.c"
 #else
-		sprintf(plugin_name, "%s/formats/lib%s.so", \
-			PLUGINS_DIR, (loc->type == NULL) ? "gaby" : loc->type);
+		g_snprintf(plugin_name, PATH_MAX, PLUGINS_DIR "/formats/lib%s" SO_EXTENSION,
+				(loc->type == NULL) ? "gaby" : loc->type);
 		handle = g_module_open(plugin_name, 0);
 		if ( handle == NULL ) {
 			gaby_errno = CUSTOM_ERROR;
-			sprintf(message, _("Couldn't load %s format plug-in. (plug-in not found)"), loc->type );
+			g_snprintf(message, 1000, _("Couldn't load %s format plug-in. (%s)"), loc->type, g_module_error() );
 			gaby_message = g_strdup(message);
 			gaby_perror_in_a_box();
 			continue;
@@ -1264,7 +1838,7 @@ gboolean table_load_file(table *t)
 		mload_file = NULL;
 		g_module_symbol(handle, "load_file", (gpointer)&mload_file);
 		if ( mload_file == NULL ) {
-			sprintf(fct, "%s_load_file", \
+			g_snprintf(fct, 100, "%s_load_file", 
 				(loc->type == NULL) ? "gaby" : loc->type);
 			g_module_symbol(handle, fct, (gpointer)&mload_file);
 		}
@@ -1272,7 +1846,7 @@ gboolean table_load_file(table *t)
 		if ( mload_file == NULL ) {
 			g_module_close(handle);
 			gaby_errno = CUSTOM_ERROR;
-			sprintf(message, _("Couldn't load %s format plug-in. (loading function not found inside)"), loc->type );
+			g_snprintf(message, 1000, _("Couldn't load %s format plug-in. (loading function not found inside)"), loc->type );
 			gaby_perror_in_a_box();
 			continue;
 		}
@@ -1281,15 +1855,15 @@ gboolean table_load_file(table *t)
 		
 		g_module_close(handle);
 #endif /* ! FOLLOW_MIGUEL */
-		table_maxindex(t);
-		indexes_create(t);
 
 		/* create a timeout so the file is reloaded every x minutes */
 
 		/* we could save the tag in loc->reread but it would
 		 * be uglier */
 
-#if 0 /* TODO: re-enable this */
+#if 0 /* TODO (post-2.0): re-enable loc->reread
+       * delayed since nobody use it
+       */
 		/* disabled since it relies on a widget-dependant function */
 		if ( loc->reread != 0 ) {
 			loc->timeout_tag = gtk_timeout_add(
@@ -1298,16 +1872,41 @@ gboolean table_load_file(table *t)
 		}
 #endif
 	}
-	
+
+	table_maxindex(t);
+	indexes_create(t);
+	t->updated = FALSE;
+
 	return TRUE;
 }
 
-void tables_load(GList *list)
+void tables_load()
 {
-	GList *l=list;
+	GList *l = list_tables;
+#ifndef USE_SQL
 	g_list_foreach(l, (GFunc)table_load_file, NULL);
+#else /* USE_SQL */
 
-	updated = FALSE;
+	sqlconn = PQsetdb(NULL, NULL, NULL, NULL, appname);
+	if (PQstatus(sqlconn) == CONNECTION_BAD)
+	{
+		fprintf(stderr, "Connection to database failed.\n");
+		fprintf(stderr, "%s", PQerrorMessage(sqlconn));
+		PQfinish(sqlconn);
+	}
+
+	while ( l ) {
+		table *t = l->data;
+		l = g_list_next(l);
+		t->max_records = -1; /* indicates you have to use 
+					table_get_records_count to get
+					the information */
+		t->records = g_new0(record*, 1);
+		t->records[0] = g_new0(record, 1);
+		t->records[0]->cont = g_new0(union data, t->nb_fields);
+	}
+
+#endif /* USE_SQL */
 }
 
 gboolean table_save_file(table *t)
@@ -1323,6 +1922,13 @@ gboolean table_save_file(table *t)
 #ifdef DEBUG_GABY
 	debug_print("[table_save_file] Saving %s\n", t->name);
 #endif
+	if ( t->updated == FALSE ) {
+#ifdef DEBUG_GABY
+		debug_print("[table_save_file] considered up-to-date; skipped.\n");
+#endif
+		return TRUE;
+	}
+
 	locations = g_list_first(t->locations);
 	
 	while ( locations != NULL ) {
@@ -1333,7 +1939,7 @@ gboolean table_save_file(table *t)
 
 		if ( loc->readonly == TRUE ) {
 #ifdef DEBUG_GABY
-			debug_print("%s is marked as read-only - skipping\n", \
+			debug_print("%s is marked as read-only - skipping\n", 
 					loc->filename );
 #endif
 			continue;
@@ -1343,12 +1949,12 @@ gboolean table_save_file(table *t)
 #include "py_sf.c"
 #endif
 		
-		sprintf(plugin_name, "%s/formats/lib%s.so", \
-			PLUGINS_DIR, (loc->type == NULL) ? "gaby" : loc->type);
+		g_snprintf(plugin_name, PATH_MAX, PLUGINS_DIR "/formats/lib%s" SO_EXTENSION,
+				(loc->type == NULL) ? "gaby" : loc->type);
 		handle = g_module_open(plugin_name, 0);
 		if ( handle == NULL ) {
 			gaby_errno = CUSTOM_ERROR;
-			sprintf(message, _("Couldn't load %s format plug-in. (plug-in not found)"), loc->type );
+			g_snprintf(message, 1000, _("Couldn't load %s format plug-in. (%s)"), loc->type, g_module_error() );
 			gaby_message = g_strdup(message);
 			gaby_perror_in_a_box();
 			continue;
@@ -1356,13 +1962,13 @@ gboolean table_save_file(table *t)
 		msave_file = NULL;
 		g_module_symbol(handle, "save_file", (gpointer)&msave_file);
 		if ( msave_file == NULL ) {
-			sprintf(fct, "%s_save_file", \
+			g_snprintf(fct, 100, "%s_save_file", 
 				(loc->type == NULL) ? "gaby" : loc->type);
 			g_module_symbol(handle, fct, (gpointer)&msave_file);
 		}
 		if ( msave_file == NULL ) {
 			g_module_close(handle);
-			sprintf(message, _("Couldn't load %s format plug-in. (saving function not found inside)"), loc->type );
+			g_snprintf(message, 1000, _("Couldn't load %s format plug-in. (saving function not found inside)"), loc->type );
 			gaby_errno = CUSTOM_ERROR;
 			gaby_message = g_strdup(message);
 			gaby_perror_in_a_box();
@@ -1374,18 +1980,19 @@ gboolean table_save_file(table *t)
 		g_module_close(handle);
 	}
 	
+	t->updated = FALSE;
+
 	return TRUE;
 }
 
-void tables_save(GList *list)
+void tables_save()
 {
-	list = list_tables;
+	GList *list = g_list_first(list_tables);
 #ifdef DEBUG_GABY
 	debug_print("[table_save] l : %p\n", list);
 #endif
 	g_list_foreach(list, (GFunc)table_save_file, NULL);
 
-	updated = FALSE;
 }
 
 gboolean table_reread_file(table *t, struct location *loc)
@@ -1415,13 +2022,13 @@ gboolean table_reread_file(table *t, struct location *loc)
 #else
 	
 	/* this is from table_load_file, should I merge them ? */
-	sprintf(plugin_name, "%s/formats/lib%s.so", \
-			PLUGINS_DIR, (loc->type == NULL) ? "gaby" : loc->type);
+	g_snprintf(plugin_name, PATH_MAX, PLUGINS_DIR "/formats/lib%s" SO_EXTENSION, 
+				(loc->type == NULL) ? "gaby" : loc->type);
 	handle = g_module_open(plugin_name, 0);
 	if ( handle == NULL ) {
 		/* note that this shouldn't happen. */
 		gaby_errno = CUSTOM_ERROR;
-		sprintf(message, _("Couldn't load %s format plug-in. (plug-in not found)"), loc->type );
+		g_snprintf(message, 1000, _("Couldn't load %s format plug-in. (%s)"), loc->type, g_module_error() );
 		gaby_message = g_strdup(message);
 		gaby_perror_in_a_box();
 		return FALSE;
@@ -1430,14 +2037,14 @@ gboolean table_reread_file(table *t, struct location *loc)
 	mload_file = NULL;
 	g_module_symbol(handle, "load_file", (gpointer)&mload_file);
 	if ( mload_file == NULL ) {
-		sprintf(fct, "%s_load_file", \
+		g_snprintf(fct, 100, "%s_load_file", 
 				(loc->type == NULL) ? "gaby" : loc->type);
 		g_module_symbol(handle, fct, (gpointer)&mload_file);
 	}
 	if ( mload_file == NULL ) {
 		g_module_close(handle);
 		gaby_errno = CUSTOM_ERROR;
-		sprintf(message, _("Couldn't load %s format plug-in. (loading function not found inside)"), loc->type );
+		g_snprintf(message, 1000, _("Couldn't load %s format plug-in. (loading function not found inside)"), loc->type );
 		gaby_perror_in_a_box();
 		return FALSE;
 	}
@@ -1449,7 +2056,41 @@ gboolean table_reread_file(table *t, struct location *loc)
 	
 	indexes_create(t);
 	table_maxindex(t);
+	t->updated = FALSE;
 
 	return TRUE;
 }
 
+gboolean tables_modified()
+{
+	table *t;
+	GList *list = g_list_first(list_tables);
+	while ( list != NULL ) {
+		t = list->data;
+#ifdef DEBUG_GABY
+		debug_print("[tables_modified] status for table %s is %d\n",
+				t->name, t->updated);
+#endif
+		if ( t->updated == TRUE ) return TRUE;
+		list = g_list_next(list);
+	}
+	return FALSE;
+}
+
+void table_free_records(table *t)
+{
+	int i;
+	record *r;
+
+	for ( i=0; i<t->max_records; i++) {
+		r = t->records[i];
+		if ( r == NULL ) continue;
+		record_free(t, r);
+		t->records[i] = NULL;
+	}
+	g_free(t->records);
+	t->records = NULL;
+	t->nb_records = 0;
+	t->max_records = 0;
+}
+
