@@ -1,5 +1,5 @@
 
-#define NO_GTK
+#define NO_GUI
 #define LISTS_DECLARED
 #define GABY_TEST
 
@@ -13,6 +13,8 @@ GList *list_subtables;
 GList *list_views;
 GList *list_actions;
 
+int debug_mode;
+
 property* field_get_property ( field *f, gchar *ident ) { return NULL; }
 void gaby_perror_in_a_box (void) { puts(errors_list[gaby_errno]); }
 
@@ -24,6 +26,7 @@ gboolean nosql_load_file    ( struct location *loc ) { return TRUE; }
 gboolean vcard_load_file    ( struct location *loc ) { return TRUE; }
 gboolean dbase_load_file    ( struct location *loc ) { return TRUE; }
 gboolean appindex_load_file ( struct location *loc ) { return TRUE; }
+gboolean dpkg_load_file     ( struct location *loc ) { return TRUE; }
 
 gboolean gaby_save_file     ( struct location *loc ) { return TRUE; }
 gboolean gaby1_save_file    ( struct location *loc ) { return TRUE; }
@@ -31,6 +34,7 @@ gboolean nosql_save_file    ( struct location *loc ) { return TRUE; }
 gboolean vcard_save_file    ( struct location *loc ) { return TRUE; }
 gboolean dbase_save_file    ( struct location *loc ) { return TRUE; }
 gboolean appindex_save_file ( struct location *loc ) { return TRUE; }
+gboolean dpkg_save_file     ( struct location *loc ) { return TRUE; }
 
 
 #define NB_FIELDS 5
